@@ -6,8 +6,8 @@
 # Author:      Riaan Booysen
 #
 # Created:     1999
-# RCS-ID:      $Id: Boa.py,v 1.45 2004/08/16 13:54:21 riaan Exp $
-# Copyright:   (c) 1999 - 2004 Riaan Booysen
+# RCS-ID:      $Id: Boa.py,v 1.57 2007/07/05 14:08:43 riaan Exp $
+# Copyright:   (c) 1999 - 2007 Riaan Booysen
 # Licence:     GPL
 #----------------------------------------------------------------------
 #Boa:App:BoaApp
@@ -18,7 +18,10 @@ Handles creation/initialisation of main objects and commandline arguments """
 
 import sys, os, string, time, warnings
 
-#try: import psyco; psyco.background()
+#sys.stdout = sys.__stdout__#open('stdout.txt', 'w')
+#sys.stderr = sys.__stderr__#open('stderr.txt', 'w')
+
+#try: import psyco; psyco.full()
 #except ImportError: pass
 
 t1 = time.time()
@@ -44,7 +47,7 @@ def trace_func(frame, event, arg):
     return trace_func
 
 def get_current_frame():
-    try: raise 'get_exc_info'
+    try: raise Exception, 'get_exc_info'
     except: return sys.exc_info()[2].tb_frame.f_back
 
 def sendToRunningBoa(names, host='127.0.0.1', port=50007):
@@ -74,99 +77,122 @@ doDebug = constricted = emptyEditor = blockSocketServer = 0
 startupfile = ''
 startupModules = ()
 startupEnv = os.environ.get('BOASTARTUP') or os.environ.get('PYTHONSTARTUP')
+wxVersionSelect = None
+unicodeEncoding = None
 
 def processArgs(argv):
     _doDebug = _doRemoteDebugSvr = _constricted = _emptyEditor = 0
     _blockSocketServer = 0
     _startupfile = ''
     _startupModules = ()
+    _wxVersionSelect = _unicodeEncoding = None
     import getopt
-    optlist, args = getopt.getopt(argv, 'CDTSBO:ERNHVhv', 
-         ['Constricted', 'Debug', 'Trace', 'StartupFile', 'BlockHomePrefs', 
-          'OverridePrefsDirName', 'EmptyEditor', 'RemoteDebugServer', 
-          'NoCmdLineTransfer', 'Help', 'Version', 'help', 'version'])
-    if (('-D', '') in optlist or ('--Debug', '') in optlist) and len(args):
-        # XXX should be able to 'debug in running Boa'
-        _doDebug = 1
-    elif (('-R', '') in optlist or ('--RemoteDebugServer', '') in optlist) and len(args):
-        _doRemoteDebugSvr = 1
-    elif ('-T', '') in optlist or ('--Trace', '') in optlist:
-        print 'Running in trace mode.'
-        global tracefile
-        tracefile = open('Boa.trace', 'wt')
-        tracefile.write(os.getcwd()+'\n')
-        trace_func(get_current_frame().f_back, 'call', None)
-        trace_func(get_current_frame(), 'call', None)
-        if trace_mode == 'functions':
-            sys.setprofile(trace_func)
-        elif trace_mode == 'lines':
-            sys.settrace(trace_func)
+    try:
+        optlist, args = getopt.getopt(argv, 'CDTSBERNHVhvO:W:U:',
+         ['Constricted', 'Debug', 'Trace', 'StartupFile', 'BlockHomePrefs',
+          'EmptyEditor', 'RemoteDebugServer', 'NoCmdLineTransfer', 'Help', 
+          'Version', 'help', 'version', 'OverridePrefsDirName', 'WxVersionSelect',
+          'UnicodeEncoding'])
+    except getopt.GetoptError, err:
+        print 'Error: %s'%str(err)
+        print 'For options: Boa.py --help'
+        sys.exit()
 
     if len(args):
         # XXX Only the first file appears in the list when multiple files
         # XXX are drag/dropped on a Boa shortcut, why?
         _startupModules = args
 
-    if ('-S', '') in optlist or ('--StartupFile', '') in optlist:
-        _startupfile = startupEnv
+    for opt, arg in optlist:
+        if opt in ('-D', '--Debug') and len(args):
+            # XXX should be able to 'debug in running Boa'
+            _doDebug = 1
+        elif opt in ('-R', '--RemoteDebugServer') and len(args):
+            _doRemoteDebugSvr = 1
+        elif opt in ('-T', '--Trace'):
+            print 'Running in trace mode.'
+            global tracefile
+            tracefile = open('Boa.trace', 'wt')
+            tracefile.write(os.getcwd()+'\n')
+            trace_func(get_current_frame().f_back, 'call', None)
+            trace_func(get_current_frame(), 'call', None)
+            if trace_mode == 'functions':
+                sys.setprofile(trace_func)
+            elif trace_mode == 'lines':
+                sys.settrace(trace_func)
+    
+        if opt in ('-S', '--StartupFile'):
+            _startupfile = startupEnv
+    
+        if opt in ('-C', '--Constricted'):
+            _constricted = 1
+    
+        if opt in ('-E', '--EmptyEditor'):
+            _emptyEditor = 1
+    
+        if opt in ('-N', '--NoCmdLineTransfer'):
+            _blockSocketServer = 1
+        
+        if opt in ('-W', '--wxVersionSelect', ''):
+            _wxVersionSelect = arg
 
-    if ('-C', '') in optlist or ('--Constricted', '') in optlist:
-        _constricted = 1
-
-    if ('-E', '') in optlist or ('--EmptyEditor', '') in optlist:
-        _emptyEditor = 1
-
-    if ('-N', '') in optlist or ('--NoCmdLineTransfer', '') in optlist:
-        _blockSocketServer = 1
-
-    if ('-h', '') in optlist or ('--help', '') in optlist or \
-       ('-H', '') in optlist or ('--Help', '') in optlist:
-        print 'Boa Constructor (%s)'%__version__.version
-        print 'Command-line usage: %s [options] [file1] [file2] ...'%main_script
-        print '-C, --Constricted:'
-        print '\tRuns in constricted mode, overrides the Preference'
-        print '-D, --Debug:'
-        print '\tRuns the first filename passed on the command-line in the Debugger '
-        print '\ton startup'
-        print '-T, --Trace:'
-        print '\tRuns in traceing mode. Used for tracking down core dumps. Every '
-        print '\tfunction call is logged to a file which can later be parsed for '
-        print '\ta traceback'
-        print '-S, --StartupFile:'
-        print '\tExecutes the script pointed to by $BOASTARTUP or '\
-              '$PYTHONSTARTUP in'
-        print '\tthe Shell namespace. The Editor object is available as sys.boa_ide.'
-        print '\tOverrides the Preference'
-        print '-B, --BlockHomePrefs:'
-        print '\tPrevents the $HOME directory being used '
-        print '-O dirname, --OverridePrefsDirName dirname:'
-        print '\tSpecify a different directory to load Preferences from.'
-        print '\tDefault is .boa and is used if it exists'
-        print '\tDirectory will be created (and populated) if it does not exist'
-        print '-E, --EmptyEditor:'
-        print "\tDon't open the files that were open last time Boa was closed."
-        print '-R, --RemoteDebugServer:'
-        print "\tRuns the first filename passed on the command-line in a "
-        print "\tRemote Debugger Server that can be connected to over a socket."
-        print '-N, --NoCmdLineTransfer:'
-        print "\tDon't transfer command line options to a running Boa, start a "
-        print "\tnew instance."
-
-        sys.exit()
-
-    if ('-v', '') in optlist or ('--version', '') in optlist or \
-       ('-V', '') in optlist or ('--Version', '') in optlist:
-        print 'Version: %s'%__version__.version
-        sys.exit()
+        if opt in ('-U', '--UnicodeEncoding', ''):
+            _unicodeEncoding = arg
+    
+        if opt in ('-h', '--help', '-H', '--Help'):
+            print 'Boa Constructor (%s)'%__version__.version
+            print 'Command-line usage: %s [options] [file1] [file2] ...'%main_script
+            print '-C, --Constricted:'
+            print '\tRuns in constricted mode, overrides the Preference'
+            print '-D, --Debug:'
+            print '\tRuns the first filename passed on the command-line in the Debugger '
+            print '\ton startup'
+            print '-T, --Trace:'
+            print '\tRuns in traceing mode. Used for tracking down core dumps. Every '
+            print '\tfunction call is logged to a file which can later be parsed for '
+            print '\ta traceback'
+            print '-S, --StartupFile:'
+            print '\tExecutes the script pointed to by $BOASTARTUP or '\
+                  '$PYTHONSTARTUP in'
+            print '\tthe Shell namespace. The Editor object is available as sys.boa_ide.'
+            print '\tOverrides the Preference'
+            print '-B, --BlockHomePrefs:'
+            print '\tPrevents the $HOME directory being used '
+            print '-O dirname, --OverridePrefsDirName dirname:'
+            print '\tSpecify a different directory to load Preferences from.'
+            print '\tDefault is .boa and is used if it exists'
+            print '\tDirectory will be created (and populated) if it does not exist'
+            print '-E, --EmptyEditor:'
+            print "\tDon't open the files that were open last time Boa was closed."
+            print '-R, --RemoteDebugServer:'
+            print '\tRuns the first filename passed on the command-line in a '
+            print '\tRemote Debugger Server that can be connected to over a socket.'
+            print '-N, --NoCmdLineTransfer:'
+            print "\tDon't transfer command line options to a running Boa, start a "
+            print '\tnew instance.'
+            print '-U encoding, --UnicodeEncoding encoding:'
+            print '\tSpecify a spesific encoding to use.'
+            print '-W version, --wxVersionSelect version:'
+            print '\tSpecify a spesific version of wxPython to use.'
+            print '-H, --Help, -h, --help:'
+            print '\tThis page.'
+    
+            sys.exit()
+    
+        if opt in ('-v', '--version', '-V', '--Version'):
+            print 'Version: %s'%__version__.version
+            sys.exit()
 
     return (_doDebug, _startupfile, _startupModules, _constricted, _emptyEditor,
-            _doRemoteDebugSvr, _blockSocketServer, optlist, args)
+            _doRemoteDebugSvr, _blockSocketServer, _wxVersionSelect, 
+            _unicodeEncoding, optlist, args)
 
 # This happens as early as possible (before wxPython loads) to make filename
 # transfer to a running Boa as quick as possible and little NS pollution
 if __name__ == '__main__' and len(sys.argv) > 1:
     (doDebug, startupfile, startupModules, constricted, emptyEditor, doDebugSvr,
-     blockSocketServer, opts, args) = processArgs(sys.argv[1:])
+     blockSocketServer, wxVersionSelect, unicodeEncoding, 
+     opts, args) = processArgs(sys.argv[1:])
     if doDebugSvr and startupModules:
         print 'Running as a Remote Debug Server'
         from Debugger.RemoteServer import start
@@ -190,30 +216,36 @@ if __name__ == '__main__' and len(sys.argv) > 1:
 print 'Starting Boa Constructor v%s'%__version__.version
 print 'importing wxPython'
 
-# silence wxPython's bool deprecations
-from wxPython import wx
+if unicodeEncoding is not None:
+    print 'using encoding %s'%unicodeEncoding
+    if hasattr(sys, 'frozen'):  
+        sys.setdefaultencoding(unicodeEncoding)
+    else:   
+        reload(sys)
+        sys.setdefaultencoding(unicodeEncoding)
+        del sys.setdefaultencoding
+
 try:
-    # wxPy 2.4.0.4 and Py 2.2 and 2.3
-    wx.true = True
-    wx.false = False
-except NameError:
-    try:
-        # wxPy 2.4.0.4 and Py 2.1
-        wx.true = wx.True
-        wx.false = wx.False
-    except AttributeError:
-        # earlier wxPys
-        pass
+    # See if there is a multi-version install of wxPython
+    if not hasattr(sys, 'frozen'):
+        import wxversion
+        if wxVersionSelect is None:
+            wxversion.ensureMinimal('2.5')
+        else:
+            wxversion.select(wxVersionSelect)
+except ImportError:
+    # Otherwise assume a normal 2.4 install, if it isn't 2.4 it will
+    # be caught below
+    pass
 
-from wxPython.wx import *
-wxRegisterId(15999)
+import wx
+wx.RegisterId(15999)
 
-warnings.filterwarnings('ignore', '', DeprecationWarning, 'wxPython.imageutils')
+#warnings.filterwarnings('ignore', '', DeprecationWarning, 'wxPython.imageutils')
 
 # Use package version string as it is the only one containing bugfix version number
-import wxPython
 # Remove non number/dot characters
-wxVersion = wxPython.__version__
+wxVersion = wx.__version__
 for c in wxVersion:
     if c not in string.digits+'.':
         wxVersion = wxVersion.replace(c, '')
@@ -222,22 +254,27 @@ wxVersion = tuple(map(lambda v: int(v),
                       (wxVersion.split('.')+['0'])[:4]))
 
 if wxVersion < __version__.wx_version:
-    wxPySimpleApp()
-    wxMessageBox('Sorry! This version of Boa requires at least '\
+    wx.PySimpleApp()
+    wx.MessageBox('Sorry! This version of Boa requires at least '\
                  'wxPython %d.%d.%d.%d'%__version__.wx_version,
-                 'Version error', wxOK | wxICON_ERROR)
-    raise 'wxPython >= %d.%d.%d.%d required'%__version__.wx_version
+                 'Version error', wx.OK | wx.ICON_ERROR)
+    raise Exception, 'wxPython >= %d.%d.%d.%d required'%__version__.wx_version
 
 if __version__.wx_version_max and wxVersion > __version__.wx_version_max:
-    wxPySimpleApp()
-    wxMessageBox('Sorry! This version of Boa does not work under '\
+    wx.PySimpleApp()
+    wx.MessageBox('Sorry! This version of Boa does not work under '\
                  'wxPython %d.%d.%d.%d, please downgrade to '\
                  'wxPython %d.%d.%d.%d'% (wxVersion+__version__.wx_version_max),
-                 'Version error', wxOK | wxICON_ERROR)
-    raise 'wxPython %d.%d.%d.%d not supported'%wxVersion
+                 'Version error', wx.OK | wx.ICON_ERROR)
+    raise Exception, 'wxPython %d.%d.%d.%d not supported'%wxVersion
+
+import Preferences, Utils
+from Utils import _
+
+import About
 
-import Preferences, Utils, About
 print 'running main...'
+
 # XXX auto created frames (main frame handled currently)
 # XXX More property editors!
 # XXX More companion classes! $
@@ -256,11 +293,12 @@ print 'running main...'
 
 # XXX Save as after app is closed
 
-# XXX Add wxImageBitmap, delete (prints class link error)
+# XXX Add wx.ImageBitmap, delete (prints class link error)
 
 
 modules ={'About': [0, 'About box and Splash screen', 'About.py'],
  'AppViews': [0, 'Views for the AppModel', 'Views/AppViews.py'],
+ 'ArtProviderBrowser': [0, '', 'PropEdit/ArtProviderBrowser.py'],
  'BaseCompanions': [0, '', 'Companions/BaseCompanions.py'],
  'BasicCompanions': [0, '', 'Companions/BasicCompanions.py'],
  'BicycleRepairMan.plug-in': [0, '', 'Plug-ins/BicycleRepairMan.plug-in.py'],
@@ -269,7 +307,6 @@ modules ={'About': [0, 'About box and Splash screen', 'About.py'],
  'ButtonCompanions': [0, '', 'Companions/ButtonCompanions.py'],
  'CPPSupport': [0, '', 'Models/CPPSupport.py'],
  'CVSExplorer': [0, '', 'Explorers/CVSExplorer.py'],
- 'CVSResults': [0, '', 'Explorers/CVSResults.py'],
  'ChildProcessClient': [0, '', 'Debugger/ChildProcessClient.py'],
  'ChildProcessServer': [0, '', 'Debugger/ChildProcessServer.py'],
  'ChildProcessServerStart': [0, '', 'Debugger/ChildProcessServerStart.py'],
@@ -290,6 +327,7 @@ modules ={'About': [0, 'About box and Splash screen', 'About.py'],
                   'Companions/Constructors.py'],
  'ContainerCompanions': [0, '', 'Companions/ContainerCompanions.py'],
  'Controllers': [0, '', 'Models/Controllers.py'],
+ 'CreationOrdDlg': [0, '', 'Views/CreationOrdDlg.py'],
  'CtrlAlign': [0, '', 'Views/CtrlAlign.py'],
  'CtrlSize': [0, '', 'Views/CtrlSize.py'],
  'Cyclops': [0, '', 'ExternalLib/Cyclops.py'],
@@ -297,6 +335,7 @@ modules ={'About': [0, 'About box and Splash screen', 'About.py'],
  'DataView': [0,
               'View to manage non visual frame objects',
               'Views/DataView.py'],
+ 'DateTimeCompanions': [0, '', 'Companions/DateTimeCompanions.py'],
  'DebugClient': [0, '', 'Debugger/DebugClient.py'],
  'Debugger': [0,
               'Module for out-of-process debugging of Python apps',
@@ -335,7 +374,6 @@ modules ={'About': [0, 'About box and Splash screen', 'About.py'],
  'FindResults': [0, '', 'FindResults.py'],
  'FlexGridGrowableDlg': [0, '', 'Companions/FlexGridGrowableDlg.py'],
  'FrameCompanions': [0, '', 'Companions/FrameCompanions.py'],
- 'GCFrame': [0, '', 'GCFrame.py'],
  'GizmoCompanions': [0, '', 'Companions/GizmoCompanions.py'],
  'HTMLCyclops': [0, '', 'HTMLCyclops.py'],
  'HTMLResponse': [0, '', 'HTMLResponse.py'],
@@ -356,6 +394,7 @@ modules ={'About': [0, 'About box and Splash screen', 'About.py'],
  'InspectorEditorControls': [0, '', 'PropEdit/InspectorEditorControls.py'],
  'IsolatedDebugger': [0, '', 'Debugger/IsolatedDebugger.py'],
  'JavaSupport.plug-in': [0, '', 'Plug-ins/JavaSupport.plug-in.py'],
+ 'LanguageSelectDlg': [0, '', 'LanguageSelectDlg.py'],
  'LibCompanions': [0, '', 'Companions/LibCompanions.py'],
  'ListCompanions': [0, '', 'Companions/ListCompanions.py'],
  'LoginDialog': [0, '', 'ZopeLib/LoginDialog.py'],
@@ -450,75 +489,86 @@ modules ={'About': [0, 'About box and Splash screen', 'About.py'],
  'wxPythonEditorModels': [0, '', 'Models/wxPythonEditorModels.py'],
  'xmlrpclib': [0, '', 'ExternalLib/xmlrpclib.py']}
 
-class BoaApp(wxApp):
+class BoaApp(wx.App):
     """ Application object, responsible for the Splash screen, applying command
         line switches, optional logging and creation of the main frames. """
 
     def __init__(self):
-        wxApp.__init__(self, false)
+        wx.App.__init__(self, False)
 
     def OnInit(self):
         Preferences.initScreenVars()
-        
-        wxInitAllImageHandlers()
 
-        wxToolTip_Enable(true)
+        # i18n support
+        self.locale = wx.Locale(Preferences.i18nLanguage)
+        wx.Locale.AddCatalogLookupPathPrefix(os.path.join(Preferences.pyPath, 'locale'))
+        if hasattr(sys, 'frozen'):
+            self.locale.AddCatalog('wxstd')   
+        self.locale.AddCatalog('boa') 
+
+        wx.ToolTip.Enable(True)
         if Preferences.debugMode == 'release':
-            self.SetAssertMode(wxPYAPP_ASSERT_SUPPRESS)
+            self.SetAssertMode(wx.PYAPP_ASSERT_SUPPRESS)
         elif Preferences.debugMode == 'development':
-            self.SetAssertMode(wxPYAPP_ASSERT_EXCEPTION)
-            
+            self.SetAssertMode(wx.PYAPP_ASSERT_EXCEPTION)
+
 
         conf = Utils.createAndReadConfig('Explorer')
-        modTot = conf.getint('splash', 'modulecount')
+        if not conf.has_section('splash'):
+            conf.add_section('splash')
+            modTot = 1
+        else:
+            modTot = conf.getint('splash', 'modulecount')
         fileTot = len(eval(conf.get('editor', 'openfiles'), {}))
 
         abt = About.createSplash(None, modTot, fileTot)
         try:
             abt.Show()
+            abt.Update()
             # Let the splash screen repaint
-            wxYield()
-    
+            wx.Yield()
+
+            # Imported here to initialise core features and plug-ins
+            import PaletteMapping
+
             print 'creating Palette'
             import Palette
             self.main = Palette.BoaFrame(None, -1, self)
-    
+
             print 'creating Inspector'
             import Inspector
             inspector = Inspector.InspectorFrame(self.main)
-    
+
             print 'creating Editor'
             import Editor
-            editor = Editor.EditorFrame(self.main, -1, inspector, wxMenu(),
+            editor = Editor.EditorFrame(self.main, -1, inspector, wx.Menu(),
                 self.main.componentSB, self, self.main)
             self.SetTopWindow(editor)
-    
+
             inspector.editor = editor
-    
-            conf.set('splash', 'modulecount', `len(sys.modules)`)
+
+            conf.set('splash', 'modulecount', str(len(sys.modules)))
             try:
                 Utils.writeConfig(conf)
             except IOError, err:
-                startupErrors.append('Error writing config file: %s\nPlease '
-              'ensure that the Explorer.*.cfg file is not read only.'% str(err))
-    
+                startupErrors.append(_('Error writing config file: %s\nPlease '
+              'ensure that the Explorer.*.cfg file is not read only.')% str(err))
+
             if not emptyEditor:
                 editor.restoreEditorState()
-    
+
             self.main.initPalette(inspector, editor)
-    
+
     ##            editor.setupToolBar()
-    
+
             import Help
-            print 'attaching wxPython doc strings'
-            Help.initWxPyDocStrs()
             if not Preferences.delayInitHelp:
-                print 'initialising Help'
+                print 'initialising help'
                 Help.initHelp()
-    
+
             global constricted
             constricted = constricted or Preferences.suBoaConstricted
-    
+
             print 'showing main frames <<100/100>>'
             if constricted:
                 editor.CenterOnScreen()
@@ -533,19 +583,17 @@ class BoaApp(wxApp):
 
             editor.Show()
             editor.doAfterShownActions()
-    
+
             # Call startup files after complete editor initialisation
             global startupfile
             if Preferences.suExecPythonStartup and startupEnv:
                 startupfile = startupEnv
-    
+
             if editor.shell:
                 editor.shell.execStartupScript(startupfile)
-        
+
         finally:
             abt.Destroy()
-            #del abt
-            pass
 
         # Apply command line switches
         if doDebug and startupModules:
@@ -557,43 +605,48 @@ class BoaApp(wxApp):
 
         editor.setupToolBar()
 
-        editor.setStatus('Startup time: %5.2f' % (time.time() - t1))
+        #editor.setStatus('Startup time: %5.2f' % (time.time() - t1))
 
         Utils.showTip(self.main.editor)
 
         if Preferences.logStdStreams:
-            sys.stderr = Utils.ErrorLoggerPF()
             sys.stdout = Utils.OutputLoggerPF()
+            sys.excepthook = Utils.wxPyExceptHook
+
+        if Preferences.exWorkingDirectory:
+            try:
+                os.chdir(Preferences.exWorkingDirectory)
+            except OSError, err:
+                startupErrors.append(_('Could not set working directory from '
+                                       'Preferences.exWorkingDirectory :'))
+                startupErrors.append(str(err))
 
         if startupErrors:
             for error in startupErrors:
-                wxLogError(error)
-            wxLogError('\nThere were errors during startup, please click "Details"')
+                wx.LogError(error)
+            wx.LogError(_('\nThere were errors during startup, please click "Details"'))
 
-        if wxPlatform == '__WXMSW__':
-            self.tbicon = wxTaskBarIcon()
+        if wx.Platform == '__WXMSW__':
+            self.tbicon = wx.TaskBarIcon()
             self.tbicon.SetIcon(self.main.GetIcon(), 'Boa Constructor')
-            EVT_TASKBAR_LEFT_DCLICK(self.tbicon, self.OnTaskBarActivate)
-            EVT_TASKBAR_RIGHT_UP(self.tbicon, self.OnTaskBarMenu)
-            EVT_MENU(self.tbicon, self.TBMENU_RESTORE, self.OnTaskBarActivate)
-            EVT_MENU(self.tbicon, self.TBMENU_CLOSE, self.OnTaskBarClose)
-            EVT_MENU(self.tbicon, self.TBMENU_ABOUT, self.OnTaskBarAbout)
-
-        if Preferences.exWorkingDirectory:
-            os.chdir(Preferences.exWorkingDirectory)
+            self.tbicon.Bind(wx.EVT_TASKBAR_LEFT_DCLICK, self.OnTaskBarActivate)
+            self.tbicon.Bind(wx.EVT_TASKBAR_RIGHT_UP, self.OnTaskBarMenu)
+            self.tbicon.Bind(wx.EVT_MENU, self.OnTaskBarActivate, id=self.TBMENU_RESTORE)
+            self.tbicon.Bind(wx.EVT_MENU, self.OnTaskBarClose, id=self.TBMENU_CLOSE)
+            self.tbicon.Bind(wx.EVT_MENU, self.OnTaskBarAbout, id=self.TBMENU_ABOUT)
 
         editor.assureRefreshed()
 
-        return true
+        return True
 
     [TBMENU_RESTORE, TBMENU_CLOSE, TBMENU_ABOUT] = Utils.wxNewIds(3)
 
     def OnTaskBarMenu(self, event):
-        menu = wxMenu()
-        menu.Append(self.TBMENU_RESTORE, 'Restore Boa Constructor')
-        menu.Append(self.TBMENU_CLOSE,   'Exit')
-        menu.Append(-1, '')
-        menu.Append(self.TBMENU_ABOUT,   'About')
+        menu = wx.Menu()
+        menu.Append(self.TBMENU_RESTORE, _('Restore Boa Constructor'))
+        menu.Append(self.TBMENU_CLOSE,   _('Exit'))
+        menu.AppendSeparator()
+        menu.Append(self.TBMENU_ABOUT,   _('About'))
         self.tbicon.PopupMenu(menu)
         menu.Destroy()
 
@@ -605,7 +658,7 @@ class BoaApp(wxApp):
 
     def OnTaskBarClose(self, event):
         self.main.Close()
-        self.ProcessIdle()
+        #self.ProcessIdle()
 
     def OnTaskBarAbout(self, event):
         self.main.editor.OnHelpAbout(event)
@@ -618,7 +671,7 @@ def main(argv=None):
         join, dirname = os.path.join, os.path.dirname
         wxPythonPath = dirname(wx.__file__)
         wxPythonLibPath = join(dirname(wx.__file__), 'lib')
-        ##pythonLibPath = dirname(wxPythonPath)
+        ##pythonLibPath = dirname(wx.PythonPath)
         try:
             # Install/update run time libs if necessary
             Utils.updateDir(join(Preferences.pyPath, 'bcrtl'),
@@ -632,13 +685,14 @@ def main(argv=None):
 
     if argv is not None:
         global doDebug, startupfile, startupModules, constricted, emptyEditor, \
-              doDebugSvr, blockSocketServer
+              doDebugSvr, blockSocketServer, wxVersionSelect, unicodeEncoding
         doDebug, startupfile, startupModules, constricted, emptyEditor, \
-              doDebugSvr, blockSocketServer, opts, args = processArgs(argv)
+              doDebugSvr, blockSocketServer, wxVersionSelect, \
+              unicodeEncoding, opts, args = processArgs(argv)
     try:
         app = BoaApp()
     except Exception, error:
-        wxMessageBox(str(error), 'Error on startup')
+        wx.MessageBox(str(error), _('Error on startup'))
         raise
 
     app.MainLoop()
