@@ -6,8 +6,8 @@
 # Author:      Riaan Booysen
 #
 # Created:     1999
-# RCS-ID:      $Id: BaseCompanions.py,v 1.35 2004/08/16 13:16:55 riaan Exp $
-# Copyright:   (c) 1999 - 2004 Riaan Booysen
+# RCS-ID:      $Id: BaseCompanions.py,v 1.43 2007/07/02 15:01:08 riaan Exp $
+# Copyright:   (c) 1999 - 2007 Riaan Booysen
 # Licence:     GPL
 #-------------------------------------------------------------------------------
 
@@ -20,9 +20,10 @@ print 'importing Companions'
 
 import copy
 
-from wxPython.wx import *
+import wx
 
 import Preferences, Utils
+from Utils import _
 
 from PropEdit.PropertyEditors import *
 from Constructors import WindowConstr
@@ -63,13 +64,13 @@ class DesignTimeCompanion(Companion):
     """ Base class for all companions participating in the design-time process.
     """
     handledConstrParams = ()
-    suppressWindowId = false
+    suppressWindowId = False
     def __init__(self, name, designer):
         Companion.__init__(self, name)
         self.parentCompanion = None
         self.designer = designer
         # Design time window id
-        self.dId = wxNewId()
+        self.dId = wx.NewId()
         self.id = None
 
         # Property editors for properties whose types cannot be deduced
@@ -99,15 +100,15 @@ class DesignTimeCompanion(Companion):
         # Run time dict of created collection companions
         self.collections = {}
         # Can't work, remove
-        self.letClickThru = false
+        self.letClickThru = False
         # Mutualy depentent props
         # These props will all be refeshed in the inspector when any one of
         # them is updated
         self.mutualDepProps = []
         # Flag for controls which do not process mouse events correctly
-        self.ctrlDisabled = false
-        self.compositeCtrl = false
-        # 
+        self.ctrlDisabled = False
+        self.compositeCtrl = False
+        #
         self.resourceImports = []
 
         # Parse objects for reading in and writing out source
@@ -313,7 +314,7 @@ class DesignTimeCompanion(Companion):
                     if prop.prop_setter == setterName:
                         return prop.params
                 except:
-                    print 'except in persistprop'
+                    #print 'except in persistprop'
                     raise
         return None
 
@@ -336,23 +337,27 @@ class DesignTimeCompanion(Companion):
                     idx = idx + 1
 
     def propIsDefault(self, name, setterName):
-        """ Returns true if no modification has been made to the property
+        """ Returns True if no modification has been made to the property
             or constructor parameter """
         c = self.constructor()
         #constructor
         if c.has_key(name):
-            dts = self.designTimeSource()
-            if dts.has_key(c[name]):
-                defVal = self.designTimeSource()[c[name]]
-                return self.textConstr.params[c[name]] == defVal
+            try:
+                dts = self.designTimeSource()
+            except TypeError:
+                return True
             else:
-                return true
+                if dts.has_key(c[name]):
+                    defVal = self.designTimeSource()[c[name]]
+                    return self.textConstr.params[c[name]] == defVal
+                else:
+                    return True
         #property
         elif name not in self.dontPersistProps():
             for prop in self.textPropList:
                 if prop.prop_setter == setterName:
-                    return false
-        return true
+                    return False
+        return True
 
     def persistEvt(self, name, value, wId = None):
         """ Add a source entry for an event or update the trigger method of
@@ -361,7 +366,9 @@ class DesignTimeCompanion(Companion):
             if evt.event_name == name:
                 evt.trigger_meth = value
                 return
-        if self.control == self.designer or not isinstance(self.control, wxEvtHandlerPtr): # or wId is not None:
+        if self.control == self.designer or \
+              not isinstance(self.control, wx.EvtHandler) or \
+              isinstance(self.control, wx.Timer):
             comp_name = ''
         else:
             comp_name = self.name
@@ -393,7 +400,7 @@ class DesignTimeCompanion(Companion):
     def SetName(self, oldValue, newValue):
         """ Triggered when the 'Name' property is changed """
         if self.designer.objects.has_key(newValue):
-            wxLogError('There is already an object named '+newValue)
+            wx.LogError(_('There is already an object named %s')%newValue)
         else:
             self.name = newValue
             self.designer.model.renameCtrl(oldValue, newValue)
@@ -431,7 +438,7 @@ class DesignTimeCompanion(Companion):
         try:
             return PaletteMapping.evalCtrl(expr, self.designer.model.specialAttrs)
         except Exception, err:
-            print 'Illegal expression: %s'%expr
+            print _('Illegal expression: %s')%expr
             raise
 
     def defaultAction(self):
@@ -469,7 +476,7 @@ class DesignTimeCompanion(Companion):
     def addContinuedLine(self, line, output, indent):
         if Preferences.cgWrapLines:
             if len(line) > Preferences.cgLineWrapWidth:
-                segs = methodparse.safesplitfields(line, ',', true, (), ())
+                segs = methodparse.safesplitfields(line, ',', True, (), ())
                 line = sourceconst.bodyIndent+segs[0].lstrip()
                 for seg in segs[1:]:
                     newLine = line +', '+ seg
@@ -490,7 +497,7 @@ class DesignTimeCompanion(Companion):
                 sourceconst.bodyIndent+self.textConstr.asText(stripFrmId),
                 output, sourceconst.bodyIndent)
 
-    nullProps = ('None', 'wxNullBitmap', 'wxNullIcon')
+    nullProps = ('None', 'wx.NullBitmap', 'wx.NullIcon')
     def writeProperties(self, output, ctrlName, definedCtrls, deps, depLinks, stripFrmId=''):
         """ Write out property setters but postpone dependent properties.
         """
@@ -511,7 +518,7 @@ class DesignTimeCompanion(Companion):
             definition not defined in source add an empty method declaration to
             the bottom of the class """
         for evt in self.textEventList:
-            if evt.trigger_meth != '(delete)':
+            if evt.trigger_meth != _('(delete)'):
                 self.addContinuedLine(
                       sourceconst.bodyIndent + evt.asText(stripFrmId),
                       output, sourceconst.bodyIndent)
@@ -562,7 +569,7 @@ class NYIDTC(DesignTimeCompanion):
     """ Blank holder for companions which have not been implemented."""
     host = 'Not Implemented'
     def __init__(self, name, designer, parent, ctrlClass):
-        raise 'Not Implemented'
+        raise Exception, _('Not Implemented')
 
 
 class ControlDTC(DesignTimeCompanion):
@@ -578,29 +585,28 @@ class ControlDTC(DesignTimeCompanion):
         self.parent = parent
         self.ctrlClass = ctrlClass
         self.generateWindowId()
-        self.container = false
+        self.container = False
 
 
     def designTimeControl(self, position, size, args = None):
         """ Create and initialise a design-time control """
         if args:
-            self.control = apply(self.ctrlClass, (), args)
+            self.control = self.ctrlClass(**args)
         else:
-            self.control = apply(self.ctrlClass, (),
-                  self.designTimeDefaults(position, size))
+            self.control = self.ctrlClass(**self.designTimeDefaults(position, size))
 
         self.initDesignTimeControl()
         return self.control
 
-    def designTimeDefaults(self, position = wxDefaultPosition,
-                                 size = wxDefaultSize):
+    def designTimeDefaults(self, position = wx.DefaultPosition,
+                                 size = wx.DefaultSize):
         """ Return a dictionary of parameters for the constructor of a wxPython
             control. e.g. {'name': 'Frame1', etc) """
-        if not position: position = wxDefaultPosition
-        if not size: size = wxDefaultSize
+        if not position: position = wx.DefaultPosition
+        if not size: size = wx.DefaultSize
 
-        dts = self.designTimeSource('wxPoint(%s, %s)'%(position.x, position.y),
-          'wxSize(%s, %s)'%(size.x, size.y))
+        dts = self.designTimeSource('wx.Point(%s, %s)'%(position.x, position.y),
+          'wx.Size(%s, %s)'%(size.x, size.y))
 
         for param in dts.keys():
             dts[param] = self.eval(dts[param])
@@ -612,7 +618,7 @@ class ControlDTC(DesignTimeCompanion):
 
         return dts
 
-    def designTimeSource(self, position = 'wxDefaultPosition', size = 'wxDefaultSize'):
+    def designTimeSource(self, position = 'wx.DefaultPosition', size = 'wx.DefaultSize'):
         """ Return a dictionary of parameters for the constructor of a wxPython
             control's source. 'parent' and 'id' handled automatically
         """
@@ -621,7 +627,7 @@ class ControlDTC(DesignTimeCompanion):
     def generateWindowId(self):
         if self.designer:
             self.id = Utils.windowIdentifier(self.designer.GetName(), self.name)
-        else: self.id = `wxNewId()`
+        else: self.id = `wx.NewId()`
 
     def SetName(self, oldValue, newValue):
         DesignTimeCompanion.SetName(self, oldValue, newValue)
@@ -664,8 +670,8 @@ class ControlDTC(DesignTimeCompanion):
                     ctrl._composite_child = 1
             self.control.SetToolTipString(self.name)
             # Disabled controls do not pass thru mouse clicks to their parents on GTK :(
-            if wxPlatform != '__WXGTK__' and self.ctrlDisabled:
-                self.control.Enable(false)
+            if wx.Platform != '__WXGTK__' and self.ctrlDisabled:
+                self.control.Enable(False)
         except:
             pass
 
@@ -673,11 +679,11 @@ class ControlDTC(DesignTimeCompanion):
 
         self.popx = self.popy = 0
 
-        EVT_RIGHT_DOWN(self.control, self.designer.OnRightDown)
+        self.control.Bind(wx.EVT_RIGHT_DOWN, self.designer.OnRightDown)
         # for wxMSW
 #        EVT_COMMAND_RIGHT_CLICK(self.control, -1, self.designer.OnRightClick)
         # for wxGTK
-        EVT_RIGHT_UP(self.control, self.designer.OnRightClick)
+        self.control.Bind(wx.EVT_RIGHT_UP, self.designer.OnRightClick)
 
     def beforeResize(self):
         pass
@@ -692,11 +698,11 @@ class ControlDTC(DesignTimeCompanion):
               and self.textConstr.params.has_key('size'):
             pos = self.control.GetPosition()
             size = self.control.GetSize()
-            self.textConstr.params['pos'] = 'wxPoint(%d, %d)' % (pos.x, pos.y)
-            self.textConstr.params['size'] = 'wxSize(%d, %d)' % (size.x, size.y)
+            self.textConstr.params['pos'] = 'wx.Point(%d, %d)' % (pos.x, pos.y)
+            self.textConstr.params['size'] = 'wx.Size(%d, %d)' % (size.x, size.y)
 
     def getDefCtrlSize(self):
-        return 'wxSize(%d, %d)'%(Preferences.dsDefaultControlSize.x,
+        return 'wx.Size(%d, %d)'%(Preferences.dsDefaultControlSize.x,
                                  Preferences.dsDefaultControlSize.y)
 
 
@@ -773,9 +779,9 @@ class UtilityDTC(DesignTimeCompanion):
 
     def designTimeObject(self, args = None):
         if args:
-            self.control = apply(self.objClass, (), args)
+            self.control = self.objClass(**args)
         else:
-            self.control = apply(self.objClass, (), self.designTimeDefaults())
+            self.control = self.objClass(**self.designTimeDefaults())
 
         return self.control
 
@@ -817,35 +823,50 @@ class WindowDTC(WindowConstr, ControlDTC):
                         'Cursor': CursorClassLinkPropEdit,
                         'Centered': EnumPropEdit,
                         'ThemeEnabled': BoolPropEdit,
+                        'WindowVariant': EnumPropEdit,
+                        'BackgroundStyle': EnumPropEdit,
                         })
-        self.options['Centered'] = [None, wxHORIZONTAL, wxVERTICAL, wxBOTH]
-        self.names['Centered'] = {'None': None, 'wxHORIZONTAL': wxHORIZONTAL,
-                                  'wxVERTICAL': wxVERTICAL, 'wxBOTH': wxBOTH}
+        self.options['Centered'] = [None, wx.HORIZONTAL, wx.VERTICAL, wx.BOTH]
+        self.names['Centered'] = {'None': None, 'wx.HORIZONTAL': wx.HORIZONTAL,
+                                  'wx.VERTICAL': wx.VERTICAL, 'wx.BOTH': wx.BOTH}
+        self.options['WindowVariant'] = [wx.WINDOW_VARIANT_NORMAL, 
+              wx.WINDOW_VARIANT_SMALL, wx.WINDOW_VARIANT_MINI, 
+              wx.WINDOW_VARIANT_LARGE]
+        self.names['WindowVariant'] = {
+            'wx.WINDOW_VARIANT_NORMAL': wx.WINDOW_VARIANT_NORMAL, 
+            'wx.WINDOW_VARIANT_SMALL':  wx.WINDOW_VARIANT_SMALL, 
+            'wx.WINDOW_VARIANT_MINI': wx.WINDOW_VARIANT_MINI, 
+            'wx.WINDOW_VARIANT_LARGE': wx.WINDOW_VARIANT_LARGE}
+        self.options['BackgroundStyle'] = [wx.BG_STYLE_SYSTEM, 
+              wx.BG_STYLE_COLOUR, wx.BG_STYLE_CUSTOM]
+        self.names['BackgroundStyle'] = {
+            'wx.BG_STYLE_SYSTEM': wx.BG_STYLE_SYSTEM, 
+            'wx.BG_STYLE_COLOUR': wx.BG_STYLE_COLOUR, 
+            'wx.BG_STYLE_CUSTOM': wx.BG_STYLE_CUSTOM}
         self.triggers.update({'Size'     : self.SizeUpdate,
                               'Position' : self.PositionUpdate})
         self.customPropEvaluators.update({'Constraints': self.EvalConstraints,
                                           'SizeHints': self.EvalSizeHints,})
 
-        self.windowStyles = ['wxCAPTION', 'wxMINIMIZE_BOX', 'wxMAXIMIZE_BOX',
-                             'wxTHICK_FRAME', 'wxSIMPLE_BORDER', 'wxDOUBLE_BORDER',
-                             'wxSUNKEN_BORDER', 'wxRAISED_BORDER',
-                             'wxSTATIC_BORDER', 'wxTRANSPARENT_WINDOW', 'wxNO_3D',
-                             'wxTAB_TRAVERSAL', 'wxWANTS_CHARS',
-                             'wxNO_FULL_REPAINT_ON_RESIZE', 'wxVSCROLL', 'wxHSCROLL',
-                             'wxCLIP_CHILDREN', 'wxNO_BORDER']
-
+        self.windowStyles = ['wx.CAPTION', 'wx.MINIMIZE_BOX', 'wx.MAXIMIZE_BOX',
+            'wx.THICK_FRAME', 'wx.SIMPLE_BORDER', 'wx.DOUBLE_BORDER',
+            'wx.SUNKEN_BORDER', 'wx.RAISED_BORDER', 'wx.STATIC_BORDER', 
+            'wx.TRANSPARENT_WINDOW', 'wx.NO_3D', 'wx.TAB_TRAVERSAL', 
+            'wx.WANTS_CHARS', 'wx.NO_FULL_REPAINT_ON_RESIZE', 'wx.VSCROLL', 
+            'wx.HSCROLL', 'wx.CLIP_CHILDREN', 'wx.NO_BORDER', 'wx.ALWAYS_SHOW_SB']
+        
         self.mutualDepProps = ['Value', 'Title', 'Label']
 
         #import UtilCompanions
         #self.subCompanions['Constraints'] = UtilCompanions.IndividualLayoutConstraintOCDTC
         #self.subCompanions['SizeHints'] = UtilCompanions.SizeHintsDTC
         self.anchorSettings = []
-        self._applyConstraints = false
+        self._applyConstraints = False
         self.initPropsThruCompanion = ['SizeHints', 'Cursor', 'Center', 'Sizer']
         self._sizeHints = (-1, -1, -1, -1)
-        self._cursor = wxNullCursor
+        self._cursor = wx.NullCursor
         self._centered = None
-        
+
     def properties(self):
         return {'Shown': ('CompnRoute', self.GetShown, self.Show),
                 'Enabled': ('CompnRoute', self.GetEnabled, self.Enable),
@@ -857,7 +878,7 @@ class WindowDTC(WindowConstr, ControlDTC):
                 'Sizer': ('CompnRoute', self.GetSizer, self.SetSizer),
                 }
 
-    def designTimeSource(self, position = 'wxDefaultPosition', size = 'wxDefaultSize'):
+    def designTimeSource(self, position = 'wx.DefaultPosition', size = 'wx.DefaultSize'):
         return {'pos':  position,
                 'size': self.getDefCtrlSize(),
                 'name': `self.name`,
@@ -873,7 +894,9 @@ class WindowDTC(WindowConstr, ControlDTC):
         return ['NextHandler', 'PreviousHandler', 'EventHandler', 'EvtHandlerEnabled',
                 'Id', 'Caret', 'WindowStyleFlag', 'ToolTip', 'Title', 'Rect',
                 'DragTarget', 'DropTarget', 'Cursor', 'VirtualSize', 'Sizer',
-                'ContainingSizer', 'Constraints', 'DefaultItem', 'Validator']
+                'ContainingSizer', 'Constraints', 'DefaultItem', 'Validator',
+                'WindowStyle', 'AcceleratorTable', 'ClientRect', 'ExtraStyle',
+                'LayoutDirection']
 
     def dontPersistProps(self):
         return ControlDTC.dontPersistProps(self) + ['ClientSize']
@@ -886,7 +909,7 @@ class WindowDTC(WindowConstr, ControlDTC):
         if action == 'delete':
             if self._cursor and `self._cursor` == `compn.control`:
                 self.propRevertToDefault('Cursor', 'SetCursor')
-                self.SetCursor(wxNullCursor)
+                self.SetCursor(wx.NullCursor)
         # XXX sizer
 
     def persistProp(self, name, setterName, value):
@@ -912,7 +935,7 @@ class WindowDTC(WindowConstr, ControlDTC):
                         else:
                             prop.params = [value]
                         return
-                
+
                 if value != 'None':
                     sizerList.append(methodparse.PropertyParse(
                           None, self.getCompName(), setterName, [value], name))
@@ -925,11 +948,11 @@ class WindowDTC(WindowConstr, ControlDTC):
             if scl:
                 for connProp in self.designer.getSizerConnectList():
                     if connProp.comp_name == self.getCompName():
-                        return false
-            return true
+                        return False
+            return True
         else:
             return ControlDTC.propIsDefault(self, propName, setterName)
-        
+
 #---ToolTips--------------------------------------------------------------------
     def GetToolTipString(self, blah):
         return self.control.GetToolTip().GetTip()
@@ -938,19 +961,19 @@ class WindowDTC(WindowConstr, ControlDTC):
         self.control.SetToolTipString(value)
 
 #---Anchors---------------------------------------------------------------------
-    from wxPython.lib.anchors import LayoutAnchors
+    from wx.lib.anchors import LayoutAnchors
 
     def writeImports(self):
         imports = ControlDTC.writeImports(self)
         if self.anchorSettings:
-            return '\n'.join( (imports, 
-                   'from wxPython.lib.anchors import LayoutAnchors') )
+            return '\n'.join( (imports,
+                   'from wx.lib.anchors import LayoutAnchors') )
         else:
             return imports
 
     def GetAnchors(self, compn):
         if self.anchorSettings:
-            return apply(self.LayoutAnchors, [self.control] + self.anchorSettings)
+            return self.LayoutAnchors(*([self.control] + self.anchorSettings))
         else:
             return None
 
@@ -997,7 +1020,7 @@ class WindowDTC(WindowConstr, ControlDTC):
                 idx = idx + 1
 
     def defaultAnchors(self):
-        self.anchorSettings = [true, true, false, false]
+        self.anchorSettings = [True, True, False, False]
 
     def applyConstraints(self):
         left, top, right, bottom = self.anchorSettings
@@ -1027,23 +1050,23 @@ class WindowDTC(WindowConstr, ControlDTC):
                             #self.designer.sizersView.layoutSizers()
                             parent = self.control.GetParent()
                             if parent:
-                                wxPostEvent(parent, wxSizeEvent(
+                                wx.PostEvent(parent, wx.SizeEvent(
                                     parent.GetSize(), parent.GetId()))
-                                wxCallAfter(parent.Refresh)#relayoutCtrl(self.designer)
+                                wx.CallAfter(parent.Refresh)#relayoutCtrl(self.designer)
                             #self.designer.model.editor.setStatus('Sizer item update %s, %s'%(p, s))
                             break
-        
+
 
 #---Designer updaters-----------------------------------------------------------
     def SizeUpdate(self, oldValue, newValue):
         if self.designer.selection:
             self.designer.selection.selectCtrl(self.control, self)
-            self.designer.selection.moveCapture(self.control, self, wxPoint(0, 0))
+            self.designer.selection.moveCapture(self.control, self, wx.Point(0, 0))
 
     def PositionUpdate(self, oldValue, newValue):
         if self.designer.selection:
             self.designer.selection.selectCtrl(self.control, self)
-            self.designer.selection.moveCapture(self.control, self, wxPoint(0, 0))
+            self.designer.selection.moveCapture(self.control, self, wx.Point(0, 0))
 
 #---Size hints------------------------------------------------------------------
     def GetSizeHints(self, dummy):
@@ -1101,7 +1124,7 @@ class WindowDTC(WindowConstr, ControlDTC):
             if prop.prop_setter == 'Show':
                 return int(prop.params[0].lower() == 'true')
         return 1
-    
+
     def Show(self, value):
         pass
 
@@ -1110,7 +1133,7 @@ class WindowDTC(WindowConstr, ControlDTC):
             if prop.prop_setter == 'Enable':
                 return int(prop.params[0].lower() == 'true')
         return 1
-    
+
     def Enable(self, value):
         pass
 
@@ -1124,7 +1147,7 @@ class ContainerDTC(WindowDTC):
     """ Parent for controls that contain/own other controls """
     def __init__(self, name, designer, parent, ctrlClass):
         WindowDTC.__init__(self, name, designer, parent, ctrlClass)
-        self.container = true
+        self.container = True
 
 class CollectionDTC(DesignTimeCompanion):
     """ Companions encapsulating list maintaining behaviour into a single
@@ -1139,7 +1162,7 @@ class CollectionDTC(DesignTimeCompanion):
     displayProp = 'undefined'
     indexProp = 'undefined'
     sourceObjName = 'parent'
-    
+
     additionalMethods = {}
 
     def __init__(self, name, designer, parentCompanion, ctrl):
@@ -1204,12 +1227,14 @@ class CollectionDTC(DesignTimeCompanion):
         """ When overriding, append this before derived finaliser """
         return []
 
-    def appendItem(self, method=None):
+    def appendItem(self, method=None, srcParams={}):
         self.index = self.getCount()
         if method is None:
             method = self.insertionMethod
+        src = self.designTimeSource(self.index, method)        
+        src.update(srcParams)
         collItemInit = methodparse.CollectionItemInitParse(None,
-          self.sourceObjName, method, self.designTimeSource(self.index, method))
+          self.sourceObjName, method, src)
 
         self.textConstrLst.append(collItemInit)
         self.setConstr(collItemInit)
@@ -1222,7 +1247,7 @@ class CollectionDTC(DesignTimeCompanion):
         # remove from ctrl
         if self.deletionMethod != '(None)':
             getattr(self.control, self.deletionMethod)(idx)
-        
+
         # renumber items following deleted one
         if self.indexProp != '(None)':
             for constr in self.textConstrLst[idx:]:
@@ -1238,17 +1263,16 @@ class CollectionDTC(DesignTimeCompanion):
 
             if self.indexProp != '(None)':
                 # swap index property values
-                (self.textConstrLst[idx].params[self.indexProp], 
+                (self.textConstrLst[idx].params[self.indexProp],
                  self.textConstrLst[newIdx].params[self.indexProp]) = \
-                (self.textConstrLst[newIdx].params[self.indexProp], 
+                (self.textConstrLst[newIdx].params[self.indexProp],
                  self.textConstrLst[idx].params[self.indexProp])
-        
+
         return newIdx
 
     def applyDesignTimeDefaults(self, params, method=None):
         if method is None:
             method = self.insertionMethod
-        #apply(getattr(self.control, method), (), self.designTimeDefaults(params, method))
         args = []
         kwargs = {}
         paramItems = self.designTimeDefaults(params, method).items()
@@ -1258,9 +1282,7 @@ class CollectionDTC(DesignTimeCompanion):
                 args.append(v)
             else:
                 kwargs[k] = v
-        #print args, kwargs
         getattr(self.control, method)(*args, **kwargs)
-        #, self.designTimeDefaults(params, method))
 
     def SetName(self, oldValue, newValue):
         self.name = newValue
@@ -1408,8 +1430,8 @@ class CollectionIddDTC(CollectionDTC):
     def isIdUsed(self, wId):
         for tc in self.textConstrLst:
             if tc.params.has_key(self.idProp) and tc.params[self.idProp] == wId:
-                return true
-        return false
+                return True
+        return False
 
 
     def newWinId(self, itemName):
@@ -1461,14 +1483,14 @@ class CollectionIddDTC(CollectionDTC):
 
     def designTimeDefaults(self, vals, method=None):
         """ Return a dictionary of parameters for the constructor of a wxPython
-            control. e.g. {'name': 'button1', etc) 
-            
+            control. e.g. {'name': 'button1', etc)
+
             Derived classes should only call this base method if method
             requires an id parameter. This is usually the case."""
         values = copy.copy(vals)
-        values[self.idProp] = `wxNewId()`
+        values[self.idProp] = `wx.NewId()`
         dts = CollectionDTC.designTimeDefaults(self, values)
-        dts[self.idProp] = wxNewId()
+        dts[self.idProp] = wx.NewId()
         return dts
 
     def GetItemId(self, x):
