@@ -5,8 +5,8 @@
 # Author:      Riaan Booysen
 #
 # Created:     2003
-# RCS-ID:      $Id: SizerCompanions.py,v 1.5 2004/08/16 13:16:56 riaan Exp $
-# Copyright:   (c) 2003 - 2004
+# RCS-ID:      $Id: SizerCompanions.py,v 1.17 2007/07/02 15:01:09 riaan Exp $
+# Copyright:   (c) 2003 - 2007
 # Licence:     GPL
 #-----------------------------------------------------------------------------
 
@@ -14,35 +14,40 @@ print 'importing Companions.SizerCompanions'
 
 # XXX _in_sizer is not necessary, use GetContainingSizer() instead
 
-import os, copy
+import os, sys, copy
 
-from wxPython.wx import *
+import wx
 
-from wxPython.lib.rcsizer import RowColSizer
+#from wx.lib.rcsizer import RowColSizer
 
 import Preferences, Utils
+from Utils import _
 
-from BaseCompanions import UtilityDTC, CollectionDTC, CollectionIddDTC, wxNullBitmap, NYIDTC
+from BaseCompanions import UtilityDTC, CollectionDTC, CollectionIddDTC, NYIDTC, HelperDTC
 import Companions
 
 from PropEdit.PropertyEditors import IntConstrPropEdit, StrConstrPropEdit, \
       CollectionPropEdit, ObjEnumConstrPropEdit, EnumConstrPropEdit, \
       FlagsConstrPropEdit, WinEnumConstrPropEdit, BoolConstrPropEdit, \
       BoolPropEdit, EnumPropEdit, ReadOnlyConstrPropEdit, \
-      SizerEnumConstrPropEdit
+      SizerEnumConstrPropEdit, SizeConstrPropEdit, ConstrPropEdit, \
+      IntPropEdit, esExpandable
+
+from PropEdit.InspectorEditorControls import TextCtrlIEC
+from PropEdit.FlexGridGrowablesDlg import FlexGridGrowablesDlg
+
 from PropEdit import Enumerations
 import EventCollections, RTTI, methodparse
-import PaletteStore
 
 
 class SizerItemsColPropEdit(CollectionPropEdit): pass
 
-class BlankSizer(wxBoxSizer):
+class BlankSizer(wx.BoxSizer):
     """ Used as a placeholder for initial sizer items which has None for
         the window or sizer """
     def __init__(self):
-        wxBoxSizer.__init__(self, wxVERTICAL)
-        self.AddSpacer(24, 24)
+        wx.BoxSizer.__init__(self, wx.VERTICAL)
+        self.AddSpacer((24, 24))
 
 class SizerDTC(UtilityDTC):
     host = 'Sizers'
@@ -100,7 +105,7 @@ class SizerFlagsConstrPropEdit(FlagsConstrPropEdit):
 class SizerWinEnumConstrPropEdit(ObjEnumConstrPropEdit):
     def getObjects(self):
         designer = self.companion.designer.controllerView
-        windows = designer.getObjectsOfClass(wxWindowPtr)
+        windows = designer.getObjectsOfClass(wx.Window)
         for n, w in windows.items():
             if hasattr(w, '_in_sizer') or n == 'self':
                 del windows[n]
@@ -123,10 +128,11 @@ class SizerItemsCDTC(CollectionDTC):
     displayProp = 0
     indexProp = '(None)'
     insertionMethod = 'AddWindow'
-    deletionMethod = 'RemovePos'
+    deletionMethod = 'Remove'
 
-    additionalMethods = { 'AddSizer': ('Add sizer', 0, '(None)'),
-                          'AddSpacer': ('Add spacer', '', '(None)')
+    additionalMethods = { 'AddSizer': (_('Add sizer'), 0, '(None)'),
+                          'AddSpacer': (_('Add spacer'), '', '(None)'),
+                          #'AddStretchSpacer': ('Add stretch spacer', '', '(None)')
                         }
 
     def __init__(self, name, designer, parentCompanion, ctrl):
@@ -136,15 +142,14 @@ class SizerItemsCDTC(CollectionDTC):
                         'Proportion': IntConstrPropEdit,
                         'Flag': SizerFlagsConstrPropEdit,
                         'Border': IntConstrPropEdit,
-                        'Width': IntConstrPropEdit,
-                        'Height': IntConstrPropEdit,
+                        'Size': SizeConstrPropEdit,
                        }
-        self.windowStyles = ['wxLEFT', 'wxRIGHT', 'wxTOP', 'wxBOTTOM', 'wxALL',
-                             'wxSHRINK', 'wxGROW', 'wxEXPAND', 'wxSHAPED',
-                             'wxALIGN_LEFT', 'wxALIGN_CENTER_HORIZONTAL',
-                             'wxALIGN_RIGHT', 'wxALIGN_BOTTOM',
-                             'wxALIGN_CENTER_VERTICAL', 'wxALIGN_TOP',
-                             'wxALIGN_CENTER', 'wxADJUST_MINSIZE']
+        self.windowStyles = ['wx.LEFT', 'wx.RIGHT', 'wx.TOP', 'wx.BOTTOM', 'wx.ALL',
+                             'wx.SHRINK', 'wx.GROW', 'wx.EXPAND', 'wx.SHAPED',
+                             'wx.ALIGN_LEFT', 'wx.ALIGN_CENTER_HORIZONTAL',
+                             'wx.ALIGN_RIGHT', 'wx.ALIGN_BOTTOM',
+                             'wx.ALIGN_CENTER_VERTICAL', 'wx.ALIGN_TOP',
+                             'wx.ALIGN_CENTER', 'wx.ADJUST_MINSIZE']
 
     def constructor(self):
         tcl = self.textConstrLst[self.index]
@@ -155,8 +160,10 @@ class SizerItemsCDTC(CollectionDTC):
             return {'Sizer': 0, 'Proportion': 1, 'Flag': 'flag',
                     'Border': 'border'}
         elif tcl.method == 'AddSpacer':
-            return {'Width': 0, 'Height': 1, 'Flag': 'flag',
+            return {'Size': 0, 'Flag': 'flag',
                     'Border': 'border'}
+        #elif tcl.method == 'AddStretchSpacer':
+        #    return {'Proportion': 0}
 
     def designTimeSource(self, wId, method=None):
         if method is None:
@@ -167,7 +174,9 @@ class SizerItemsCDTC(CollectionDTC):
         elif method == 'AddSizer':
             return {0: 'None', 1: '0', 'flag': '0', 'border': '0'}
         elif method == 'AddSpacer':
-            return {0:  '8',   1: '8', 'flag': '0', 'border': '0'}
+            return {0: 'wx.Size(8, 8)', 'flag': '0', 'border': '0'}
+        #elif method == 'AddStretchSpacer':
+        #    return {0: '1'}
 
     def notification(self, compn, action):
         if action == 'delete':
@@ -179,14 +188,17 @@ class SizerItemsCDTC(CollectionDTC):
                         self.recreateSizers()
                         return
 
-    def appendItem(self, method=None):
-        CollectionDTC.appendItem(self, method)
-        self.updateGUI()
+    def appendItem(self, method=None, srcParams={}):
+        CollectionDTC.appendItem(self, method, srcParams)
+        
+        self.recreateSizers()
+        #self.updateGUI()
 
     def deleteItem(self, idx):
         CollectionDTC.deleteItem(self, idx)
         del self.textConstrLst[idx]
-        self.updateGUI()
+        self.recreateSizers()
+        #self.updateGUI()
 
     def moveItem(self, idx, dir):
         newIdx = CollectionDTC.moveItem(self, idx, dir)
@@ -201,22 +213,22 @@ class SizerItemsCDTC(CollectionDTC):
                 name = Utils.ctrlNameFromSrcRef(constr.params[0])
                 designer = self.designer.controllerView
                 compn, ctrl = designer.objects[name][:2]
-                designer.inspector.selectObject(compn, true)
+                designer.inspector.selectObject(compn, True)
                 designer.Raise()
                 designer.selection.selectCtrl(ctrl, compn)
 
-                wxCallAfter(designer.SetFocus)
-                return true
+                wx.CallAfter(designer.SetFocus)
+                return True
 
         elif constr.method == 'AddSizer':
             if constr.params[0] != 'None':
                 name = Utils.ctrlNameFromSrcRef(constr.params[0])
                 compn = self.designer.objects[name][0]
-                self.designer.inspector.selectObject(compn, true)
+                self.designer.inspector.selectObject(compn, True)
                 self.designer.selectCtrls([name])
 
-                wxCallAfter(self.designer.SetFocus)
-                return true
+                wx.CallAfter(self.designer.SetFocus)
+                return True
 
     def designTimeDefaults(self, vals, method=None):
         if method is None:
@@ -273,7 +285,7 @@ class SizerItemsCDTC(CollectionDTC):
         colEdKey = (self.parentCompanion.name, 'Items')
         if self.designer.collEditors.has_key(colEdKey):
             collEditView = self.designer.collEditors[colEdKey]
-            wxCallAfter(self.setWindowRefresh, collEditView)
+            wx.CallAfter(self.setWindowRefresh, collEditView)
 
     def setWindowRefresh(self, collEditView):
         collEditView.refreshCtrl(1)
@@ -287,11 +299,9 @@ class SizerItemsCDTC(CollectionDTC):
 
     def persistProp(self, name, setterName, value):
         CollectionDTC.persistProp(self, name, setterName, value)
-        if name in ('Width', 'Height'):
+        if name in ('Size',):
             self.recreateSizers()
         elif name in ('Flag', 'Border', 'Proportion'):
-            if name == 'Proportion':
-                name = 'Option'
             si = self.control.GetChildren()[self.index]
             getattr(si, 'Set'+name)(self.eval(value))
             self.updateGUI()
@@ -301,35 +311,35 @@ class SizerItemsCDTC(CollectionDTC):
         warn = 0
         for constr in self.textConstrLst:
             if constr.params[0] == 'None':
-                wxLogWarning('No control/sizer for sizer item of %s'%(
+                wx.LogWarning(_('No control/sizer for sizer item of %s')%(
                       self.parentCompanion.name))
                 warn = 1
         if warn:
-            wxLogWarning('None values are only valid in the Designer.\n'
-                         'The generated source will be invalid outside the '
-                         'Designer and should be fixed before executing.')
-
+            wx.LogWarning(_('None values are only valid in the Designer.\n'
+                            'The generated source will be invalid outside the '
+                            'Designer and should be fixed before executing.'))
+  
     def recreateSizers(self):
         self.designer.recreateSizers()
         self.updateGUI()
 
     def updateGUI(self):
         self.control.Layout()
-        wxCallAfter(self.designer.controllerView.Refresh)
+        wx.CallAfter(self.designer.controllerView.Refresh)
 
 class BoxSizerDTC(SizerDTC):
     def __init__(self, name, designer, objClass):
         SizerDTC.__init__(self, name, designer, objClass)
         self.editors['Orientation'] = EnumPropEdit
-        self.names['Orientation'] = {'wxVERTICAL': wxVERTICAL,
-                                     'wxHORIZONTAL': wxHORIZONTAL}
-        self.options['Orientation'] = [wxVERTICAL, wxHORIZONTAL]
+        self.names['Orientation'] = {'wx.VERTICAL': wx.VERTICAL,
+                                     'wx.HORIZONTAL': wx.HORIZONTAL}
+        self.options['Orientation'] = [wx.VERTICAL, wx.HORIZONTAL]
 
     def constructor(self):
         return {'Name': 'name', 'Orientation': 'orient'}
 
     def designTimeSource(self):
-        return {'orient': 'wxVERTICAL'}
+        return {'orient': 'wx.VERTICAL'}
 
 class GridSizerDTC(SizerDTC):
     def constructor(self):
@@ -343,21 +353,20 @@ class GridSizerDTC(SizerDTC):
 class GrowablesColPropEdit(CollectionPropEdit):
     def edit(self, event):
         ce = self.companion.designer.showCollectionEditor(self.companion.name,
-              self.name, false)
+              self.name, False)
 
         growableRows, growableCols = ce.companion.getGrowables()
 
         fgsCompn = ce.companion.parentCompanion
-        numRows = self.companion.eval(fgsCompn.textConstr.params['rows'])
-        numCols = self.companion.eval(fgsCompn.textConstr.params['cols'])
+        numRows, numCols = fgsCompn.getNumRowsCols(ce.companion)
 
         if not numRows and not numCols:
-            wxLogError('Rows and Cols may not both be 0')
+            wx.LogError(_('Rows and Cols may not both be 0'))
             return
 
         if not numRows or not numCols:
             numItems = len(self.companion.designer.showCollectionEditor(
-                self.companion.name, 'Items', false).companion.textConstrLst)
+                self.companion.name, 'Items', False).companion.textConstrLst)
         else:
             numItems = -1
 
@@ -374,13 +383,12 @@ class GrowablesColPropEdit(CollectionPropEdit):
         for col in range(numCols):
             cols.append(col in growableCols)
 
-        from FlexGridGrowableDlg import FlexGridGrowablesDlg
         dlg = FlexGridGrowablesDlg(self.parent, rows, cols)
         try:
             res = dlg.ShowModal()
-            if res == wxID_CANCEL:
+            if res == wx.ID_CANCEL:
                 return
-            if res == wxID_YES:
+            if res == wx.ID_YES:
                 ce.show()
                 return
 
@@ -438,7 +446,7 @@ class GrowablesCDTC(CollectionDTC):
         for idx, row in zip(range(len(rows)), rows):
             if row:
                 self._appendItem('AddGrowableRow', idx)
-        for idx, col in zip(range(len(rows)), cols):
+        for idx, col in zip(range(len(cols)), cols):
             if col:
                 self._appendItem('AddGrowableCol', idx)
 
@@ -448,7 +456,7 @@ class GrowablesCDTC(CollectionDTC):
 
     def updateGUI(self):
         self.control.Layout()
-        wxCallAfter(self.designer.controllerView.Refresh)
+        wx.CallAfter(self.designer.controllerView.Refresh)
 
 
 class FlexGridSizerDTC(GridSizerDTC):
@@ -457,6 +465,20 @@ class FlexGridSizerDTC(GridSizerDTC):
         self.editors['Growables'] = GrowablesColPropEdit
         self.subCompanions['Growables'] = GrowablesCDTC
 
+        self.editors['FlexibleDirection'] = EnumPropEdit
+        self.names['FlexibleDirection'] = {'wx.VERTICAL': wx.VERTICAL,
+                                     'wx.HORIZONTAL': wx.HORIZONTAL,
+                                     'wx.BOTH': wx.BOTH}
+        self.options['FlexibleDirection'] = [wx.VERTICAL, wx.HORIZONTAL, wx.BOTH]
+
+        self.editors['NonFlexibleGrowMode'] = EnumPropEdit
+        self.names['NonFlexibleGrowMode'] = {'wx.FLEX_GROWMODE_NONE': wx.FLEX_GROWMODE_NONE,
+              'wx.FLEX_GROWMODE_SPECIFIED': wx.FLEX_GROWMODE_SPECIFIED,
+              'wx.FLEX_GROWMODE_ALL': wx.FLEX_GROWMODE_ALL}
+        self.options['NonFlexibleGrowMode'] = [wx.FLEX_GROWMODE_NONE, 
+                                               wx.FLEX_GROWMODE_SPECIFIED,
+                                               wx.FLEX_GROWMODE_ALL]
+
     def properties(self):
         props = GridSizerDTC.properties(self)
         props.update({'Growables': ('NoneRoute', None, None)})
@@ -465,10 +487,16 @@ class FlexGridSizerDTC(GridSizerDTC):
     def dependentProps(self):
         return GridSizerDTC.dependentProps(self) + ['Growables']
 
-class RowColSizerDTC(FlexGridSizerDTC):
-    def writeImports(self):
-        return '\n'.join( (GridSizerDTC.writeImports(self),
-                           'from wxPython.lib.rcsizer import RowColSizer') )
+    def getNumRowsCols(self, childCompanion):
+        numRows = self.eval(self.textConstr.params['rows'])
+        numCols = self.eval(self.textConstr.params['cols'])
+        
+        return numRows, numCols
+
+#class RowColSizerDTC(FlexGridSizerDTC):
+#    def writeImports(self):
+#        return '\n'.join( (GridSizerDTC.writeImports(self),
+#                           'from wx.lib.rcsizer import RowColSizer') )
 
 class ControlLinkedSizerDTC(SizerDTC):
     LinkClass = None
@@ -476,24 +504,24 @@ class ControlLinkedSizerDTC(SizerDTC):
     _linkName = ''
     def designTimeObject(self, args = None):
         if args is not None:
-            self.control = apply(self.objClass, (), args)
+            self.control = self.objClass(**args)
         else:
             linkClassName = self.LinkClass.__name__[:-3]
             dtd = self.designTimeDefaults()
             linkObjs = self.designer.controllerView.getObjectsOfClass(self.LinkClass).items()
             if not linkObjs:
-                raise Exception, 'No %s controls available'%linkClassName
+                raise Exception, _('No %s controls available')%linkClassName
 
             linkObjs.sort()
             names, objs = [], []
             for name, obj in linkObjs:
                 names.append(name); objs.append(obj)
 
-            dlg = wxSingleChoiceDialog(self.designer, 'Choose control',
-                  'Create sizer', names)
+            dlg = wx.SingleChoiceDialog(self.designer, _('Choose control'),
+                  _('Create sizer'), names)
             try:
-                if dlg.ShowModal() != wxID_OK:
-                    raise Exception, 'Must choose control to link with sizer'
+                if dlg.ShowModal() != wx.ID_OK:
+                    raise Exception, _('Must choose a control to link with sizer')
                 idx = dlg.GetSelection()
             finally:
                 dlg.Destroy()
@@ -501,7 +529,7 @@ class ControlLinkedSizerDTC(SizerDTC):
             self._linkName = names[idx]
             dtd[self.ctrlParam] = objs[idx]
 
-            self.control = apply(self.objClass, (), dtd)
+            self.control = self.objClass(**dtd)
 
         return self.control
 
@@ -524,55 +552,253 @@ class ControlLinkedSizerDTC(SizerDTC):
 
 
 class StaticBoxSizerDTC(ControlLinkedSizerDTC):
-    LinkClass = wxStaticBoxPtr
+    LinkClass = wx.StaticBox
     ctrlParam = 'box'
     def __init__(self, name, designer, objClass):
         ControlLinkedSizerDTC.__init__(self, name, designer, objClass)
         self.editors['Orientation'] = EnumPropEdit
-        self.names['Orientation'] = {'wxVERTICAL': wxVERTICAL,
-                                     'wxHORIZONTAL': wxHORIZONTAL}
-        self.options['Orientation'] = [wxVERTICAL, wxHORIZONTAL]
+        self.names['Orientation'] = {'wx.VERTICAL': wx.VERTICAL,
+                                     'wx.HORIZONTAL': wx.HORIZONTAL}
+        self.options['Orientation'] = [wx.VERTICAL, wx.HORIZONTAL]
         self.editors['StaticBox'] = ReadOnlyConstrPropEdit
+        
+        self._staticBoxParent = None
+        self._staticBoxLabel = ''
+        self._staticBoxName = wx.StaticBoxNameStr
 
     def constructor(self):
         return {'Name': 'name', 'StaticBox': 'box', 'Orientation': 'orient'}
 
     def designTimeSource(self):
-        return {'box': 'None', 'orient': 'wxVERTICAL'}
+        return {'box': 'None', 'orient': 'wx.VERTICAL'}
+
+    def designTimeObject(self, args = None):
+        if args and 'box' in args:
+            b = args['box']
+            if b is not None:
+                if not b: # deleted static box
+                    args['box'] = wx.StaticBox(self._staticBoxParent, -1, 
+                          self._staticBoxLabel, name=self._staticBoxName)
+                else:
+                    self._staticBoxParent = b.GetParent()
+                    self._staticBoxLabel = b.GetLabel()
+                    self._staticBoxName = b.GetName()
+                
+        return ControlLinkedSizerDTC.designTimeObject(self, args)
 
 
+##class NotebookSizerDTC(ControlLinkedSizerDTC):
+##    LinkClass = wx.Notebook
+##    ctrlParam = 'nb'
+##    def __init__(self, name, designer, objClass):
+##        ControlLinkedSizerDTC.__init__(self, name, designer, objClass)
+##        self.editors['Notebook'] = ReadOnlyConstrPropEdit
+##
+##    def constructor(self):
+##        return {'Name': 'name', 'Notebook': 'nb'}
+##
+##    def designTimeSource(self):
+##        wx.LogWarning('wx.NotebookSizer no longer needed, please remove from source. Support will be removed.')
+##        return {'nb': 'None'}
+##
+##    def properties(self):
+##        props = ControlLinkedSizerDTC.properties(self)
+##        del props['Items']
+##        return props
+##
+##    def defaultAction(self):
+##        pass
 
-class NotebookSizerDTC(ControlLinkedSizerDTC):
-    LinkClass = wxNotebookPtr
-    ctrlParam = 'nb'
+class GridBagSizerDTC(FlexGridSizerDTC):
     def __init__(self, name, designer, objClass):
-        ControlLinkedSizerDTC.__init__(self, name, designer, objClass)
-        self.editors['Notebook'] = ReadOnlyConstrPropEdit
+        FlexGridSizerDTC.__init__(self, name, designer, objClass)
+        self.subCompanions['Items'] = GBSizerItemsCDTC
 
     def constructor(self):
-        return {'Name': 'name', 'Notebook': 'nb'}
+        return {'Name': 'name', 'VGap': 'vgap', 'HGap': 'hgap'}
 
     def designTimeSource(self):
-        return {'nb': 'None'}
+        return {'vgap': '0', 'hgap': '0'}
+
+    def getNumRowsCols(self, childCompanion):
+        maxRows = 0
+        maxCols = 0
+        for si in self.control.GetChildren():
+            (sipr, sipc), (sisr, sisc) = si.GetPos(), si.GetSpan()
+            if sipr + sisr > maxRows:
+                maxRows = sipr + sisr
+            if sipc + sisc > maxCols:
+                maxCols = sipc + sisc
+            
+        return maxRows, maxCols
+
+class GBSizerItemsCDTC(SizerItemsCDTC):
+    def __init__(self, name, designer, parentCompanion, ctrl):
+        SizerItemsCDTC.__init__(self, name, designer, parentCompanion, ctrl)
+        self.editors.update({'Position': PositionTuplePropEdit,
+                             'Span': SpanTuplePropEdit })
+    def constructor(self):
+        tcl = self.textConstrLst[self.index]
+        if tcl.method == 'AddWindow':
+            return {'Window': 0, 'Position': 1, 
+                    'Span': 'span', 'Flag': 'flag', 'Border': 'border'}
+        elif tcl.method == 'AddSizer':
+            return {'Sizer': 0, 'Position': 1, 
+                    'Span': 'span', 'Flag': 'flag', 'Border': 'border'}
+        elif tcl.method == 'AddSpacer':
+            return {'Size': 0, 'Position': 1, 
+                    'Span': 'span', 'Flag': 'flag', 'Border': 'border'}
+
+    def designTimeSource(self, wId, method=None):
+        if method is None:
+            method = self.insertionMethod
+
+        pos = self.findOpenPosition()
+
+        if method == 'AddWindow':
+            return {0: 'None', 1: repr(pos),  'span': '(1, 1)', 
+                    'flag': '0', 'border': '0'}
+        elif method == 'AddSizer':
+            return {0: 'None', 1: repr(pos), 'span': '(1, 1)', 
+                    'flag': '0', 'border': '0'}
+        elif method == 'AddSpacer':
+            return {0: 'wx.Size(8, 8)', 1: repr(pos), 'span': '(1, 1)', 
+                    'flag': '0', 'border': '0'}
+
+    def findOpenPosition(self):
+        pos = [0, 0]
+        while self.control.FindItemAtPosition(tuple(pos)):
+            pos[1] += 1
+        return tuple(pos)
+
+    def applyDesignTimeDefaults(self, params, method=None):
+        if method is None:
+            method = self.insertionMethod
+
+        pos = self.eval(params[1])
+        if self.control.FindItemAtPosition(pos):
+            raise Exception, _('Cannot use Position %s, an item is already at that position')%params[1]
+        if pos[0] < 0 or pos[1] < 0:
+            raise Exception, _('Position %s invalid, cannot contain negative values')%params[1]
+        
+        span = self.eval(params['span'])
+        if span[0] < 0 or span[1] < 0:
+            raise Exception, _('Span %s invalid, cannot contain negative values')%params[1]
+        
+
+        if (method in ('AddWindow', 'AddSizer') and params[0] == 'None') or \
+           (method == 'Insert' and params[1] == 'None'):
+            defaults = self.designTimeDefaults(params, method)
+            self.control.AddSizer(BlankSizer(), defaults[1], 
+                  defaults['span'], defaults['flag'], defaults['border'])
+        else:
+            SizerItemsCDTC.applyDesignTimeDefaults(self, params, method)
+
+    def getSizerGUIObject(self):
+        """ Returns a control, sizer, integer or None """
+        constr = self.textConstrLst[self.index]
+        
+        srcRef = constr.params[0]
+        if srcRef != 'None':
+            if srcRef.startswith('wx.Size'):
+                return self.index
+            else:
+                return self.designer.controllerView.getAllObjects()[srcRef]
+        else:
+            return None
+
+    def persistProp(self, name, setterName, value):
+        SizerItemsCDTC.persistProp(self, name, setterName, value)
+        if name in ('Position', 'Span'):
+            obj = self.getSizerGUIObject()
+            if obj is not None:
+                getattr(self.control, 'SetItem'+name)(obj, self.eval(value))
+                self.updateGUI()
+
+class TupleConstrPropEdit(ConstrPropEdit):
+    def inspectorEdit(self):
+        self.editorCtrl = TextCtrlIEC(self, self.value)
+        self.editorCtrl.createControl(self.parent, self.value, self.idx,
+          self.width)
+
+    def getValue(self):
+        if self.editorCtrl:
+            self.value = self.editorCtrl.getValue()
+        else:
+            self.value = self.getCtrlValue()
+        return self.value
+
+class PositionTuplePropEdit(TupleConstrPropEdit):
+    def getStyle(self):
+        return [esExpandable]
+    def getSubCompanion(self):
+        return PositionRowColDTC
+
+class SpanTuplePropEdit(TupleConstrPropEdit):
+    def getStyle(self):
+        return [esExpandable]
+    def getSubCompanion(self):
+        return SpanRowColDTC
+
+class PositiveIntPropEdit(IntPropEdit):
+    def inspectorEdit(self):
+        IntPropEdit.inspectorEdit(self)
+        self.editorCtrl.editorCtrl.SetRange(0, sys.maxint)
+    
+class RowColDTC(HelperDTC):
+    propName = 'Prop'
+    paramName = 'param'
+    setterMethod = 'Setter'
+    
+    def __init__(self, name, designer, cmpn, obj, ownerPW):
+        HelperDTC.__init__(self, name, designer, cmpn, obj, ownerPW)
+        self.editors = {'Row' : PositiveIntPropEdit,
+                        'Column' : PositiveIntPropEdit}
 
     def properties(self):
-        props = ControlLinkedSizerDTC.properties(self)
-        del props['Items']
-        return props
+        return {'Row': ('NameRoute', self.GetRowCol, self.SetRowCol),
+                'Column': ('NameRoute', self.GetRowCol, self.SetRowCol)}
 
-    def defaultAction(self):
-        pass
+    def GetRowCol(self, name):
+        t = self.eval(self.ownerCompn.textConstr.params[self.paramName])
+        if name == 'Row': 
+            return t[0]
+        elif name == 'Column': 
+            return t[1]
+        
+    def SetRowCol(self, name, value):
+        t = self.eval(self.ownerCompn.textConstr.params[self.paramName])
+        obj = self.ownerCompn.getSizerGUIObject()
+        if name == 'Row': 
+            newVal = (value, t[1])
+        elif name == 'Column': 
+            newVal = (t[0], value)
+        self.ownerCompn.textConstr.params[self.paramName] = `newVal`
+        self.designer.inspector.constructorUpdate(self.propName)
+        # XXX Setting to an existing position causes asserts and is wrong
+        # XXX Not sure how to handle this everywhere in the GridBagSizer support
+        getattr(self.ownerCompn.control, self.setterMethod)( obj, newVal )
 
 
-PaletteStore.paletteLists['ContainersLayout'].extend([
-  wxBoxSizer, wxGridSizer, wxFlexGridSizer, wxStaticBoxSizer, wxNotebookSizer, # RowColSizer,
-])
+class PositionRowColDTC(RowColDTC):
+    propName = 'Position'
+    paramName = 1
+    setterMethod = 'SetItemPosition'
 
-PaletteStore.compInfo.update({
-  wxBoxSizer: ['wxBoxSizer', BoxSizerDTC],
-  wxGridSizer: ['wxGridSizer', GridSizerDTC],
-  wxFlexGridSizer: ['wxFlexGridSizer', FlexGridSizerDTC],
-  wxStaticBoxSizer: ['wxStaticBoxSizer', StaticBoxSizerDTC],
-  wxNotebookSizer: ['wxNotebookSizer', NotebookSizerDTC]
-  #RowColSizer: ['RowColSizer', RowColSizerDTC],
-})
+class SpanRowColDTC(RowColDTC):
+    propName = 'Span'
+    paramName = 'span'
+    setterMethod = 'SetItemSpan'
+
+#-------------------------------------------------------------------------------
+
+import Plugins
+
+Plugins.registerComponents('ContainersLayout',
+      (wx.BoxSizer, 'wx.BoxSizer', BoxSizerDTC),
+      (wx.GridSizer, 'wx.GridSizer', GridSizerDTC),
+      (wx.FlexGridSizer, 'wx.FlexGridSizer', FlexGridSizerDTC),
+      (wx.StaticBoxSizer, 'wx.StaticBoxSizer', StaticBoxSizerDTC),
+#      (wx.NotebookSizer, 'wx.NotebookSizer', NotebookSizerDTC),
+      (wx.GridBagSizer, 'wx.GridBagSizer', GridBagSizerDTC),
+    )
