@@ -5,18 +5,19 @@
 # Author:      Riaan Booysen
 #
 # Created:     2000
-# RCS-ID:      $Id: UtilCompanions.py,v 1.26 2004/08/16 13:16:56 riaan Exp $
-# Copyright:   (c) 2000 - 2004
+# RCS-ID:      $Id: UtilCompanions.py,v 1.34 2007/07/02 15:01:09 riaan Exp $
+# Copyright:   (c) 2000 - 2007
 # Licence:     GPL
 #-----------------------------------------------------------------------------
 print 'importing Companions.UtilCompanions'
 import os, copy
 
-from wxPython.wx import *
+import wx
 
 import Preferences, Utils
+from Utils import _
 
-from BaseCompanions import UtilityDTC, CollectionDTC, CollectionIddDTC, wxNullBitmap, NYIDTC
+from BaseCompanions import UtilityDTC, CollectionDTC, CollectionIddDTC, NYIDTC
 
 import Constructors
 from PropEdit.PropertyEditors import IntConstrPropEdit, StrConstrPropEdit, \
@@ -24,19 +25,13 @@ from PropEdit.PropertyEditors import IntConstrPropEdit, StrConstrPropEdit, \
       LCCEdgeConstrPropEdit, WinEnumConstrPropEdit, BoolConstrPropEdit, \
       MenuEnumConstrPropEdit, BoolPropEdit, ColourConstrPropEdit, \
       ConstrPropEdit
-      
+
 from PropEdit import Enumerations, InspectorEditorControls
-import EventCollections, RTTI, methodparse
-import PaletteStore
+import EventCollections, RTTI
 
-import moduleparse, sourceconst
-
-PaletteStore.paletteLists['Utilities (Data)'] = []
-PaletteStore.palette.append(['Utilities (Data)', 'Editor/Tabs/Utilities',
-                             PaletteStore.paletteLists['Utilities (Data)']])
+import methodparse, moduleparse, sourceconst
 
 class ImageListDTC(UtilityDTC):
-    #wxDocs = HelpCompanions.wxImageListDocs
     def __init__(self, name, designer, objClass):
         UtilityDTC.__init__(self, name, designer, objClass)
         self.editors.update({'Width': IntConstrPropEdit,
@@ -62,7 +57,6 @@ class ImageListDTC(UtilityDTC):
             nv.propEditor.edit(None)
 
 class ImageListImagesCDTC(CollectionDTC):
-    #wxDocs = HelpCompanions.wxImageListDocs
     propName = 'Images'
     displayProp = 'bitmap'
     indexProp = '(None)'
@@ -70,7 +64,7 @@ class ImageListImagesCDTC(CollectionDTC):
     deletionMethod = 'Remove'
 
     additionalMethods = { 'AddWithColourMask': ('Add with colour mask', 'bitmap', '(None)'),
-#                          'AddIcon'     : ('Add icon', 'icon', '(None)') 
+#                          'AddIcon'     : ('Add icon', 'icon', '(None)')
                         }
 
     def __init__(self, name, designer, parentCompanion, ctrl):
@@ -102,15 +96,15 @@ class ImageListImagesCDTC(CollectionDTC):
     def designTimeSource(self, wId, method=None):
         if method is None:
             method = self.insertionMethod
-        
+
         if method == 'Add':
-            return {'bitmap': 'wxNullBitmap',
-                    'mask':   'wxNullBitmap'}
+            return {'bitmap': 'wx.NullBitmap',
+                    'mask':   'wx.NullBitmap'}
         elif method == 'AddWithColourMask':
-            return {'bitmap': 'wxNullBitmap',
-                    'maskColour': 'wxColour(255, 0, 255)'}
+            return {'bitmap': 'wx.NullBitmap',
+                    'maskColour': 'wx.Colour(255, 0, 255)'}
 #        elif method == 'AddIcon':
-#            return {'icon': 'wxNullIcon'}
+#            return {'icon': 'wx.NullIcon'}
 
     def moveItem(self, idx, dir):
         newIdx = CollectionDTC.moveItem(self, idx, dir)
@@ -125,8 +119,8 @@ class ImageListImagesCDTC(CollectionDTC):
         tcl = self.textConstrLst[self.index]
         if tcl.params.has_key(self.displayProp):
             value = tcl.params[self.displayProp]
-            if value != 'wxNullBitmap':
-                if value.startswith('wxBitmap'):
+            if value != 'wx.NullBitmap':
+                if value.startswith('wx.Bitmap'):
                     value = os.path.basename(value[10:-21])
                 else:
                     m = moduleparse.is_resource_bitmap.search(value)
@@ -135,9 +129,9 @@ class ImageListImagesCDTC(CollectionDTC):
         return value
 
     def setBitmap(self, value):
-        if value != wxNullBitmap:
+        if value != wx.NullBitmap:
             self.control.Replace(self.index, value)
-            self.designer.collEditors[(self.name, self.propName)].refreshCtrl(true)
+            self.designer.collEditors[(self.name, self.propName)].refreshCtrl(True)
 
     def defaultAction(self):
         nv = self.designer.inspector.constr.getNameValue('Bitmap')
@@ -147,51 +141,50 @@ class ImageListImagesCDTC(CollectionDTC):
     def designTimeDefaults(self, vals, method=None):
         dtd = CollectionDTC.designTimeDefaults(self, vals)
 
-        # resize wxNullBitmap if different size than the imagelist
+        # resize wx.NullBitmap if different size than the imagelist
         ix, iy = self.parentCompanion.control.GetSize(0)
         for param in vals.keys():
-            if vals[param] == 'wxNullBitmap' and (\
+            if vals[param] == 'wx.NullBitmap' and (\
                   dtd[param].GetWidth() != ix or\
                   dtd[param].GetHeight() != iy):
-                newbmp = wxEmptyBitmap(ix, iy)
-                mdc = wxMemoryDC()
+                newbmp = wx.EmptyBitmap(ix, iy)
+                mdc = wx.MemoryDC()
                 mdc.SelectObject(newbmp)
-                mdc.DrawBitmap(dtd[param], 0, 0, false)
-                mdc.SelectObject(wxNullBitmap)
+                mdc.DrawBitmap(dtd[param], 0, 0, False)
+                mdc.SelectObject(wx.NullBitmap)
                 dtd[param] = newbmp
 
         return dtd
 
     def applyDesignTimeDefaults(self, params, method=None):
         dtparams = {}; dtparams.update(params)
-        if dtparams.has_key('mask') and dtparams['mask'] == 'wxNullBitmap':
+        if dtparams.has_key('mask') and dtparams['mask'] == 'wx.NullBitmap':
             del dtparams['mask']
         CollectionDTC.applyDesignTimeDefaults(self, dtparams, method)
 
 # This class handles window id magic which should be done by a base class
 # UtilityIddDTC or maybe an IddDTCMix for everyone
-EventCollections.EventCategories['TimerEvent'] = (EVT_TIMER,)
+EventCollections.EventCategories['TimerEvent'] = ('wx.EVT_TIMER',)
 EventCollections.commandCategories.append('TimerEvent')
 class TimerDTC(UtilityDTC):
     handledConstrParams = ('id',)
-    #wxDocs = HelpCompanions.wxTimerDocs
     def __init__(self, name, designer, objClass):
         UtilityDTC.__init__(self, name, designer, objClass)
         self.id = self.getWinId()
     def constructor(self):
-        return {'EventHandler': 'evtHandler', 'Id': 'id'}
+        return {'Owner': 'owner', 'Id': 'id'}
     def designTimeSource(self):
-        return {'evtHandler': 'self', 'id': self.id}
+        return {'owner': 'self', 'id': self.id}
     def designTimeObject(self, args=None):
         return UtilityDTC.designTimeObject(self, self.designTimeDefaults())
     def designTimeDefaults(self):
-        return {'evtHandler': self.designer, 'id': wxNewId()}
+        return {'owner': self.designer, 'id': wx.NewId()}
     def events(self):
         return ['TimerEvent']
     def defaultAction(self):
         insp = self.designer.inspector
         insp.pages.SetSelection(2)
-        insp.events.doAddEvent('TimerEvent', 'EVT_TIMER')
+        insp.events.doAddEvent('TimerEvent', 'wx.EVT_TIMER')
 #-------------------------------------------------------------------------------
     def getWinId(self):
         return Utils.windowIdentifier(self.designer.model.main, self.name)
@@ -226,14 +219,14 @@ class AcceleratorEntryPropEdit(ConstrPropEdit):
         self.editorCtrl.createControl(self.parent, self.idx, self.width, self.edit)
 
     def edit(self, event):
-        dlg = wxTextEntryDialog(self.parent, 'Question', 'Caption', 'Default answer')
+        dlg = wx.TextEntryDialog(self.parent, 'Question', 'Caption', 'Default answer')
         try:
-            if dlg.ShowModal() != wxID_OK:
+            if dlg.ShowModal() != wx.ID_OK:
                 return
             self.value = dlg.GetValue()
             # Your code
         finally:
-            self.inspectorPost(false)
+            self.inspectorPost(False)
             dlg.Destroy()
 
 
@@ -249,7 +242,7 @@ class AcceleratorTableEntriesCDTC(CollectionDTC):
         CollectionDTC.__init__(self, name, designer, parentCompanion, ctrl)
 
         self.editors['Entry'] = AcceleratorEntryPropEdit
-        
+
 #        self.editors.update({'Flags':   IntConstrPropEdit,
 #                             'KeyCode': IntConstrPropEdit,
 #                             'Command': IntConstrPropEdit})
@@ -268,7 +261,7 @@ class AcceleratorTableEntriesCDTC(CollectionDTC):
 #    def SetName(self, oldName, newName):
 #        CollectionDTC.SetName(self, oldName, newName)
 
-    def designTimeSource(self, idx, method):
+    def designTimeSource(self, idx, method=None):
         return {0: '(0, 0, -1)'}
 
     def getDisplayProp(self):
@@ -283,11 +276,10 @@ class AcceleratorTableEntriesCDTC(CollectionDTC):
     def applyDesignTimeDefaults(self, params, method):
         return
 
-EventCollections.EventCategories['MenuEvent'] = (EVT_MENU,)
+EventCollections.EventCategories['MenuEvent'] = ('wx.EVT_MENU',)
 EventCollections.commandCategories.append('MenuEvent')
 
 class MenuDTC(UtilityDTC):
-    #wxDocs = HelpCompanions.wxMenuDocs
     def __init__(self, name, designer, objClass):
         UtilityDTC.__init__(self, name, designer, objClass)
         self.editors.update({'Title': StrConstrPropEdit,
@@ -319,66 +311,69 @@ class MenuDTC(UtilityDTC):
             nv.propEditor.edit(None)
 
 class MenuItemsCIDTC(CollectionIddDTC):
-    #wxDocs = HelpCompanions.wxMenuDocs
     propName = 'Items'
-    displayProp = 'item'
+    displayProp = 'text'
     indexProp = '(None)'
     insertionMethod = 'Append'
     insertionDesc = 'Append item'
     deletionMethod = 'Remove'
     idProp = 'id'
-    idPropNameFrom = 'item'
+    idPropNameFrom = 'text'
 
     additionalMethods = { 'AppendSeparator': ('Append separator', '', '(None)'),
-                          'AppendMenu'     : ('Append sub menu', 'item', '(None)') }
+                          'AppendMenu'     : ('Append sub menu', 'text', '(None)') }
 
     def __init__(self, name, designer, parentCompanion, ctrl):
         CollectionIddDTC.__init__(self, name, designer, parentCompanion, ctrl)
-        self.editors.update({'Label': StrConstrPropEdit,
-                             'HelpString': StrConstrPropEdit,
+        self.editors.update({'Text': StrConstrPropEdit,
+                             'Help': StrConstrPropEdit,
                              'Kind': EnumConstrPropEdit,
                              'Menu': MenuEnumConstrPropEdit,
                             })
 
-        self.names['Kind'] = ['wxITEM_NORMAL', 'wxITEM_CHECK', 'wxITEM_RADIO']
+        self.names['Kind'] = ['wx.ITEM_NORMAL', 'wx.ITEM_CHECK', 'wx.ITEM_RADIO']
 
     def constructor(self):
         tcl = self.textConstrLst[self.index]
         if tcl.method == 'Append':
-            return {'Label': 'item', 'HelpString': 'helpString',
+            return {'Text': 'text', 'Help': 'help',
                     'Kind': 'kind', 'ItemId': 'id'}
         elif tcl.method == 'AppendSeparator':
             return {}
         elif tcl.method == 'AppendMenu':
-            return {'Label': 'item', 'HelpString': 'helpString',
-                    'Menu': 'subMenu', 'ItemId': 'id'}
+            return {'Text': 'text', 'Help': 'help',
+                    'Menu': 'submenu', 'ItemId': 'id'}
 
     def properties(self):
-        props = CollectionIddDTC.properties(self)
-        props.update(
-            {'Label': ('IdRoute', wxMenu.GetLabel, wxMenu.SetLabel),
-             'HelpString': ('IdRoute', wxMenu.GetHelpString, wxMenu.SetHelpString),
-             'Menu': ('IdRoute', wxMenu.GetHelpString, wxMenu.SetHelpString)})
+        tcl = self.textConstrLst[self.index]
+        if tcl.method in ('Append', 'AppendMenu'):
+            props = CollectionIddDTC.properties(self)
+            props.update(
+                {'Text': ('IdRoute', wx.Menu.GetLabel, wx.Menu.SetLabel),
+                 'Help': ('IdRoute', wx.Menu.GetHelpString, wx.Menu.SetHelpString)})
+        elif tcl.method == 'AppendSeparator':
+            props = {}
+
         return props
 
     def designTimeSource(self, wId, method=None):
         if method is None:
             method = self.insertionMethod
-            
+
         newItemName, winId = self.newUnusedItemNames(wId)
 
         if method == 'Append':
             return {'id': winId,
-                    'item': `newItemName`,
-                    'helpString': `''`,
-                    'kind': 'wxITEM_NORMAL'}
+                    'text': `newItemName`,
+                    'help': `''`,
+                    'kind': 'wx.ITEM_NORMAL'}
         elif method == 'AppendSeparator':
             return {}
         elif method == 'AppendMenu':
             return {'id': winId,
-                    'item': `newItemName`,
-                    'subMenu': 'wxMenu()',
-                    'helpString': `''`}
+                    'text': `newItemName`,
+                    'submenu': 'wx.Menu()',
+                    'help': `''`}
 
     def designTimeDefaults(self, vals, method=None):
         if method is None:
@@ -386,16 +381,16 @@ class MenuItemsCIDTC(CollectionIddDTC):
 
         dtd = {}
         for param in vals.keys():
-            if param == 'subMenu':
+            if param == 'submenu':
                 name = vals[param]
                 if name[:4] == 'self':
                     dtd[param] = self.designer.objects[name[5:]][1]
-                elif name == 'wxMenu()':
-                    dtd[param] = wxMenu()
+                elif name == 'wx.Menu()':
+                    dtd[param] = wx.Menu()
                 else:
-                    raise Exception, 'Invalid menu reference'
+                    raise Exception, _('Invalid menu reference: %s')%name
             elif param == self.idProp:
-                dtd[param] = wxNewId()
+                dtd[param] = wx.NewId()
             else:
                 dtd[param] = self.eval(vals[param])
 
@@ -407,7 +402,7 @@ class MenuItemsCIDTC(CollectionIddDTC):
     def defaultAction(self):
         insp = self.designer.inspector
         insp.pages.SetSelection(2)
-        insp.events.doAddEvent('MenuEvent', 'EVT_MENU')
+        insp.events.doAddEvent('MenuEvent', 'wx.EVT_MENU')
 
     def moveItem(self, idx, dir):
         newIdx = CollectionIddDTC.moveItem(self, idx, dir)
@@ -430,20 +425,18 @@ class MenuItemsCIDTC(CollectionIddDTC):
             if compn != self:
                 compnSrcRef = Utils.srcRefFromCtrlName(compn.name)
                 for constr in self.textConstrLst:
-                    if constr.params.has_key('subMenu'):
-                        if compnSrcRef == constr.params['subMenu']:
-                            constr.params['subMenu'] = 'wxMenu()'
+                    if constr.params.has_key('submenu'):
+                        if compnSrcRef == constr.params['submenu']:
+                            constr.params['submenu'] = 'wx.Menu()'
 
     def GetMenu(self):
-        return self.textConstrLst[self.index].params['subMenu']
+        return self.textConstrLst[self.index].params['submenu']
 
     def SetMenu(self, value):
-        self.textConstrLst[self.index].params['subMenu'] = value
+        self.textConstrLst[self.index].params['submenu'] = value
 
 
 class MenuBarDTC(UtilityDTC):
-    #wxDocs = HelpCompanions.wxMenuBarDocs
-
     def __init__(self, name, designer, objClass):
         UtilityDTC.__init__(self, name, designer, objClass)
         self.editors.update({'Menus': CollectionPropEdit})
@@ -460,7 +453,7 @@ class MenuBarDTC(UtilityDTC):
     def dependentProps(self):
         return UtilityDTC.dependentProps(self) + ['Menus']
 
-    def designTimeSource(self, position = 'wxDefaultPos', size = 'wxDefaultSize'):
+    def designTimeSource(self, position = 'wx.DefaultPosition', size = 'wx.DefaultSize'):
         return {}
 
     def initDesignTimeControl(self):
@@ -479,13 +472,12 @@ class MenuBarDTC(UtilityDTC):
             nv.propEditor.edit(None)
 
 class MenuBarMenusCDTC(CollectionDTC):
-    #wxDocs = HelpCompanions.wxMenuBarDocs
     propName = 'Menus'
     displayProp = 'title'
     indexProp = '(None)'
     insertionMethod = 'Append'
     deletionMethod = 'Remove'
-    
+
 
     def __init__(self, name, designer, parentCompanion, ctrl):
         CollectionDTC.__init__(self, name, designer, parentCompanion, ctrl)
@@ -496,7 +488,7 @@ class MenuBarMenusCDTC(CollectionDTC):
         return {'Menu': 'menu', 'Title': 'title'}
 
     def designTimeSource(self, wId, method=None):
-        return {'menu': 'wxMenu()',
+        return {'menu': 'wx.Menu()',
                 'title': `'%s%d'%(self.propName, wId)`}
 
     def designTimeDefaults(self, vals, method=None):
@@ -506,10 +498,10 @@ class MenuBarMenusCDTC(CollectionDTC):
                 name = vals[param]
                 if name[:4] == 'self':
                     dtd[param] = self.designer.objects[name[5:]][1]
-                elif name == 'wxMenu()':
-                    dtd[param] = wxMenu()
+                elif name == 'wx.Menu()':
+                    dtd[param] = wx.Menu()
                 else:
-                    raise 'Invalid menu reference'
+                    raise Exception, _('Invalid menu reference: %s')%name
             else:
                 dtd[param] = self.eval(vals[param])
 
@@ -524,7 +516,7 @@ class MenuBarMenusCDTC(CollectionDTC):
         return newIdx
 
     def vetoedMethods(self):
-        return CollectionDTC.vetoedMethods(self)+['GetPosition', 'SetPosition', 
+        return CollectionDTC.vetoedMethods(self)+['GetPosition', 'SetPosition',
               'GetSize', 'SetSize']
 
     def GetMenu(self):
@@ -534,7 +526,6 @@ class MenuBarMenusCDTC(CollectionDTC):
         self.textConstrLst[self.index].params['menu'] = value
 
 class LayoutConstraintsDTC(Constructors.EmptyConstr, UtilityDTC):
-    #wxDocs = HelpCompanions.wxLayoutConstraintsDocs
     def __init__(self, name, designer, objClass):
         UtilityDTC.__init__(self, name, designer, objClass)
         self.editors.update({'Constraints': CollPropEdit})
@@ -545,8 +536,8 @@ class LayoutConstraintsDTC(Constructors.EmptyConstr, UtilityDTC):
         props.update({'Constraints': ('NoneRoute', None, None)})
         return props
 
-cursorIconTypes = ['wxBITMAP_TYPE_XBM', 'wxBITMAP_TYPE_CUR',
-                   'wxBITMAP_TYPE_CUR_RESOURCE', 'wxBITMAP_TYPE_ICO']
+cursorIconTypes = ['wx.BITMAP_TYPE_XBM', 'wx.BITMAP_TYPE_CUR',
+                   'wx.BITMAP_TYPE_CUR_RESOURCE', 'wx.BITMAP_TYPE_ICO']
 
 class CursorDTC(UtilityDTC):
     def __init__(self, name, designer, objClass):
@@ -561,20 +552,20 @@ class CursorDTC(UtilityDTC):
     def constructor(self):
         return {'CursorName': 'cursorName', 'Flags': 'flags',
                 'HotSpotX': 'hotSpotX', 'HotSpotY': 'hotSpotY'}
-    def designTimeSource(self, position='wxDefaultPos', size='wxDefaultSize'):
+    def designTimeSource(self, position='wx.DefaultPosition', size='wx.DefaultSize'):
         return {'cursorName': "''",
-                'flags': 'wxBITMAP_TYPE_CUR',
+                'flags': 'wx.BITMAP_TYPE_CUR',
                 'hotSpotX': '0',
                 'hotSpotY': '0'}
 
-stockCursorIds = ['wxCURSOR_ARROW', 'wxCURSOR_BULLSEYE', 'wxCURSOR_CHAR',
-      'wxCURSOR_CROSS', 'wxCURSOR_HAND', 'wxCURSOR_IBEAM', 'wxCURSOR_LEFT_BUTTON',
-      'wxCURSOR_MAGNIFIER', 'wxCURSOR_MIDDLE_BUTTON', 'wxCURSOR_NO_ENTRY',
-      'wxCURSOR_PAINT_BRUSH', 'wxCURSOR_PENCIL', 'wxCURSOR_POINT_LEFT',
-      'wxCURSOR_POINT_RIGHT', 'wxCURSOR_QUESTION_ARROW', 'wxCURSOR_RIGHT_BUTTON',
-      'wxCURSOR_SIZENESW', 'wxCURSOR_SIZENS', 'wxCURSOR_SIZENWSE', 'wxCURSOR_SIZEWE',
-      'wxCURSOR_SIZING', 'wxCURSOR_SPRAYCAN', 'wxCURSOR_WAIT', 'wxCURSOR_WATCH',
-      'wxCURSOR_ARROWWAIT']
+stockCursorIds = ['wx.CURSOR_ARROW', 'wx.CURSOR_BULLSEYE', 'wx.CURSOR_CHAR',
+      'wx.CURSOR_CROSS', 'wx.CURSOR_HAND', 'wx.CURSOR_IBEAM', 'wx.CURSOR_LEFT_BUTTON',
+      'wx.CURSOR_MAGNIFIER', 'wx.CURSOR_MIDDLE_BUTTON', 'wx.CURSOR_NO_ENTRY',
+      'wx.CURSOR_PAINT_BRUSH', 'wx.CURSOR_PENCIL', 'wx.CURSOR_POINT_LEFT',
+      'wx.CURSOR_POINT_RIGHT', 'wx.CURSOR_QUESTION_ARROW', 'wx.CURSOR_RIGHT_BUTTON',
+      'wx.CURSOR_SIZENESW', 'wx.CURSOR_SIZENS', 'wx.CURSOR_SIZENWSE', 'wx.CURSOR_SIZEWE',
+      'wx.CURSOR_SIZING', 'wx.CURSOR_SPRAYCAN', 'wx.CURSOR_WAIT', 'wx.CURSOR_WATCH',
+      'wx.CURSOR_ARROWWAIT']
 
 class StockCursorDTC(UtilityDTC):
     handledConstrParams = ()
@@ -588,23 +579,26 @@ class StockCursorDTC(UtilityDTC):
         return ['Handle']
     def constructor(self):
         return {'CursorId': 'id'}
-    def designTimeSource(self, position='wxDefaultPos', size='wxDefaultSize'):
-        return {'id': 'wxCURSOR_ARROW'}
+    def designTimeSource(self, position='wx.DefaultPosition', size='wx.DefaultSize'):
+        return {'id': 'wx.CURSOR_ARROW'}
 
 
-PaletteStore.paletteLists['Utilities (Data)'].extend([wxMenuBar, wxMenu, #wxAcceleratorTable, 
-    wxImageList, wxTimer, wxStockCursor]) 
-    #wxCursor, causes problems on wxGTK
+#-------------------------------------------------------------------------------
+import Plugins
 
-PaletteStore.compInfo.update({wxMenuBar: ['wxMenuBar', MenuBarDTC],
-    wxImageList: ['wxImageList', ImageListDTC],
-    #wxAcceleratorTable: ['wxAcceleratorTable', AcceleratorTableDTC],
-    wxMenu: ['wxMenu', MenuDTC],
-    wxCursor: ['wxCursor', CursorDTC],
-    wxStockCursor: ['wxStockCursor', StockCursorDTC],
+Plugins.registerPalettePage('Utilities (Data)', _('Utilities (Data)'))
 
-    # these objects need design time inheritance
-    wxTimer: ['wxTimer', TimerDTC],
-    wxTextDropTarget: ['wxTextDropTarget', NYIDTC],
-    wxFileDropTarget: ['wxFileDropTarget', NYIDTC],
-})
+Plugins.registerComponents('Utilities (Data)',
+      (wx.MenuBar, 'wx.MenuBar', MenuBarDTC),
+      (wx.Menu, 'wx.Menu', MenuDTC),
+      (wx.ImageList, 'wx.ImageList', ImageListDTC),
+      (wx.Timer, 'wx.Timer', TimerDTC),
+      (wx.StockCursor, 'wx.StockCursor', StockCursorDTC),
+
+      #(wx.AcceleratorTable, 'wx.AcceleratorTable', AcceleratorTableDTC),
+      #(wxCursor: ['wx.Cursor', CursorDTC],
+
+      # these objects need design time inheritance
+      #(wxTextDropTarget, 'wx.TextDropTarget', NYIDTC),
+      #(wxFileDropTarget, 'wx.FileDropTarget', NYIDTC),
+    )
