@@ -5,8 +5,8 @@
 # Author:      Riaan Booysen
 #
 # Created:     2000/10/22
-# RCS-ID:      $Id: CVSExplorer.py,v 1.30 2004/08/16 13:21:59 riaan Exp $
-# Copyright:   (c) 1999 - 2004 Riaan Booysen
+# RCS-ID:      $Id: CVSExplorer.py,v 1.36 2007/07/02 15:01:10 riaan Exp $
+# Copyright:   (c) 1999 - 2007 Riaan Booysen
 # Licence:     GPL
 #-----------------------------------------------------------------------------
 print 'importing Explorers.CVSExplorer'
@@ -15,18 +15,21 @@ print 'importing Explorers.CVSExplorer'
 
 import time, stat, os
 
-from wxPython.lib.dialogs import wxScrolledMessageDialog
-from wxPython.wx import *
+import wx
+from wx.lib.dialogs import ScrolledMessageDialog
+
+import Utils
+from Preferences import IS
+from Utils import _
 
 import ExplorerNodes
 from Models import EditorModels, EditorHelper
-from Preferences import IS
 
-import ProcessProgressDlg, Utils
+import ProcessProgressDlg
 import scrm
 
 cvs_environ_vars = ['CVSROOT', 'CVS_RSH', 'HOME']
-cvs_environ_ids  = map(lambda x: wxNewId(), range(len(cvs_environ_vars)))
+cvs_environ_ids  = [wx.NewId() for ev in cvs_environ_vars]
 
 (wxID_CVSUPDATE, wxID_CVSCOMMIT, wxID_CVSADD, wxID_CVSADDBINARY, wxID_CVSREMOVE,
  wxID_CVSDIFF, wxID_CVSLOG, wxID_CVSSTATUS, wxID_FSCVSIMPORT, wxID_FSCVSCHECKOUT,
@@ -34,6 +37,7 @@ cvs_environ_ids  = map(lambda x: wxNewId(), range(len(cvs_environ_vars)))
  wxID_CVSLOCK, wxID_CVSUNLOCK, wxID_CVSTEST) = Utils.wxNewIds(18)
 
 cvsFolderImgIdx = 6
+maxHelpLines = 30
 
 def isCVS(filename):
     file = os.path.basename(filename)
@@ -77,7 +81,7 @@ class CVSController(ExplorerNodes.Controller):
     def __init__(self, editor, list, inspector, controllers):
         ExplorerNodes.Controller.__init__(self, editor)
         self.list = list
-        self.menu = wxMenu()
+        self.menu = wx.Menu()
         self.cvsOptions = '-z7'
 
         self.cvsMenuDef = [
@@ -109,10 +113,10 @@ class CVSController(ExplorerNodes.Controller):
               (wxID_FSCVSLOGOUT, 'Logout', self.OnLogoutCVS, '-'),
         ]
 
-        self.fileCVSMenu = wxMenu()
-        self.setupMenu(self.fileCVSMenu, self.list, self.fileCVSMenuDef, false)
+        self.fileCVSMenu = wx.Menu()
+        self.setupMenu(self.fileCVSMenu, self.list, self.fileCVSMenuDef, False)
 
-##        self.cvsEnvMenu = wxMenu()
+##        self.cvsEnvMenu = wx.Menu()
 ##        menus = []
 ##        for env, id in map(lambda x, v = cvs_environ_vars, i = cvs_environ_ids: \
 ##            (v[x], i[x]), range(len(cvs_environ_vars))):
@@ -121,7 +125,7 @@ class CVSController(ExplorerNodes.Controller):
 ##
 ##        self.fileCVSMenu.AppendMenu(wxID_FSCVSENV, 'CVS shell environment vars', self.cvsEnvMenu)
 
-        self.images = wxImageList(16, 16)
+        self.images = wx.ImageList(16, 16)
         for cvsImg in ( 'Images/CvsPics/File.png',
                         'Images/CvsPics/BinaryFile.png',
                         'Images/CvsPics/ModifiedFile.png',
@@ -129,7 +133,7 @@ class CVSController(ExplorerNodes.Controller):
                         'Images/CvsPics/MissingFile.png',
                         'Images/CvsPics/ConflictingFile.png',
                         'Images/CvsPics/Dir.png',
-                        'Images/Modules/FolderUp_s.png',
+                        'Images/Modules/FolderUp.png',
                         'Images/CvsPics/UnknownDir.png',
                         'Images/CvsPics/UnknownFile.png'):
             self.images.Add(IS.load(cvsImg))
@@ -154,12 +158,12 @@ class CVSController(ExplorerNodes.Controller):
             return name
 
     def setupListCtrl(self):
-        self.list.SetWindowStyleFlag(wxLC_REPORT)
-        self.list.InsertColumn(0, 'Name', wxLIST_FORMAT_LEFT, 150)
-        self.list.InsertColumn(1, 'Rev.', wxLIST_FORMAT_LEFT, 50)
-        self.list.InsertColumn(2, 'Date', wxLIST_FORMAT_LEFT, 150)
-        self.list.InsertColumn(3, 'Status', wxLIST_FORMAT_LEFT, 150)
-        self.list.InsertColumn(4, 'Options', wxLIST_FORMAT_LEFT, 50)
+        self.list.SetWindowStyleFlag(wx.LC_REPORT)
+        self.list.InsertColumn(0, 'Name', wx.LIST_FORMAT_LEFT, 150)
+        self.list.InsertColumn(1, 'Rev.', wx.LIST_FORMAT_LEFT, 50)
+        self.list.InsertColumn(2, 'Date', wx.LIST_FORMAT_LEFT, 150)
+        self.list.InsertColumn(3, 'Status', wx.LIST_FORMAT_LEFT, 150)
+        self.list.InsertColumn(4, 'Options', wx.LIST_FORMAT_LEFT, 50)
 
     def cleanupListCtrl(self):
         cols = range(5)
@@ -168,7 +172,7 @@ class CVSController(ExplorerNodes.Controller):
             self.list.DeleteColumn(col)
 
     def showMessage(self, cmd, msg):
-        dlg = wxScrolledMessageDialog(self.list, msg, cmd)
+        dlg = ScrolledMessageDialog(self.list, msg, cmd)
         try: dlg.ShowModal()
         finally: dlg.Destroy()
 
@@ -183,18 +187,18 @@ class CVSController(ExplorerNodes.Controller):
             cvsroot = self.list.node.root
         else:
             cvsroot = os.environ.get('CVSROOT', '(not defined)')
-        dlg = wxTextEntryDialog(self.list, 'CVSROOT: %s\nCVS_RSH: %s\n(in dir %s)\n\n%s'\
+        dlg = wx.TextEntryDialog(self.list, 'CVSROOT: %s\nCVS_RSH: %s\n(in dir %s)\n\n%s'\
               %(cvsroot, os.environ.get('CVS_RSH', '(not defined)'), inDir, help),
               'CVS command line', wholeCommand)
-        if wxPlatform == '__WXMSW__':
-            te = Utils.getCtrlsFromDialog(dlg, 'wxTextCtrlPtr')[0]
+        if wx.Platform == '__WXMSW__':
+            te = Utils.getCtrlsFromDialog(dlg, 'TextCtrl')[0]
             try:
                 te.SetSelection(wholeCommand.index('['),
                                 wholeCommand.index(']')+1)
             except ValueError:
                 te.SetInsertionPoint(len(wholeCommand))
         try:
-            if dlg.ShowModal() == wxID_OK:
+            if dlg.ShowModal() == wx.ID_OK:
                 return dlg.GetValue()
             else:
                 return ''
@@ -203,23 +207,23 @@ class CVSController(ExplorerNodes.Controller):
 
     def getCvsHelp(self, cmd, option = '-H'):
         CVSPD = ProcessProgressDlg.ProcessProgressDlg(self.list,
-                  'cvs %s %s'% (option, cmd), '', modally=false)
+                  'cvs %s %s'% (option, cmd), '', modally=False)
         try:
-            return ' '.join(CVSPD.errors[:-1]).expandtabs(8)
+            return ' '.join(CVSPD.errors[:-1][:maxHelpLines]).expandtabs(8)
         finally:
             CVSPD.Destroy()
 
     # cvsOutput can be 'output window', 'dialogs' or 'tuple'
     def doCvsCmd(self, cmd, cvsDir, stdinput='', cvsOutput='output window'):
         # Repaint background
-        wxYield()
+        wx.Yield()
 
         cwd = os.getcwd()
         try:
             os.chdir(cvsDir)
             CVSPD = ProcessProgressDlg.ProcessProgressDlg(self.list, cmd, 'CVS progress...')
             try:
-                if CVSPD.ShowModal() == wxOK:
+                if CVSPD.ShowModal() == wx.OK:
                     outls = CVSPD.output
                     errls = CVSPD.errors
                 else:
@@ -231,13 +235,13 @@ class CVSController(ExplorerNodes.Controller):
 
             if cvsOutput == 'output window':
                 errout = self.editor.erroutFrm
-                tbs = errout.updateCtrls((), outls, 'CVS Result', '', err)
+                tbs = errout.updateCtrls((), outls, _('CVS Result'), '', err)
                 errout.display(tbs)
 
             elif cvsOutput == 'dialogs':
                 if err.strip():
-                    dlg = wxMessageDialog(self.list, err,
-                      'Server response or Error', wxOK | wxICON_EXCLAMATION)
+                    dlg = wx.MessageDialog(self.list, err,
+                      _('Server response or Error'), wx.OK | wx.ICON_EXCLAMATION)
                     try: dlg.ShowModal()
                     finally: dlg.Destroy()
 
@@ -249,7 +253,7 @@ class CVSController(ExplorerNodes.Controller):
             #msgType = 'warning' if err else 'info' # i wish
             if err: msgType = 'Warning'
             else: msgType = 'Info'
-            self.editor.setStatus('CVS command completed: %s'%cmd, msgType)
+            self.editor.setStatus(_('CVS command completed: %s')%cmd, msgType)
 
         finally:
             os.chdir(cwd)
@@ -275,9 +279,9 @@ class CVSController(ExplorerNodes.Controller):
               cvsDir, self.getCvsHelp(cmd))
         if cmdStr:
             self.doCvsCmd(cmdStr, cvsDir)
-            return true
+            return True
         else:
-            return false
+            return False
 
     def importCVSItems(self):
         # Imports are called from normal folders not CVS folders
@@ -296,11 +300,11 @@ class CVSController(ExplorerNodes.Controller):
         for line in lines:
             cvsroots.append(line.split()[0])
         if cvsroots:
-            dlg = wxSingleChoiceDialog(self.list, 'Select and click OK to set CVSROOT'\
-             ' or Cancel to use environment variable.\n\nYou have pserver access to the following servers:',
-             'Choose CVSROOT (-d parameter)', cvsroots)
+            dlg = wx.SingleChoiceDialog(self.list, _('Select and click OK to set CVSROOT'\
+             ' or Cancel to use environment variable.\n\nYou have pserver access to the following servers:'),
+             _('Choose CVSROOT (-d parameter)'), cvsroots)
             try:
-                if dlg.ShowModal() == wxID_OK:
+                if dlg.ShowModal() == wx.ID_OK:
                     cvsOpts = '-d'+dlg.GetStringSelection()
                 else:
                     cvsOpts = ''
@@ -356,7 +360,7 @@ class CVSController(ExplorerNodes.Controller):
         if res is not None and len(res)==2:
             outls, errls = res
             errout = self.editor.erroutFrm
-            tbs = errout.updateCtrls((), outls, 'CVS Result', '', errls)
+            tbs = errout.updateCtrls((), outls, _('CVS Result'), '', errls)
             errout.display(tbs)
             errout.displayDiff(''.join(outls))
 
@@ -398,13 +402,13 @@ class CVSController(ExplorerNodes.Controller):
                 else:
                     cvsroot = ''
 
-        cvsroot = self.cvsCmdPrompt(cvsroot, cvsDir, 
-              help='Change the CVSROOT if necessary:')
+        cvsroot = self.cvsCmdPrompt(cvsroot, cvsDir,
+              help=_('Change the CVSROOT if necessary:'))
 
-        dlg = wxTextEntryDialog(self.list, 'Enter cvs password for '+cvsroot, 
-              'CVS login', '', style=wxOK|wxCANCEL|wxCENTRE|wxTE_PASSWORD)
+        dlg = wx.TextEntryDialog(self.list, _('Enter cvs password for %s')%cvsroot,
+              'CVS login', '', style=wx.OK | wx.CANCEL | wx.CENTRE | wx.TE_PASSWORD)
         try:
-            if dlg.ShowModal() == wxID_OK:
+            if dlg.ShowModal() == wx.ID_OK:
                 password = scrm.scramble(dlg.GetValue())
             else:
                 return
@@ -431,7 +435,7 @@ class CVSController(ExplorerNodes.Controller):
             else:
                 return open(cvspass, 'w'), []
         else:
-            raise Exception('HOME env var is not defined or not legal')
+            raise Exception(_('HOME env var is not defined or not legal'))
 
     def OnLogoutCVS(self, event):
         cvsDir = self.list.node.resourcepath
@@ -439,17 +443,17 @@ class CVSController(ExplorerNodes.Controller):
 
     def OnEditEnv(self, event):
         envKey = cvs_environ_vars[cvs_environ_ids.index(event.GetId())]
-        envVal = os.environ.get(envKey, '(not defined)')
-        dlg = wxTextEntryDialog(self.list, 'Edit CVS shell environment variable: %s\nA blank entry will remove the variable.'% envKey,
-            'CVS shell environment variables', envVal)
+        envVal = os.environ.get(envKey, _('(not defined)'))
+        dlg = wx.TextEntryDialog(self.list, _('Edit CVS shell environment variable: %s\nA blank entry will remove the variable.')% envKey,
+            _('CVS shell environment variables'), envVal)
         try:
-            if dlg.ShowModal() == wxID_OK:
+            if dlg.ShowModal() == wx.ID_OK:
                 answer = dlg.GetValue()
-                if answer and answer != '(not defined)':
+                if answer and answer != _('(not defined)'):
                     try:
                         os.environ[envKey] = answer
                     except:
-                        wxMessageBox('Changing environment variables is not supported on this OS\nConsult CVS howtos on how to set these globally')
+                        wx.MessageBox(_('Changing environment variables is not supported on this OS\nConsult CVS howtos on how to set these globally'))
                 else:
                     if os.environ.has_key(envKey):
                         del os.environ[envKey]
@@ -458,7 +462,7 @@ class CVSController(ExplorerNodes.Controller):
 
     def OnTest(self, event):
         print 'TEST'
-#        self.list.SetWindowStyleFlag(wxLC_REPORT)
+#        self.list.SetWindowStyleFlag(wx.LC_REPORT)
         self.setupListCtrl()
 
 class CVSFolderNode(ExplorerNodes.ExplorerNode):
@@ -478,7 +482,7 @@ class CVSFolderNode(ExplorerNodes.ExplorerNode):
         return '/'.join(('D', self.name, self.revision, self.timestamp, self.options, self.tagdate))
 
     def isFolderish(self):
-        return false
+        return False
 
     def notifyBeginLabelEdit(self, event):
         event.Veto()
@@ -509,16 +513,16 @@ class CVSFileNode(ExplorerNodes.ExplorerNode):
 
         ExplorerNodes.ExplorerNode.__init__(self, name, resourcepath, None, -1, parent)
 
-        self.missing = false
-        self.modified = false
-        self.conflict = false
+        self.missing = False
+        self.modified = False
+        self.conflict = False
         self.imgIdx = 0
         if self.timestamp:
             filename = os.path.abspath(os.path.join(self.resourcepath, '..', name))
             if os.path.exists(filename):
                 self.modified, self.conflict = cvsFileLocallyModified(filename, self.timestamp)
             else:
-                self.missing = true
+                self.missing = True
 
         self.imgIdx = self.missing and self.missing << 2 \
                       or (self.options == '-kb' and not self.modified) \
@@ -526,7 +530,7 @@ class CVSFileNode(ExplorerNodes.ExplorerNode):
                       or self.conflict *5 or self.modified << 1
 
     def isFolderish(self):
-        return false
+        return False
 
     def notifyBeginLabelEdit(self, event):
         event.Veto()
@@ -559,7 +563,7 @@ class CVSFileNode(ExplorerNodes.ExplorerNode):
                     resultView.refresh()
                     resultView.focus()
                 else:
-                    editor.setStatus('No CVS conflicts in file', 'Warning', true)
+                    editor.setStatus(_('No CVS conflicts in file'), 'Warning', True)
 
                 return model, controller
         return None, None
@@ -582,7 +586,7 @@ class FSCVSFolderNode(ExplorerNodes.ExplorerNode):
     def __init__(self, name, resourcepath, clipboard, imgIdx, parent, bookmarks=None):
         ExplorerNodes.ExplorerNode.__init__(self, name, resourcepath, clipboard,
               EditorModels.CVSFolderModel.imgIdx, parent)
-        self.vetoSort = true
+        self.vetoSort = True
         self.dirpos = 0
         self.upImgIdx = 7
 
@@ -602,7 +606,7 @@ class FSCVSFolderNode(ExplorerNodes.ExplorerNode):
             return ExplorerNodes.ExplorerNode.getTitle(self)
 
     def isFolderish(self):
-        return true
+        return True
 
     def notifyBeginLabelEdit(self, event):
         event.Veto()
@@ -640,7 +644,7 @@ class FSCVSFolderNode(ExplorerNodes.ExplorerNode):
         self.dirpos = 0
         fileEntries = self.parent.openList()
         txtEntries = open(os.path.join(self.resourcepath, 'Entries')).readlines()
-        filenames = map(lambda x: x.name, fileEntries)
+        filenames = [f.name for f in fileEntries]
         missingEntries = []
 
         for txtEntry in txtEntries:
@@ -678,9 +682,9 @@ class FSCVSFolderNode(ExplorerNodes.ExplorerNode):
         cvsChd = tree.getChildNamed(cvsParentItemParent, 'CVS')
         if cvsChd.IsOk():
             tree.SelectItem(cvsChd)
-            return true
+            return True
         else:
-            return false
+            return False
 
 #---------------------------------------------------------------------------
 # Register cvs dirs as a subtype of file explorers
