@@ -5,21 +5,22 @@
 # Author:      Riaan Booysen
 #
 # Created:     2001
-# RCS-ID:      $Id: ExplorerNodes.py,v 1.32 2004/08/16 13:22:00 riaan Exp $
-# Copyright:   (c) 2001 - 2004 Riaan Booysen
+# RCS-ID:      $Id: ExplorerNodes.py,v 1.39 2007/07/02 15:01:10 riaan Exp $
+# Copyright:   (c) 2001 - 2007 Riaan Booysen
 # Licence:     GPL
 #-----------------------------------------------------------------------------
 print 'importing Explorers.ExplorerNodes'
 
 import sys, os, time, stat, copy, pprint
+from ConfigParser import ConfigParser
 
-from wxPython import wx
+import wx
 
 import Preferences, Utils
+from Utils import _
 
 from Models import EditorHelper
 import scrm
-false=0;true=1
 
 sensitive_properties = ('passwd', 'scp_pass')
 
@@ -84,38 +85,38 @@ class ExplorerClipboard:
 
 class Controller:
     Node = None
-    
+
     plugins = ()
     def __init__(self, editor):
         self.editor = editor
-        
+
         self.plugins = [Plugin(self, editor) for Plugin in self.plugins]
 
     def editorUpdateNotify(self, info=''):
         pass
 
-    def setupMenu(self, menu, win, menus, addPlugins=true):
+    def setupMenu(self, menu, win, menus, addPlugins=True):
         pluginMenuDefs = []
         if addPlugins:
             for plugin in self.plugins:
                 pluginMenuDefs.extend(plugin.menuDefs())
-            
+
         for wId, help, method, bmp in menus + pluginMenuDefs:
             if help != '-':
                 if help[0] == '+':
-                    canCheck = true
+                    canCheck = True
                     help = help[1:]
                 else:
-                    canCheck = false
+                    canCheck = False
 
                 if type(method) in (type(()), type([])):
-                    subMenu = wx.wxMenu()
+                    subMenu = wx.Menu()
                     self.setupMenu(subMenu, win, method)
                     menu.AppendMenu(wId, help, subMenu)
                 else:
                     menu.Append(wId, help, '', canCheck)
-                    wx.EVT_MENU(win, wId, method)
-                    wx.EVT_MENU(self.editor, wId, method)
+                    win.Bind(wx.EVT_MENU, method, id=wId)
+                    self.editor.Bind(wx.EVT_MENU, method, id=wId)
             else:
                 menu.AppendSeparator()
 
@@ -173,19 +174,19 @@ class ClipboardControllerMix:
          (wxID_CLIPNEWFOLDER, 'Folder', self.OnNewFolder, '-'),
          (wxID_CLIPNEWBLANKDOC, 'Blank document', self.OnNewBlankDoc, '-'),
         ]
-        self.clipMenuDef = [ (wxID_CLIPRELOAD, 'Reload', self.OnReloadItems, '-'),
+        self.clipMenuDef = [ (wxID_CLIPRELOAD, _('Reload'), self.OnReloadItems, '-'),
          (-1, '-', None, '-'),
-         (wxID_CLIPCUT, 'Cut', self.OnCutItems, self.cutBmp),
-         (wxID_CLIPCOPY, 'Copy', self.OnCopyItems, self.copyBmp),
-         (wxID_CLIPPASTE, 'Paste', self.OnPasteItems, self.pasteBmp),
+         (wxID_CLIPCUT, _('Cut'), self.OnCutItems, self.cutBmp),
+         (wxID_CLIPCOPY, _('Copy'), self.OnCopyItems, self.copyBmp),
+         (wxID_CLIPPASTE, _('Paste'), self.OnPasteItems, self.pasteBmp),
          (-1, '-', None, ''),
-         (wxID_CLIPDELETE, 'Delete', self.OnDeleteItems, self.deleteBmp),
-         (wxID_CLIPRENAME, 'Rename', self.OnRenameItems, '-'),
+         (wxID_CLIPDELETE, _('Delete'), self.OnDeleteItems, self.deleteBmp),
+         (wxID_CLIPRENAME, _('Rename'), self.OnRenameItems, '-'),
          (-1, '-', None, ''),
-         (wxID_CLIPNEWMENU, 'New', self.newMenuDef, '-'),
+         (wxID_CLIPNEWMENU, _('New'), self.newMenuDef, '-'),
          (-1, '-', None, '-'),
-         (wxID_CLIPBOOKMARK, 'Bookmark', self.OnBookmarkItems, self.bookmarkBmp),
-         (wxID_CLIPCOPYPATH, 'Copy path(s) to clipboard', self.OnCopyPath, '-'),
+         (wxID_CLIPBOOKMARK, _('Bookmark'), self.OnBookmarkItems, self.bookmarkBmp),
+         (wxID_CLIPCOPYPATH, _('Copy path(s) to clipboard'), self.OnCopyPath, '-'),
         ]
     def destroy(self):
         self.clipMenuDef = []
@@ -202,16 +203,16 @@ class ClipboardControllerMix:
 
     def OnPasteItems(self, event):
         if self.list.node:
-            wx.wxBeginBusyCursor()
+            wx.BeginBusyCursor()
             try:
                 self.list.node.clipPaste()
                 self.list.refreshCurrent()
             finally:
-                wx.wxEndBusyCursor()
+                wx.EndBusyCursor()
 
     def OnDeleteItems(self, event):
         if self.list.node:
-            wx.wxBeginBusyCursor()
+            wx.BeginBusyCursor()
             try:
                 idxs = self.list.getMultiSelection()
                 for item in self.getNodesForSelection(idxs):
@@ -220,7 +221,7 @@ class ClipboardControllerMix:
                 self.list.node.deleteItems(names)
                 self.list.refreshCurrent()
             finally:
-                wx.wxEndBusyCursor()
+                wx.EndBusyCursor()
 
     def OnRenameItems(self, event):
         self.list.EditLabel(self.list.selected)
@@ -246,11 +247,11 @@ class ClipboardControllerMix:
     def OnNewFolder(self, event):
         if self.list.node:
             name = Utils.getValidName(self.list.getAllNames(), 'Folder')
-            wx.wxBeginBusyCursor()
+            wx.BeginBusyCursor()
             try:
                 self.list.node.newFolder(name)
             finally:
-                wx.wxEndBusyCursor()
+                wx.EndBusyCursor()
             self.list.refreshCurrent()
             self.selectNewItem(name)
 
@@ -258,11 +259,11 @@ class ClipboardControllerMix:
     def OnNewBlankDoc(self, event):
         if self.list.node:
             name = Utils.getValidName(self.list.getAllNames(), 'BlankDoc')
-            wx.wxBeginBusyCursor()
+            wx.BeginBusyCursor()
             try:
                 self.list.node.newBlankDocument(name)
             finally:
-                wx.wxEndBusyCursor()
+                wx.EndBusyCursor()
             self.list.refreshCurrent()
             self.selectNewItem(name)
 
@@ -277,12 +278,12 @@ class ClipboardControllerMix:
                 if node.bookmarks:
                     node.bookmarks.add(node.getURI())
                     self.editor.statusBar.setHint(
-                          'Bookmarked %s'% node.resourcepath, 'Info')
+                          _('Bookmarked %s')% node.resourcepath, 'Info')
             else:
                 node = self.list.node
                 if not nodes and node.bookmarks:
                     node.bookmarks.add(node.getURI())
-                    self.editor.setStatus('Bookmarked %s'% node.getURI())
+                    self.editor.setStatus(_('Bookmarked %s')% node.getURI())
 
     def OnCopyPath(self, event):
         if self.list.node:
@@ -293,7 +294,7 @@ class ClipboardControllerMix:
                 paths.append(node.getURI())
             Utils.writeTextToClipboard(os.linesep.join(paths))
 
-            self.editor.setStatus('Path(s) copied to clipboard')
+            self.editor.setStatus(_('Path(s) copied to clipboard'))
 
 class TransportError(Exception):
     def __str__(self):
@@ -331,10 +332,10 @@ class ExplorerNode:
     viewMode = 'list'
     pathSep = '/'
     # Is it a stateless protocol or does it require a connection
-    connection = false
+    connection = False
     filter = ''
     # Should the node keep a reference to it's possible tree item
-    refTree = false
+    refTree = False
     def __init__(self, name, resourcepath, clipboard, imgIdx, parent=None, properties=None):
         self.name = name
         self.resourcepath = resourcepath
@@ -345,13 +346,13 @@ class ExplorerNode:
         self.parent = parent
         self.treename = name
         self.treeitem = None
-        self.bold = false
+        self.bold = False
         self.colour = None
-        self.vetoRequery = false
-        self.vetoSort = false
+        self.vetoRequery = False
+        self.vetoSort = False
         self.upImgIdx = EditorHelper.imgFolderUp
-        self.parentOpensChildren = false
-        self.ignoreParentDir = false
+        self.parentOpensChildren = False
+        self.ignoreParentDir = False
         self.category = ''
         self.stdAttrs = {'size': 0,
                          'creation-date': 0.0,
@@ -365,7 +366,7 @@ class ExplorerNode:
     def createChildNode(self, value): pass
     def openList(self): pass
     def closeList(self): pass
-    def isFolderish(self): return false
+    def isFolderish(self): return False
     def getTitle(self):
         if self.resourcepath: return self.resourcepath
         else: return self.name
@@ -382,8 +383,8 @@ class ExplorerNode:
 #---Default item actions--------------------------------------------------------
     def open(self, editor):
         return editor.openOrGotoModule(self.getURI(), transport = self)
-    def openParent(self, editor): return false
-    def checkOpenInEditor(self): return false
+    def openParent(self, editor): return False
+    def checkOpenInEditor(self): return False
 
 #---Methods on sub items--------------------------------------------------------
     def deleteItems(self, names): pass
@@ -400,14 +401,14 @@ class ExplorerNode:
         self.clipboard.clipPaste(self)
 
     def canAdd(self, paletteName):
-        return false
+        return False
 
 #---Persistance (loading and saving)--------------------------------------------
     def assertFilename(self, filename):
         """ Utility function to strip and assert the protocol from the uri """
         from Explorers.Explorer import splitURI
         prot, cat, res, uri = splitURI(filename)
-        assert self.protocol==prot, 'Illegal protocol change'
+        assert self.protocol==prot, _('Illegal protocol change')
         return res
     def currentFilename(self):
         return self.assertFilename(self.getURI())
@@ -433,7 +434,7 @@ class CachedNodeMixin:
         Not used yet
     """
     def __init__(self):
-        self.valid = false
+        self.valid = False
         self.cache = None
 
     def openList(self):
@@ -443,7 +444,7 @@ class CachedNodeMixin:
             # define this method
             self.cache = self.openList_cache()
 
-            self.valid = true
+            self.valid = True
             return self.cache
 
 class ContainerNode(ExplorerNode):
@@ -451,10 +452,10 @@ class ContainerNode(ExplorerNode):
     def __init__(self, name, imgIdx):
         ExplorerNode.__init__(self, name, '', None, imgIdx, None)
         self.entries = []
-        self.vetoRequery = true
-        self.vetoSort = true
+        self.vetoRequery = True
+        self.vetoSort = True
     def destroy(self): pass
-    def isFolderish(self): return true
+    def isFolderish(self): return True
     def createParentNode(self): return self
     def createChildNode(self, value): return value
     def openList(self): return self.entries
@@ -479,7 +480,7 @@ class CategoryNode(ExplorerNode):
     def __init__(self, name, resourcepath, clipboard, config, parent, imgIdx=EditorHelper.imgFolder):
         ExplorerNode.__init__(self, name, resourcepath, clipboard, imgIdx, parent)
         self.config = config
-        self.bold = true
+        self.bold = True
         if not self.sharedEntries.has_key(self.protocol):
             self.sharedEntries[self.itemProtocol] = copy.copy(self.entries)
         self.entries = self.sharedEntries[self.itemProtocol]
@@ -489,13 +490,12 @@ class CategoryNode(ExplorerNode):
         pass
 
     def isFolderish(self):
-        return true
+        return True
 
     def getTitle(self):
         return self.name
 
     def getConfigValue(self):
-        from ExternalLib import ConfigParser
         try:
             return eval(self.config.get(self.resourcepath[cat_section],
                         self.resourcepath[cat_option]), {})
@@ -532,7 +532,7 @@ class CategoryNode(ExplorerNode):
             try:
                 del self.entries[name]
             except KeyError:
-                wx.wxLogWarning('Could not find %s in %s for deletion'%(name,
+                wx.LogWarning(_('Could not find %s in %s for deletion')%(name,
                       self.entries.keys()))
         self.updateConfig()
 
@@ -540,9 +540,9 @@ class CategoryNode(ExplorerNode):
     def renameItem(self, name, newName):
         for ill_substr in self.illegal_substrs:
             if newName.find(ill_substr) != -1:
-                raise Exception('Contains invalid string sequence or char: "%s"'%ill_substr)
+                raise Exception, _('Contains invalid string sequence or char: "%s"')%ill_substr
         if self.entries.has_key(newName):
-            raise Exception, 'Name exists'
+            raise Exception, _('Name exists')
         self.entries[newName] = self.entries[name]
         del self.entries[name]
         self.updateConfig()
@@ -555,19 +555,19 @@ class CategoryNode(ExplorerNode):
 
     def updateConfig(self):
         assert type(self.entries) is type(self.__class__.entries), \
-               'Entries type %s invalid, expected %s'%(str(type(self.entries)),
+               _('Entries type %s invalid, expected %s')%(str(type(self.entries)),
                                               str(type(self.__class__.entries)))
         self.config.set(self.resourcepath[cat_section],
                   self.resourcepath[cat_option], pprint.pformat(self.entries))
         Utils.writeConfig(self.config)
-    
+
     def copyCatFrom(self, node):
         name = Utils.getValidName(self.entries.keys(), node.name or node.treename)
         self.entries[name] = copy.copy(node.properties)
         self.updateConfig()
 
 
-(wxID_CATNEW, wxID_CATINSPECT, wxID_CATCOPY, wxID_CATDELETE, wxID_CATRENAME, 
+(wxID_CATNEW, wxID_CATINSPECT, wxID_CATCOPY, wxID_CATDELETE, wxID_CATRENAME,
  wxID_CATRELOAD) = Utils.wxNewIds(6)
 
 class CategoryController(Controller):
@@ -580,17 +580,17 @@ class CategoryController(Controller):
     def __init__(self, editor, list, inspector, controllers, menuDefs = []):
         Controller.__init__(self, editor)
         self.list = list
-        self.menu = wx.wxMenu()
+        self.menu = wx.Menu()
         self.inspector = inspector
 
-        self.catMenuDef = [ (wxID_CATNEW, 'New', self.OnNewItem, self.newBmp),
-                            (wxID_CATINSPECT, 'Inspect', self.OnInspectItem, self.inspectBmp),
-                            (wxID_CATRELOAD, 'Reload', self.OnReloadItems, '-'),
+        self.catMenuDef = [ (wxID_CATNEW, _('New'), self.OnNewItem, self.newBmp),
+                            (wxID_CATINSPECT, _('Inspect'), self.OnInspectItem, self.inspectBmp),
+                            (wxID_CATRELOAD, _('Reload'), self.OnReloadItems, '-'),
                             (-1, '-', None, ''),
-                            (wxID_CATCOPY, 'Create copy', self.OnCreateCopy, self.copyBmp),
+                            (wxID_CATCOPY, _('Create copy'), self.OnCreateCopy, self.copyBmp),
                             (-1, '-', None, ''),
-                            (wxID_CATDELETE, 'Delete', self.OnDeleteItems, self.deleteBmp),
-                            (wxID_CATRENAME, 'Rename', self.OnRenameItem, '-') ]
+                            (wxID_CATDELETE, _('Delete'), self.OnDeleteItems, self.deleteBmp),
+                            (wxID_CATRENAME, _('Rename'), self.OnRenameItem, '-') ]
 
         self.setupMenu(self.menu, self.list, self.catMenuDef + menuDefs)
         self.toolbarMenus = [self.catMenuDef + menuDefs]
@@ -608,7 +608,7 @@ class CategoryController(Controller):
             catComp = self.list.node.createCatCompanion(catItem)
             catComp.updateProps()
 
-            self.inspector.selectObject(catComp, false, focusPage=1, restore=true)
+            self.inspector.selectObject(catComp, False, focusPage=1, restore=True)
 
     def OnNewItem(self, event):
         if self.list.node:
@@ -640,15 +640,15 @@ class CategoryController(Controller):
                 self.list.node.copyCatFrom(node)
 
             self.list.refreshCurrent()
-    
+
 class BookmarksCatNode(CategoryNode):
     """ Stores folderish references to any transport protocol """
     #protocol = 'config.bookmark'
-    defName = 'Bookmark'
+    defName = _('Bookmark')
     defaultStruct = Preferences.explorerFileSysRootDefault[1]
-    refTree = true
+    refTree = True
     def __init__(self, clipboards, config, parent, catTransports, tree=None,
-          name='Bookmarks', confSpec=('explorer', 'bookmarks')):
+          name=_('Bookmarks'), confSpec=('explorer', 'bookmarks')):
         CategoryNode.__init__(self, name, confSpec, None, config, parent)
         self.catTransports = catTransports
         self.tree = tree
@@ -705,7 +705,7 @@ class BookmarksCatNode(CategoryNode):
         # XXX if under bookmarks when adding bookmarks, tree is rebuilt and
         # XXX position in tree is lost
         # XXX At least update list when Bookmarks node is selected.
-        
+
         #if self.tree and self.treeitem and self.treeitem.IsOk():
         #    if self.tree.IsExpanded(self.treeitem):
         #        self.tree.CollapseAndReset(self.treeitem)
@@ -724,7 +724,7 @@ class SubBookmarksCatNode(BookmarksCatNode):
         self._entries = bookmarks
         BookmarksCatNode.__init__(self, parent.clipboards, parent.config,
               parent, parent.catTransports, parent.tree)
-        self.bold = false
+        self.bold = False
         self.name = self.treename = name
 
     def refresh(self):
@@ -738,15 +738,15 @@ class SubBookmarksCatNode(BookmarksCatNode):
 
 class MRUCatNode(BookmarksCatNode):
     protocol = 'recent.files'
-    defName = 'Recent files'
+    defName = _('Recent files')
     entries = []
     defaultStruct = ''
     def __init__(self, clipboards, config, parent, catTransports, tree):
         BookmarksCatNode.__init__(self, clipboards, config, parent,
-              catTransports, tree, 'Recent files', ('explorer', 'recentfiles'))
-        self.vetoSort = true
+              catTransports, tree, _('Recent files'), ('explorer', 'recentfiles'))
+        self.vetoSort = True
         self.imgIdx = EditorHelper.imgRecentFiles
-        self.ignoreParentDir = true
+        self.ignoreParentDir = True
 
     def openList(self):
         res = []
@@ -769,7 +769,7 @@ class MRUCatNode(BookmarksCatNode):
         self.entries.insert(0, respath)
 
         if len(self.entries) > Preferences.exRecentFilesListSize:
-            self.entries[-Preferences.exRecentFilesListSize:] = []
+            self.entries[Preferences.exRecentFilesListSize:] = []
 
         self.updateConfig()
 
@@ -799,15 +799,15 @@ class MRUCatController(Controller):
     def __init__(self, editor, list, inspector, controllers, menuDefs = []):
         Controller.__init__(self, editor)
         self.list = list
-        self.menu = wx.wxMenu()
+        self.menu = wx.Menu()
         self.inspector = inspector
 
-        self.mruMenuDef = [ 
-            (wxID_MRUOPEN, 'Open', self.OnOpenItems, '-'),
+        self.mruMenuDef = [
+            (wxID_MRUOPEN, _('Open'), self.OnOpenItems, '-'),
             (-1, '-', None, '-'),
-            (wxID_MRURELOAD, 'Reload', self.OnReloadItems, '-'),
+            (wxID_MRURELOAD, _('Reload'), self.OnReloadItems, '-'),
             (-1, '-', None, ''),
-            (wxID_MRUREMOVE, 'Remove', self.OnRemoveItems, self.deleteBmp)
+            (wxID_MRUREMOVE, _('Remove'), self.OnRemoveItems, self.deleteBmp)
         ]
 
         self.setupMenu(self.menu, self.list, self.mruMenuDef + menuDefs)
@@ -823,12 +823,12 @@ class MRUCatController(Controller):
     def createRecentFilesMenu(self):
         # XXX not finished yet
         self.recentItemsMenuIds = {}
-        menu = wxMenu()
+        menu = wx.Menu()
         for node in self.list.node.openList():
             if node.name not in self.recentItemsMenuIds.values():
-                wid = wxNewId()
+                wid = wx.NewId()
                 self.recentItemsMenuIds[wid] = node.name
-                EVT_MENU(self.list, wid, self.OnMRUMenuItemSelect)
+                self.list.Bind(wx.EVT_MENU, self.OnMRUMenuItemSelect, id=wid)
             else:
                 for wid, name in self.recentItemsMenuIds.items():
                     if name == node.name:
@@ -896,7 +896,7 @@ class ExplorerCompanion(Companion):
     def persistProp(self, name, setterName, value):
         pass
     def propIsDefault(self, name, setterName):
-        return true
+        return True
     def persistedPropVal(self, name, setterName):
         return ''
 
@@ -978,8 +978,8 @@ class CategoryDictCompanion(CategoryCompanion):
         # scramble sensitive properties before saving
         try:
             if not self.catNode.entries.has_key(self.name):
-                raise Exception('%s not found in the config, renaming config '\
-                            'entries while Inspecting is not allowed.'%self.name)
+                raise Exception(_('%s not found in the config, renaming config '
+                          'entries while Inspecting is not allowed.')%self.name)
 
             entry = self.catNode.entries[self.name]
             entry[name] = value
@@ -999,7 +999,7 @@ class CategoryDictCompanion(CategoryCompanion):
             for entry, key, val in scrams:
                 entry[key] = val
 
-        return true
+        return True
 
 class CategoryStringCompanion(CategoryCompanion):
     def getPropertyItems(self):
@@ -1018,8 +1018,8 @@ def uriSplitNone(filename, filepath):
     return 'none', '', filepath, filename
 
 #-Registry for explorer nodes-------------------------------------------------
-# Successfully loaded modules from the 
-# Explorer.*.cfg [explorers] installedtransports import list are recorded here. 
+# Successfully loaded modules from the
+# Explorer.*.cfg [explorers] installedtransports import list are recorded here.
 # Explorer Plug-ins bypassing the Explorer imports should add themselves
 # to this list to have their controller classes hooked into the IDE
 installedModules = []
@@ -1043,12 +1043,12 @@ all_transports = None
 explorerNodeReg = {}
 nodeRegByProt = {}
 # List of protocols that don't have Category nodes, and must be created
-# at the top level of the tree 
+# at the top level of the tree
 explorerRootNodesReg = []
 
 
-def register(Node, clipboard=None, confdef=('', ''), controller=None, 
-             category=None, root=false):
+def register(Node, clipboard=None, confdef=('', ''), controller=None,
+             category=None, root=False):
     """ Register a new explorer Node.
 
     clipboard  : Clipboard class or protocol name (string) of existing clipboard
@@ -1061,7 +1061,7 @@ def register(Node, clipboard=None, confdef=('', ''), controller=None,
     explorerNodeReg[Node] = {'clipboard': clipboard, 'confdef': confdef,
                              'controller': controller, 'category': category}
     nodeRegByProt[Node.protocol] = Node
-    
+
     if root:
         explorerRootNodesReg.append(Node.protocol)
 
