@@ -5,17 +5,18 @@
 # Author:      Riaan Booysen
 #
 # Created:     2001/03/06
-# RCS-ID:      $Id: FileExplorer.py,v 1.24 2004/08/16 13:22:00 riaan Exp $
-# Copyright:   (c) 2001 - 2004 Riaan Booysen
+# RCS-ID:      $Id: FileExplorer.py,v 1.31 2007/07/02 15:01:10 riaan Exp $
+# Copyright:   (c) 2001 - 2007 Riaan Booysen
 # Licence:     GPL
 #-----------------------------------------------------------------------------
 print 'importing Explorers.FileExplorer'
 
-import os, time, stat
+import os, time, stat, sys
 
-from wxPython.wx import *
+import wx
 
 import Preferences, Utils
+from Utils import _
 
 import ExplorerNodes
 from Models import Controllers, EditorHelper
@@ -26,11 +27,11 @@ class FileSysCatNode(ExplorerNodes.CategoryNode):
     itemProtocol = 'file'
     defName, defaultStruct = Preferences.explorerFileSysRootDefault
     def __init__(self, clipboard, config, parent, bookmarks):
-        ExplorerNodes.CategoryNode.__init__(self, 'Filesystem', ('explorer', 'file'),
+        ExplorerNodes.CategoryNode.__init__(self, _('Filesystem'), ('explorer', 'file'),
               clipboard, config, parent)
         self.bookmarks = bookmarks
 
-        if not self.entries and wxPlatform == '__WXMSW__':
+        if not self.entries and wx.Platform == '__WXMSW__':
             drives = {}
             for x in range(ord('C'), ord('Z')+1):
                 driveName = '%s:\\'%(chr(x))
@@ -39,7 +40,7 @@ class FileSysCatNode(ExplorerNodes.CategoryNode):
 
             self.entries = drives
             self.updateConfig()
-            wxLogMessage('%d drives added to the filesystem definition.'%len(drives))
+            wx.LogMessage(_('%d drives added to the filesystem definition.')%len(drives))
 
     def createParentNode(self):
         return self.parent
@@ -48,7 +49,7 @@ class FileSysCatNode(ExplorerNodes.CategoryNode):
         comp = ExplorerNodes.CategoryStringCompanion(catNode.treename, self)
         return comp
 
-    def createChildNode(self, entry, value, forceFolder=true):
+    def createChildNode(self, entry, value, forceFolder=True):
         if forceFolder: Node = NonCheckPyFolderNode
         else: Node = FileSysNode
 
@@ -68,20 +69,20 @@ class FileSysCatNode(ExplorerNodes.CategoryNode):
 
     def renameItem(self, name, newName):
         if self.entries.has_key(newName):
-            raise Exception, 'Name exists'
+            raise Exception, _('Name exists')
         self.entries[newName] = newName
         del self.entries[name]
         self.updateConfig()
 
-    def getNodeFromPath(self, respath, forceFolder=true):
+    def getNodeFromPath(self, respath, forceFolder=True):
         cn = self.createChildNode(os.path.basename(respath), respath, forceFolder)
         return cn
 
 
-(wxID_FSOPEN, wxID_FSTEST, wxID_FSNEW, wxID_FSNEWFOLDER, wxID_FSCVS,
+(wxID_FSOPEN, wxID_FSTEST, wxID_FSNEW, wxID_FSNEWFOLDER, wxID_FSCVS, wxID_FSSVN,
  wxID_FSBOOKMARK, wxID_FSFINDINFILES, wxID_FSFINDFILES, wxID_FSFILTERIMAGES,
  wxID_FSSETASCWD, wxID_FSNEWZIP, wxID_FSINSPECT,
-) = Utils.wxNewIds(12)
+) = Utils.wxNewIds(13)
 
 (wxID_FSFILTER, wxID_FSFILTERBOAMODULES, wxID_FSFILTERSTDMODULES,
  wxID_FSFILTERINTMODULES, wxID_FSFILTERALLMODULES,
@@ -89,18 +90,18 @@ class FileSysCatNode(ExplorerNodes.CategoryNode):
 
 filterDescrOrd = ['BoaFiles', 'StdFiles', 'BoaIntFiles', 'ImageFiles', 'AllFiles']
 
-filterDescr = {'BoaFiles': ('Boa files', wxID_FSFILTERBOAMODULES),
-               'StdFiles': ('Standard files', wxID_FSFILTERSTDMODULES),
-               'BoaIntFiles': ('Internal files', wxID_FSFILTERINTMODULES),
-               'ImageFiles': ('Image files', wxID_FSFILTERIMAGES),
-               'AllFiles': ('All files', wxID_FSFILTERALLMODULES)}
+filterDescr = {'BoaFiles': (_('Boa files'), wxID_FSFILTERBOAMODULES),
+               'StdFiles': (_('Standard files'), wxID_FSFILTERSTDMODULES),
+               'BoaIntFiles': (_('Internal files'), wxID_FSFILTERINTMODULES),
+               'ImageFiles': (_('Image files'), wxID_FSFILTERIMAGES),
+               'AllFiles': (_('All files'), wxID_FSFILTERALLMODULES)}
 
 # XXX CVS and Zip support must also move to registering
 class FileSysController(ExplorerNodes.Controller, ExplorerNodes.ClipboardControllerMix):
     bookmarkBmp = 'Images/Shared/Bookmark.png'
     findBmp = 'Images/Shared/Find.png'
     inspectBmp = 'Images/Shared/Inspector.png'
-    
+
     def __init__(self, editor, list, inspector, controllers):
         ExplorerNodes.Controller.__init__(self, editor)
         ExplorerNodes.ClipboardControllerMix.__init__(self)
@@ -113,25 +114,25 @@ class FileSysController(ExplorerNodes.Controller, ExplorerNodes.ClipboardControl
 ##        else:
 ##            self.cvsController = None
 
-        self.menu = wxMenu()
+        self.menu = wx.Menu()
 
         self.fileMenuDef = [
-              (wxID_FSOPEN, 'Open', self.OnOpenItems, '-'),
+              (wxID_FSOPEN, _('Open'), self.OnOpenItems, '-'),
+              (-1, '-', None, ''),
+              (wxID_FSINSPECT, _('Inspect'), self.OnInspectItem, self.inspectBmp),
               (-1, '-', None, ''),
-              (wxID_FSINSPECT, 'Inspect', self.OnInspectItem, self.inspectBmp),
-              (-1, '-', None, ''), 
         ] + self.clipMenuDef + [
-              (wxID_FSSETASCWD, 'Set as os.cwd', self.OnSetAsSysCwd, '-'),
+              (wxID_FSSETASCWD, _('Set as os.cwd'), self.OnSetAsSysCwd, '-'),
               (-1, '-', None, ''),
-              (wxID_FSFINDINFILES, 'Find', self.OnFindFSItem, self.findBmp),
+              (wxID_FSFINDINFILES, _('Find'), self.OnFindFSItem, self.findBmp),
         ]
-        
+
         if controllers.has_key('zip'):
             self.newMenuDef.append(
-             (wxID_FSNEWZIP, 'Empty zip archive', self.OnEmptyZipArchive, '-') )
+             (wxID_FSNEWZIP, _('Empty zip archive'), self.OnEmptyZipArchive, '-') )
         if controllers.has_key('tar.gz'):
             self.newMenuDef.append(
-             (wxID_FSNEWZIP, 'Empty tar.gz archive', self.OnEmptyTarGzipArchive, '-') )
+             (wxID_FSNEWZIP, _('Empty tar.gz archive'), self.OnEmptyTarGzipArchive, '-') )
 
         self.setupMenu(self.menu, self.list, self.fileMenuDef)
 
@@ -141,16 +142,19 @@ class FileSysController(ExplorerNodes.Controller, ExplorerNodes.ClipboardControl
             filters.append( (wid, '+'+descr, self.OnFilterFSItems , '-') )
 
         self.fileFilterMenuDef = filters
-        self.fileFilterMenu = wxMenu()
-        self.setupMenu(self.fileFilterMenu, self.list, self.fileFilterMenuDef, false)
+        self.fileFilterMenu = wx.Menu()
+        self.setupMenu(self.fileFilterMenu, self.list, self.fileFilterMenuDef, False)
 
         # Check default option
-        self.fileFilterMenu.Check(wxID_FSFILTERBOAMODULES, true)
+        self.fileFilterMenu.Check(wxID_FSFILTERBOAMODULES, True)
 
-        self.menu.AppendMenu(wxID_FSFILTER, 'Filter', self.fileFilterMenu)
+        self.menu.AppendMenu(wxID_FSFILTER, _('Filter'), self.fileFilterMenu)
 
+        # XXX this should not be done here
         if controllers.has_key('cvs'):
             self.menu.AppendMenu(wxID_FSCVS, 'CVS', controllers['cvs'].fileCVSMenu)
+        if controllers.has_key('svn'):
+            self.menu.AppendMenu(wxID_FSSVN, 'SVN', controllers['svn'].fileSVNMenu)
 
         self.toolbarMenus = [self.fileMenuDef]
 
@@ -166,7 +170,7 @@ class FileSysController(ExplorerNodes.Controller, ExplorerNodes.ClipboardControl
 
     def OnFilterFSItems(self, event):
         evtid = event.GetId()
-        self.groupCheckMenu(self.fileFilterMenu, self.fileFilterMenuDef, evtid, true)
+        self.groupCheckMenu(self.fileFilterMenu, self.fileFilterMenuDef, evtid, True)
         for filter in filterDescrOrd:
             descr, wid = filterDescr[filter]
             if wid == evtid:
@@ -180,7 +184,7 @@ class FileSysController(ExplorerNodes.Controller, ExplorerNodes.ClipboardControl
         """
         nd = self.list.node
         if not isinstance( self.list.node, ResultsFolderNode ):
-            self.list.node = ResultsFolderNode('Results', nd.resourcepath,
+            self.list.node = ResultsFolderNode(_('Results'), nd.resourcepath,
                   nd.clipboard, -1, nd, nd.bookmarks)
 
         mapFindInFileCount = {}
@@ -212,14 +216,14 @@ class FileSysController(ExplorerNodes.Controller, ExplorerNodes.ClipboardControl
         if os.path.isfile(path): path = os.path.split(path)[0]
         os.chdir(path)
 
-        self.editor.setStatus('Updated os.cwd to %s'%path, ringBell=true)
+        self.editor.setStatus(_('Updated os.cwd to %s')%path, ringBell=True)
 
     def OnEmptyZipArchive(self, event):
         # must move to zip
         files = os.listdir(self.list.node.resourcepath)
         newName = Utils.getValidName(files, 'archive', 'zip')
         import zipfile
-        zipfile.ZipFile(os.path.join(self.list.node.resourcepath, newName), 'w', 
+        zipfile.ZipFile(os.path.join(self.list.node.resourcepath, newName), 'w',
               zipfile.ZIP_DEFLATED).close()
 
         self.list.refreshCurrent()
@@ -228,27 +232,27 @@ class FileSysController(ExplorerNodes.Controller, ExplorerNodes.ClipboardControl
 
     def OnEmptyTarGzipArchive(self, event):
         pass
-                
+
     def OnInspectItem(self, event):
         if self.list.node:
             item = self.list.getSelection()
             if item:
                 comp = FileSysCompanion(item.name, item)
                 comp.updateProps()
-                self.inspector.selectObject(comp, false, focusPage=1)        
+                self.inspector.selectObject(comp, False, focusPage=1)
 
 
 
 class FileSysAttrPropEdit(PropertyEditors.PropertyEditor):
     def inspectorEdit(self):
-        self.editorCtrl = InspectorEditorControls.BeveledLabelIEC(self, 
+        self.editorCtrl = InspectorEditorControls.BeveledLabelIEC(self,
               self.getValue())
         self.editorCtrl.createControl(self.parent, self.idx, self.width)
         self.editorCtrl.setValue(self.getValue())
 
     def getDisplayValue(self):
         return self.value
-    
+
 
 class FileSysCompanion(ExplorerNodes.ExplorerCompanion):
     def __init__(self, name, fsNode):
@@ -266,8 +270,8 @@ class FileSysCompanion(ExplorerNodes.ExplorerCompanion):
         for date in ('creation-date', 'modify-date', 'access-date'):
             value = attrs[date]
             if value:
-                res.append( (date, 
-                             time.strftime(self.timeFmt, time.gmtime(value))) )
+                res.append( (date,
+                             time.strftime(self.timeFmt, time.localtime(value))) )
 
         value = attrs['read-only']
         res.append( ('read-only', value and 'True' or 'False') )
@@ -316,7 +320,7 @@ class FileSysNode(ExplorerNodes.ExplorerNode):
     filter = 'BoaFiles'
     lastSearch = ''
     subExplorerReg = {'file': [], 'folder': []}
-    connection = false
+    connection = False
     pathSep = os.sep
     def __init__(self, name, resourcepath, clipboard, imgIdx, parent=None,
           bookmarks=None, properties={}):
@@ -327,8 +331,8 @@ class FileSysNode(ExplorerNodes.ExplorerNode):
         self.entries = []
 
         # XXX not used ?
-        self.doCVS = true
-        self.doZip = true
+        self.doCVS = True
+        self.doZip = True
         self.allowedProtocols = ['*']
         self.updateStdAttrs()
 
@@ -370,8 +374,8 @@ class FileSysNode(ExplorerNodes.ExplorerNode):
                     if issubclass(Model, SubTypeModel):
                         break
                 else:
-                    return '', None    
-            return 'mod', FileSysNode(file, filename, self.clipboard, 
+                    return '', None
+            return 'mod', FileSysNode(file, filename, self.clipboard,
               Model.imgIdx, self, self.bookmarks, {})
               #{'datetime': time.strftime('%a %b %d %H:%M:%S %Y',
               #             time.gmtime(os.stat(filename)[stat.ST_MTIME]))})
@@ -391,7 +395,16 @@ class FileSysNode(ExplorerNodes.ExplorerNode):
 
     def openList(self):
         try:
-            files = os.listdir(self.resourcepath)
+            #----------------------------------------
+            # A hack for locally-encoded filesystems:
+            # We need to convert filesystem names
+            # from local encoding to unicode
+            if type(self.resourcepath) is str:
+                files = os.listdir(self.resourcepath.decode(
+                      sys.getfilesystemencoding()))
+            else: # unicode or other
+                files = os.listdir(self.resourcepath)
+            #---------------------------------------- 
         except Exception, err:
             raise ExplorerNodes.TransportError(err)
         files.sort()
@@ -474,11 +487,11 @@ class FileSysNode(ExplorerNodes.ExplorerNode):
 
     def getFilterExts(self):
         return {'BoaFiles': (self.exts, {}),
-                'StdFiles': (self.exts, {}), 
-                'BoaIntFiles': (EditorHelper.internalFilesReg, {}), 
-                'ImageFiles': (EditorHelper.imageExtReg, 
+                'StdFiles': (self.exts, {}),
+                'BoaIntFiles': (EditorHelper.internalFilesReg, {}),
+                'ImageFiles': (EditorHelper.imageExtReg,
                                EditorHelper.imageSubTypeExtReg),
-                'AllFiles': (['.*'], {})}[self.filter]
+                'AllFiles': (['.*'], {})}.get(self.filter, (self.exts, {}))
 
     def load(self, mode='rb'):
         try:
@@ -488,14 +501,14 @@ class FileSysNode(ExplorerNodes.ExplorerNode):
         except IOError, error:
             raise ExplorerNodes.TransportLoadError(error, self.resourcepath)
 
-    def save(self, filename, data, mode='wb', overwriteNewer=false):
+    def save(self, filename, data, mode='wb', overwriteNewer=False):
         if self.resourcepath != filename:
             self.resourcepath = filename
             self.name = os.path.basename(self.resourcepath)
         try:
             if not overwriteNewer and self.fileIsNewer():
-                raise ExplorerNodes.TransportModifiedSaveError('This file has '
-                  'been saved by someone else since it was loaded',
+                raise ExplorerNodes.TransportModifiedSaveError(_('This file has '
+                  'been saved by someone else since it was loaded'),
                   self.resourcepath)
             open(self.resourcepath, mode).write(data)
         except IOError, error:
@@ -533,7 +546,7 @@ class FileSysNode(ExplorerNodes.ExplorerNode):
 class ResultsFolderNode(FileSysNode):
     results = []
     def openList(self):
-        self.parentOpensChildren = true
+        self.parentOpensChildren = True
         self.results.sort()
         self.results.reverse()
         entries = []
@@ -549,7 +562,7 @@ class ResultsFolderNode(FileSysNode):
 
     def openParent(self, editor):
         editor.explorer.tree.SelectItem(editor.explorer.tree.GetSelection())
-        return true
+        return True
 
     def open(self, node, editor):
         mod, cntrl = node.open(editor)
@@ -560,11 +573,11 @@ class ResultsFolderNode(FileSysNode):
         return mod, cntrl
 
     def getTitle(self):
-        return 'Find results for %s in %s' % (self.lastSearch, self.resourcepath)
+        return _('Find results for %s in %s') % (self.lastSearch, self.resourcepath)
 
 class NonCheckPyFolderNode(FileSysNode):
     def isFolderish(self):
-        return true
+        return True
 
 class CurWorkDirNode(FileSysNode):
     protocol = 'os.cwd'
@@ -573,7 +586,7 @@ class CurWorkDirNode(FileSysNode):
         FileSysNode.__init__(self, 'os.cwd', self.cwd, clipboard,
               EditorHelper.imgPathFolder, parent)
         self.bookmarks = bookmarks
-        self.bold = true
+        self.bold = True
         #self.setFilter('AllFiles')
 
     def openList(self):
@@ -591,17 +604,17 @@ def uriSplitFile(filename, filepath):
 def findFileExplorerNode(category, respath, transports):
     for tp in transports.entries:
         if tp.itemProtocol == 'file':
-            return tp.getNodeFromPath(respath, forceFolder=false)
+            return tp.getNodeFromPath(respath, forceFolder=False)
     raise ExplorerNodes.TransportError(
-          'FileSysCatNode not found in transports %s'%transports.entries)
+          _('FileSysCatNode not found in transports %s')%transports.entries)
 
 #-------------------------------------------------------------------------------
 ExplorerNodes.register(FileSysNode, clipboard=FileSysExpClipboard,
       confdef=('explorer', 'file'), controller=FileSysController,
       category=FileSysCatNode)
-ExplorerNodes.register(CurWorkDirNode, clipboard='file', controller='file', 
+ExplorerNodes.register(CurWorkDirNode, clipboard='file', controller='file',
       root=True)
 ExplorerNodes.fileOpenDlgProtReg.append('file')
 ExplorerNodes.uriSplitReg[('file', 2)] = uriSplitFile
 ExplorerNodes.uriSplitReg[('os.cwd', 2)] = uriSplitFile
-ExplorerNodes.transportFindReg['file'] = findFileExplorerNode
\ No newline at end of file
+ExplorerNodes.transportFindReg['file'] = findFileExplorerNode
