@@ -5,8 +5,8 @@
 # Author:      Riaan Booysen
 #
 # Created:     1999
-# RCS-ID:      $Id: Palette.py,v 1.36 2004/08/16 12:45:39 riaan Exp $
-# Copyright:   (c) 1999 - 2004 Riaan Booysen
+# RCS-ID:      $Id: Palette.py,v 1.45 2007/07/02 15:01:04 riaan Exp $
+# Copyright:   (c) 1999 - 2007 Riaan Booysen
 # Licence:     GPL
 #----------------------------------------------------------------------
 #Boa:Frame:BoaFrame
@@ -15,67 +15,67 @@ print 'importing Palette'
 
 import os, sys
 
-from wxPython.wx import *
+import wx
 
-import PaletteMapping, PaletteStore
+import PaletteStore
 import Help, Preferences, Utils, Plugins
-
 from Preferences import IS, flatTools
+from Utils import _
 
-from wxPython.lib.buttons import wxGenButton, wxGenBitmapButton, wxGenToggleButton, wxGenBitmapToggleButton, wxGenButtonEvent
+import wx.lib.buttons
 
 currentMouseOverTip = ''
 
 
-[wxID_BOAFRAME, wxID_BOAFRAMECONTEXTHELPSEARCH, wxID_BOAFRAMEPALETTE,
- wxID_BOAFRAMETOOLBAR,
-] = map(lambda _init_ctrls: wxNewId(), range(4))
+[wxID_BOAFRAME, wxID_BOAFRAMEPALETTE, wxID_BOAFRAMETOOLBAR, 
+] = [wx.NewId() for _init_ctrls in range(3)]
 
-[wxID_BOAFRAMETOOLBARTOOLS0, wxID_BOAFRAMETOOLBARTOOLS1,
- wxID_BOAFRAMETOOLBARTOOLS2,
-] = map(lambda _init_coll_toolBar_Tools: wxNewId(), range(3))
+[wxID_BOAFRAMETOOLBARTOOLS0, wxID_BOAFRAMETOOLBARTOOLS1, 
+] = [wx.NewId() for _init_coll_toolBar_Tools in range(2)]
+
+class BoaFrame(wx.Frame, Utils.FrameRestorerMixin):
+
+    paletteIcon = 'Images/Icons/Boa.ico'
 
-class BoaFrame(wxFrame, Utils.FrameRestorerMixin):
     def _init_coll_toolBar_Tools(self, parent):
         # generated method, don't edit
 
         parent.AddTool(bitmap=IS.load('Images/Shared/Inspector.png'),
-              id=wxID_BOAFRAMETOOLBARTOOLS0, isToggle=false, longHelpString='',
-              pushedBitmap=wxNullBitmap,
-              shortHelpString='Brings the Inspector to the front')
+              id=wxID_BOAFRAMETOOLBARTOOLS0, isToggle=False, longHelpString='',
+              pushedBitmap=wx.NullBitmap,
+              shortHelpString=_('Brings the Inspector to the front'))
         parent.AddTool(bitmap=IS.load('Images/Shared/Editor.png'),
-              id=wxID_BOAFRAMETOOLBARTOOLS1, isToggle=false, longHelpString='',
-              pushedBitmap=wxNullBitmap,
-              shortHelpString='Brings the Editor to the front')
-        EVT_TOOL(self, wxID_BOAFRAMETOOLBARTOOLS0, self.OnInspectorToolClick)
-        EVT_TOOL(self, wxID_BOAFRAMETOOLBARTOOLS1, self.OnEditorToolClick)
+              id=wxID_BOAFRAMETOOLBARTOOLS1, isToggle=False, longHelpString='',
+              pushedBitmap=wx.NullBitmap,
+              shortHelpString=_('Brings the Editor to the front'))
+        self.Bind(wx.EVT_TOOL, self.OnInspectorToolClick,
+              id=wxID_BOAFRAMETOOLBARTOOLS0)
+        self.Bind(wx.EVT_TOOL, self.OnEditorToolClick,
+              id=wxID_BOAFRAMETOOLBARTOOLS1)
 
         parent.Realize()
 
-    def _init_utils(self):
-        # generated method, don't edit
-        pass
-
     def _init_ctrls(self, prnt):
         # generated method, don't edit
-        wxFrame.__init__(self, id=wxID_BOAFRAME, name='', parent=prnt,
-              pos=wxPoint(116, 275), size=wxSize(645, 74),
-              style=wxSYSTEM_MENU | wxRESIZE_BORDER | wxCAPTION | wxMINIMIZE_BOX,
+        wx.Frame.__init__(self,
+              #style=wx.SYSTEM_MENU | wx.RESIZE_BORDER | wx.CAPTION | wx.MINIMIZE_BOX,
+              id=wxID_BOAFRAME, name='', parent=prnt, pos=wx.Point(116, 275),
+              size=wx.Size(645, 74),
+              style=wx.DEFAULT_FRAME_STYLE& ~wx.MAXIMIZE_BOX,
               title=self.frameTitle)
-        self._init_utils()
-        self.SetClientSize(wxSize(637, 47))
-        EVT_CLOSE(self, self.OnCloseWindow)
-        EVT_ICONIZE(self, self.OnBoaframeIconize)
+        self.SetClientSize(wx.Size(637, 47))
+        self.Bind(wx.EVT_CLOSE, self.OnCloseWindow)
+        self.Bind(wx.EVT_ICONIZE, self.OnBoaframeIconize)
 
-        self.toolBar = wxToolBar(id=wxID_BOAFRAMETOOLBAR, name='toolBar',
-              parent=self, pos=wxPoint(0, 0), size=wxSize(637, 24),
-              style=wxTB_HORIZONTAL | wxNO_BORDER | Preferences.flatTools)
-        self._init_coll_toolBar_Tools(self.toolBar)
+        self.toolBar = wx.ToolBar(id=wxID_BOAFRAMETOOLBAR, name='toolBar',
+              parent=self, pos=wx.Point(0, 0), size=wx.Size(637, 24),
+              style=wx.TB_HORIZONTAL | wx.NO_BORDER | Preferences.flatTools)
         self.SetToolBar(self.toolBar)
 
-        self.palette = wxNotebook(id=wxID_BOAFRAMEPALETTE, name='palette',
-              parent=self, pos=wxPoint(0, 24), size=wxSize(637, 23), style=0)
+        self.palette = wx.Notebook(id=wxID_BOAFRAMEPALETTE, name='palette',
+              parent=self, pos=wx.Point(0, 24), size=wx.Size(637, 23), style=0)
 
+        self._init_coll_toolBar_Tools(self.toolBar)
 
     def __init__(self, parent, id, app):
         self.frameTitle = 'Boa Constructor - Python IDE & wxPython GUI Builder'
@@ -88,15 +88,15 @@ class BoaFrame(wxFrame, Utils.FrameRestorerMixin):
 
         self.paletteStyle = Preferences.paletteStyle
         if self.paletteStyle == 'menu':
-            self.menuBar = wxMenuBar()
+            self.menuBar = wx.MenuBar()
             self.SetMenuBar(self.menuBar)
-            self.palette.Show(false)
+            self.palette.Show(False)
 
         self.app = app
-        self.destroying = false
+        self.destroying = False
 
         self.widgetSet = {}
-        self.SetIcon(IS.load('Images/Icons/Boa.ico'))
+        self.SetIcon(IS.load(self.paletteIcon))
 
         self.browser = None
 
@@ -113,37 +113,36 @@ class BoaFrame(wxFrame, Utils.FrameRestorerMixin):
         self.paletteHelpItems = eval(conf.get('help', 'palettehelp'), {})
 
         self.toolBar.AddSeparator()
-        self.addTool('Images/Shared/Help', 'Boa or selected component help',
-              'Show help', self.OnHelpToolClick)
-        self.addTool('Images/Shared/wxWinHelp', 'wxPython help',
-              'Show help', self.OnWxWinHelpToolClick)
-        self.addTool('Images/Shared/PythonHelp', 'Python help',
-              'Show help', self.OnPythonHelpToolClick)
+        self.addTool('Images/Shared/Help', _('Boa or selected component help'),
+              _('Show help'), self.OnHelpToolClick)
+        self.addTool('Images/Shared/wxWinHelp', _('wxPython help'),
+              _('Show help'), self.OnWxWinHelpToolClick)
+        self.addTool('Images/Shared/PythonHelp', _('Python help'),
+              _('Show help'), self.OnPythonHelpToolClick)
 
         # Add additional helpbuttons if defined in the config file
         customHelpItems = eval(conf.get('help', 'customhelp'), {})
         self.customHelpItems = {}
         for caption, helpFile in customHelpItems.items():
-            mID = wxNewId()
+            mID = wx.NewId()
             self.toolBar.AddTool(mID, IS.load('Images/Shared/CustomHelp.png'),
               shortHelpString = caption)
-            EVT_TOOL(self, mID, self.OnCustomHelpToolClick)
+            self.Bind(wx.EVT_TOOL, self.OnCustomHelpToolClick, id=mID)
             self.customHelpItems[mID] = (caption, helpFile)
 
-        if wxPlatform == '__WXGTK__':
+        if wx.Platform == '__WXGTK__':
             self.toolBar.AddSeparator()
             self.addTool('Images/Shared/CloseWindow', 'Exit', '', self.OnCloseClick)
         self.toolBar.Realize()
 
         self.palettePages = []
 
-        self.SetBackgroundColour(wxSystemSettings_GetSystemColour(wxSYS_COLOUR_BTNFACE))
+        self.SetBackgroundColour(wx.SystemSettings.GetColour(wx.SYS_COLOUR_BTNFACE))
 
     def initPalette(self, inspector, editor):
         self.inspector = inspector
         self.editor = editor
 
-        transpSF = ''
         if Preferences.paletteStyle == 'menu':
             mb = self.menuBar
         else:
@@ -152,88 +151,64 @@ class BoaFrame(wxFrame, Utils.FrameRestorerMixin):
         # XXX Set these from class
         if not hasattr(sys, 'cyclops'):
             # 'New' page
-            palettePage = NewPalettePage(self.palette, 'New',
-                  'Images/Palette/'+transpSF, self, self.widgetSet,
-                  self)
+            palettePage = NewPalettePage(self.palette, PaletteStore.newPalette[0],
+                  'Images/Palette/', self, self.widgetSet, self)
 
             for modelName in PaletteStore.paletteLists['New']:
                 palettePage.addButton2(modelName,
                     PaletteStore.newControllers[modelName],
-                    wxGenBitmapButton)
-            if mb: mb.Append(menu = palettePage.menu, title = 'New')
+                    wx.lib.buttons.GenBitmapButton)
+            if mb: mb.Append(menu=palettePage.menu, title=PaletteStore.newPalette[0])
             self.palettePages.append(palettePage)
+
             # Normal control pages
-            for palette in PaletteMapping.palette:
+            for palette in PaletteStore.palette:
                 palettePage = PalettePage(self.palette, palette[0],
-                      'Images/Palette/'+transpSF, self, self.widgetSet,
+                      'Images/Palette/', self, self.widgetSet,
                       self.componentSB, self)
                 palettePage.addToggleBitmaps(palette[2], None, None)
                 self.palettePages.append(palettePage)
-                if mb: mb.Append(menu = palettePage.menu, title = palette[0])
+                if mb: mb.Append(menu=palettePage.menu, title=palette[0])
+
             # Dialog page
-            if PaletteMapping.dialogPalette[2]:
-                self.dialogPalettePage = PanelPalettePage(self.palette,
-                      PaletteMapping.dialogPalette[0],
-                      'Images/Palette/'+transpSF, self, self.widgetSet,
-                      self.componentSB, self)
-                for dialog in PaletteMapping.dialogPalette[2]:
-                    self.dialogPalettePage.addButton(
-                          PaletteMapping.compInfo[dialog][0],
-                          dialog, PaletteMapping.compInfo[dialog][1],
-                          self.OnDialogPaletteClick, None, None,
-                          wxGenBitmapButton)
-                self.palettePages.append(self.dialogPalettePage)
-                if mb:
-                    mb.Append(menu = self.dialogPalettePage.menu, title = 'Dialogs')
+##            if PaletteStore.dialogPalette[2]:
+##                self.dialogPalettePage = PanelPalettePage(self.palette,
+##                      PaletteStore.dialogPalette[0],
+##                      'Images/Palette/', self, self.widgetSet,
+##                      self.componentSB, self)
+##                for dialog in PaletteStore.dialogPalette[2]:
+##                    self.dialogPalettePage.addButton(
+##                          PaletteStore.compInfo[dialog][0],
+##                          dialog, PaletteStore.compInfo[dialog][1],
+##                          self.OnDialogPaletteClick, None, None,
+##                          wx.lib.buttons.GenBitmapButton)
+##                self.palettePages.append(self.dialogPalettePage)
+##                if mb: mb.Append(menu=self.dialogPalettePage.menu, 
+##                                 title=PaletteStore.dialogPalette[0])
+
             # Zope page
             if Plugins.transportInstalled('ZopeLib.ZopeExplorer'):
                 self.zopePalettePage = ZopePalettePage(self.palette,
-                      PaletteMapping.zopePalette[0], 'Images/Palette/'+transpSF,
+                      PaletteStore.zopePalette[0], 'Images/Palette/',
                       self, self.widgetSet, self.componentSB, self)
                 self.zopePalettePage.addToggleBitmaps(
-                      PaletteMapping.zopePalette[2], None, None)
+                      PaletteStore.zopePalette[2], None, None)
                 self.palettePages.append(self.zopePalettePage)
-                if mb: mb.Append(menu = self.zopePalettePage.menu, title = 'Zope')
+                if mb: mb.Append(menu=self.zopePalettePage.menu, 
+                                 title=PaletteStore.zopePalette[0])
         else:
             palettePage = None
 
-        # Prototype for composites
-        # Composites are very much not thought out right now, but basically
-        # reflects Frames in Delphi 5. A D5 frame is a composite component
-        # for reuse of common control combinations. In implementation it's
-        # very much like Delphi's form inheritance, i.e. by changing the parent
-        # all children will be updated.
-        # Current thoughts on implementation in Boa:
-        #    To centralise, I like the idea of storing initialisations in a
-        #    sepatate file and using 'import' to load controls into a frame.
-
-##        self.composites = CompositeListCtrlPalPage(self.palette, -1, style = wxLC_SMALL_ICON)
-##        self.palette.AddPage(self.composites, 'Composites')
-##        self.composites.InsertStringItem(0, 'OK / Cancel buttons')
-##        self.composites.InsertStringItem(0, 'Tabbed dialog')
-##        self.composites.InsertStringItem(0, 'Name/Value')
-##        self.composites.Enable(false)
-
-        # Prototype for templates
-        # Templates is a real simple idea, instead of starting from a blank
-        # frame, start from a previously saved frame in the templates directory
-
-##        self.templates = TemplateListCtrlPalPage(self.palette, -1, style = wxLC_SMALL_ICON)
-##        self.palette.AddPage(self.templates, 'Templates')
-##        self.templates.InsertStringItem(0, 'Menu/Toolbar/StatusBar')
-##        self.templates.InsertStringItem(0, 'Wizard')
-##        self.templates.Enable(false)
-
     def setDefaultDimensions(self):
-        self.SetDimensions(0, Preferences.topMenuHeight,
+        self.SetDimensions(Preferences.screenX, Preferences.screenY + Preferences.topMenuHeight,
             Preferences.screenWidth - Preferences.windowManagerSide * 2,
             Preferences.paletteHeight)
 
-    def addTool(self, filename, text, help, func, toggle = false):
-        mID = wxNewId()
+    def addTool(self, filename, text, help, func, toggle = False):
+        mID = wx.NewId()
         self.toolBar.AddTool(mID, IS.load(filename+'.png'),
           shortHelpString = text, isToggle = toggle)
-        EVT_TOOL(self, mID, func)
+        self.Bind(wx.EVT_TOOL, func, id=mID)
         return mID
 
     def OnInspectorToolClick(self, event):
@@ -277,16 +252,16 @@ class BoaFrame(wxFrame, Utils.FrameRestorerMixin):
         self.Close()
 
     def OnCloseWindow(self, event):
-        self.destroying = true
+        self.destroying = True
         try:
             if hasattr(self, 'editor') and self.editor:
-                self.editor.destroying = true
+                self.editor.destroying = True
                 self.editor.Close()
                 if not self.destroying:
                     return
 
             if hasattr(self, 'inspector'):
-                self.inspector.destroying = true
+                self.inspector.destroying = True
                 self.inspector.Close()
 
                 if hasattr(self, 'app'):
@@ -300,12 +275,17 @@ class BoaFrame(wxFrame, Utils.FrameRestorerMixin):
 
         finally:
             if not self.destroying:
-                self.editor.destroying = false
-                self.inspector.destroying = false
+                self.editor.destroying = False
+                self.inspector.destroying = False
             else:
                 self.Destroy()
                 event.Skip()
 
+                app =wx.GetApp()
+                if hasattr(app, 'tbicon'):
+                    app.tbicon.Destroy()
+
+
     def OnUncheckComponent(self, event):
         self.componentSB.selectNone()
 
@@ -320,33 +300,33 @@ class BoaFrame(wxFrame, Utils.FrameRestorerMixin):
         if Help._hc:
             frm = Help._hc.GetFrame()
             if frm: frm.Iconize(iconize)
-        wxFrame.Iconize(self, iconize)
+        wx.Frame.Iconize(self, iconize)
 
     def OnBoaframeIconize(self, event):
         self.SetFocus()
         if Help._hc:
             frm = Help._hc.GetFrame()
-            if frm: frm.Iconize(true)
+            if frm: frm.Iconize(True)
         event.Skip()
 
 class ComponentSelection:
     """ Controls the selection of the palette and access to associated
         palette mapping structures. Accessed by the Designer """
     def __init__(self, palette):
-        wID = wxNewId()
-        self.selComp = wxCheckBox(palette.toolBar, wID, '  (Nothing selected)', 
-              size = wxSize(160, 20))
-        self.selComp.Enable(false)
-        EVT_CHECKBOX(self.selComp, wID, palette.OnUncheckComponent)
+        wID = wx.NewId()
+        self.selComp = wx.CheckBox(palette.toolBar, wID, '  '+_('(Nothing selected)'),
+              size =wx.Size(180, 20))
+        self.selComp.Enable(False)
+        self.selComp.Bind(wx.EVT_CHECKBOX, palette.OnUncheckComponent, id=wID)
         palette.toolBar.AddControl(self.selComp)
 
-        cId = palette.addTool('Images/Shared/Compose', 'Compose', ' ', 
-              palette.OnComposeClick, toggle = true)
-        iId = palette.addTool('Images/Shared/Inherit', 'Inherit', ' ', 
-              palette.OnInheritClick, toggle = true)
-        palette.toolBar.ToggleTool(cId, true)
-        palette.toolBar.EnableTool(cId, false)
-        palette.toolBar.EnableTool(iId, false)
+##        cId = palette.addTool('Images/Shared/Compose', 'Compose', ' ',
+##              palette.OnComposeClick, toggle = True)
+##        iId = palette.addTool('Images/Shared/Inherit', 'Inherit', ' ',
+##              palette.OnInheritClick, toggle = True)
+##        palette.toolBar.ToggleTool(cId, True)
+##        palette.toolBar.EnableTool(cId, False)
+##        palette.toolBar.EnableTool(iId, False)
 
         self.selection = None
         self.prevPage = None
@@ -355,33 +335,33 @@ class ComponentSelection:
         if self.prevPage: self.prevPage.selectNone()
         self.selection = detail
         self.prevPage = page
-        self.selComp.Enable(true)
+        self.selComp.Enable(True)
         self.selComp.SetLabel('  '+detail[0])
-        self.selComp.SetValue(true)
+        self.selComp.SetValue(True)
 
     def selectNone(self):
         if self.prevPage: self.prevPage.selectNone()
         self.selection = None
-        self.selComp.Enable(false)
-        self.selComp.SetLabel('  (Nothing selected)')
-        self.selComp.SetValue(false)
+        self.selComp.Enable(False)
+        self.selComp.SetLabel('  '+_('(Nothing selected)'))
+        self.selComp.SetValue(False)
 
 class BasePalettePage:
     pass
-class ListCtrlPalettePage(wxListCtrl, BasePalettePage):
+class ListCtrlPalettePage(wx.ListCtrl, BasePalettePage):
     pass
 class CompositeListCtrlPalPage(ListCtrlPalettePage):
     pass
 class TemplateListCtrlPalPage(ListCtrlPalettePage):
     pass
 
-class PanelPalettePage(wxPanel, BasePalettePage):
+class PanelPalettePage(wx.Panel, BasePalettePage):
     buttonSep = 11
     buttonBorder = 7
     def __init__(self, parent, name, bitmapPath, eventOwner, widgets, components, palette):
         # default size provided for better sizing on GTK where notebook page
         # size isn't available at button creation time
-        wxPanel.__init__(self, parent, -1, size=(44, 44))
+        wx.Panel.__init__(self, parent, -1, size=(44, 44))
 
         self.palette = palette
         self.components = components
@@ -393,8 +373,8 @@ class PanelPalettePage(wxPanel, BasePalettePage):
         self.posX = self.buttonSep/2
         self.posY = (self.GetSize().y -(24+self.buttonBorder))/2
         self.eventOwner = eventOwner
-        self.menu = wxMenu()
-        self.menusCheckable = false
+        self.menu =wx.Menu()
+        self.menusCheckable = False
 
     def destroy(self):
         if hasattr(self, 'widgets'):
@@ -409,11 +389,12 @@ class PanelPalettePage(wxPanel, BasePalettePage):
             if self.palette.paletteStyle == 'tabs':
                 self.menu.Destroy()
 
-    def addButton(self, widgetName, wxClass, constrClass, clickEvt, hintFunc, hintLeaveFunc, btnType):
-        mID = wxNewId()
+    def addButton(self, widgetName, wxClass, constrClass, clickEvt, hintFunc, 
+                  hintLeaveFunc, btnType):
+        mID = wx.NewId()
 
         self.menu.Append(mID, widgetName, '', self.menusCheckable)
-        EVT_MENU(self.palette, mID, clickEvt)
+        self.palette.Bind(wx.EVT_MENU, clickEvt, id=mID)
 
         self.widgets[mID] = (widgetName, wxClass, constrClass)
 
@@ -424,18 +405,18 @@ class PanelPalettePage(wxPanel, BasePalettePage):
         width = bmp.GetWidth() + self.buttonBorder
         height = bmp.GetHeight() + self.buttonBorder
 
-        newButton = btnType(self, mID, None, wxPoint(self.posX, self.posY),
-                           wxSize(width, height))
+        newButton = btnType(self, mID, None, wx.Point(self.posX, self.posY),
+                           wx.Size(width, height))
 
         newButton.SetBezelWidth(1)
         newButton.SetUseFocusIndicator(0)
         newButton.SetToolTipString(widgetName)
         try:
-            newButton.SetBitmapLabel(bmp, false)
+            newButton.SetBitmapLabel(bmp, False)
         except TypeError:
             newButton.SetBitmapLabel(bmp)
 
-        EVT_BUTTON(self, mID, clickEvt)
+        self.Bind(wx.EVT_BUTTON, clickEvt, id=mID)
 
         self.buttons[widgetName] = newButton
         self.posX = self.posX + bmp.GetWidth() + 11
@@ -447,40 +428,51 @@ class PanelPalettePage(wxPanel, BasePalettePage):
 
 class NewPalettePage(PanelPalettePage):
     def __init__(self, parent, name, bitmapPath, eventOwner, widgets, palette):
-        PanelPalettePage.__init__(self, parent, name, bitmapPath, eventOwner, widgets, palette, palette)
+        PanelPalettePage.__init__(self, parent, name, bitmapPath, eventOwner, 
+                                  widgets, palette, palette)
         self.selection = None
 
     def destroy(self):
         PanelPalettePage.destroy(self)
 
-    def addButton(self, widgetName, wxClass, constrClass, clickEvt, hintFunc, hintLeaveFunc, btnType):
-        mID = PanelPalettePage.addButton(self, widgetName, wxClass, constrClass, clickEvt, hintFunc, hintLeaveFunc, btnType)
+    def addButton(self, widgetName, wxClass, constrClass, clickEvt, hintFunc, 
+                  hintLeaveFunc, btnType):
+        mID = PanelPalettePage.addButton(self, widgetName, wxClass, constrClass, 
+              clickEvt, hintFunc, hintLeaveFunc, btnType)
         return mID
 
     def addButton2(self, name, Controller, btnType):
-        mID = PanelPalettePage.addButton(self, name, Controller, None, self.OnClickTrap, None, None, btnType)
-        EVT_MENU(self.palette.editor, mID, self.OnClickTrap)
+        mID = PanelPalettePage.addButton(self, name, Controller, None, 
+              self.OnClickTrap, None, None, btnType)
+        self.palette.editor.Bind(wx.EVT_MENU, self.OnClickTrap, id=mID)
 
         return mID
 
     def getButtonBmp(self, name, wxClass):
-        return IS.load('%s%s.png' %(self.bitmapPath, name))
+        try:
+            return IS.load('%s%s.png' %(self.bitmapPath, name))
+        except IS.Error:
+            return IS.load('Images/Palette/Component.png')
 
     def OnClickTrap(self, event):
         modPageInfo = self.widgets[event.GetId()]
-        Utils.wxCallAfter(self.palette.OnCreateNew, name=modPageInfo[0], controller=modPageInfo[1])
+        wx.CallAfter(self.palette.OnCreateNew, name=modPageInfo[0], 
+              controller=modPageInfo[1])
 
 class PalettePage(PanelPalettePage):
-    def __init__(self, parent, name, bitmapPath, eventOwner, widgets, components, palette):
-        PanelPalettePage.__init__(self, parent, name, bitmapPath, eventOwner, widgets, components, palette)
+    def __init__(self, parent, name, bitmapPath, eventOwner, widgets, 
+                 components, palette):
+        PanelPalettePage.__init__(self, parent, name, bitmapPath, eventOwner, 
+              widgets, components, palette)
         self.clickEvt = None
         self.selection = None
-        self.menusCheckable = true
+        self.menusCheckable = True
 
     def addToggleBitmaps(self, classes, hintFunc, hintLeaveFunc):
         for wxClass in classes:
-            ci = PaletteMapping.compInfo[wxClass]
-            self.addButton(ci[0], wxClass, ci[1], self.OnClickTrap, hintFunc, hintLeaveFunc, wxGenBitmapToggleButton)
+            ci = PaletteStore.compInfo[wxClass]
+            self.addButton(ci[0], wxClass, ci[1], self.OnClickTrap, hintFunc, 
+                  hintLeaveFunc, wx.lib.buttons.GenBitmapToggleButton)
 
     def OnClickTrap(self, event):
         wId = event.GetId()
@@ -499,25 +491,25 @@ class PalettePage(PanelPalettePage):
                 self.components.selectNone()
             else:
                 self.components.selectComponent(self, self.widgets[wId])
-                sel.Check(true)
+                sel.Check(True)
                 self.selection = sel
             event.Skip()
 
     def selectNone(self):
         if self.selection:
             if self.palette.paletteStyle == 'tabs':
-                self.selection.SetToggle(false)
+                self.selection.SetToggle(False)
                 self.selection.Refresh()
                 self.selection = None
             elif self.palette.paletteStyle == 'menu':
-                self.selection.Check(false)
+                self.selection.Check(False)
                 self.selection = None
 
 
 class ZopePalettePage(PalettePage):
-    def __init__(self, parent, name, bitmapPath, eventOwner, widgets, 
+    def __init__(self, parent, name, bitmapPath, eventOwner, widgets,
           components, palette):
-        PalettePage.__init__(self, parent, name, bitmapPath, eventOwner, 
+        PalettePage.__init__(self, parent, name, bitmapPath, eventOwner,
               widgets, components, palette)
 
     def getButtonBmp(self, name, wxClass):
@@ -525,9 +517,10 @@ class ZopePalettePage(PalettePage):
 
 
 if __name__ == '__main__':
-    app = wxPySimpleApp()
-    wxInitAllImageHandlers()
+    app = wx.PySimpleApp()
     palette = BoaFrame(None, -1, app)
     palette.Show()
+    palette.palette.AddPage(wx.Panel(palette.palette, -1), 'test')
+    
 
     app.MainLoop()
