@@ -5,43 +5,46 @@
 # Author:      Riaan Booysen
 #
 # Created:     1999
-# RCS-ID:      $Id: Utils.py,v 1.41 2004/08/16 12:46:11 riaan Exp $
-# Copyright:   (c) 1999 - 2004 Riaan Booysen
+# RCS-ID:      $Id: Utils.py,v 1.61 2007/07/05 11:52:34 riaan Exp $
+# Copyright:   (c) 1999 - 2007 Riaan Booysen
 # Licence:     GPL
 #----------------------------------------------------------------------
-import string, os, glob, pprint
-from types import InstanceType
+import string, os, sys, glob, pprint, types, re, traceback
 
-from wxPython.wx import *
+import wx
 
 import Preferences
 from Preferences import IS
-from ExternalLib.ConfigParser import ConfigParser
+from ConfigParser import ConfigParser
+
+# Centralised i18n gettext compatible definition
+_ = wx.GetTranslation
+
 
 def toPyPath(filename):
     return os.path.join(Preferences.pyPath, filename)
 
 def ShowErrorMessage(parent, caption, mess):
-    dlg = wxMessageDialog(parent, mess.__class__.__name__ +': '+`mess`,
-                          caption, wxOK | wxICON_EXCLAMATION)
+    dlg = wx.MessageDialog(parent, mess.__class__.__name__ +': '+`mess`,
+                          caption, wx.OK | wx.ICON_EXCLAMATION)
     try: dlg.ShowModal()
     finally: dlg.Destroy()
 
-def ShowMessage(parent, caption, message, msgTpe=wxICON_INFORMATION):
-    dlg = wxMessageDialog(parent, message, caption, wxOK | msgTpe)
+def ShowMessage(parent, caption, message, msgTpe=wx.ICON_INFORMATION):
+    dlg = wx.MessageDialog(parent, message, caption, wx.OK | msgTpe)
     try: dlg.ShowModal()
     finally: dlg.Destroy()
 
 def yesNoDialog(parent, title, question):
-    dlg = wxMessageDialog(parent, question, title, wxYES_NO | wxICON_QUESTION)
-    try: return (dlg.ShowModal() == wxID_YES)
+    dlg = wx.MessageDialog(parent, question, title, wx.YES_NO | wx.ICON_QUESTION)
+    try: return (dlg.ShowModal() == wx.ID_YES)
     finally: dlg.Destroy()
 
 def AddToolButtonBmpObject(frame, toolbar, thebitmap, hint, triggermeth,
-      theToggleBitmap=wxNullBitmap):
-    nId = wxNewId()
+      theToggleBitmap=wx.NullBitmap):
+    nId = wx.NewId()
     toolbar.AddTool(nId, thebitmap, theToggleBitmap, shortHelpString = hint)
-    EVT_TOOL(frame, nId, triggermeth)
+    frame.Bind(wx.EVT_TOOL, triggermeth, id=nId)
     return nId
 
 def AddToolButtonBmpFile(frame, toolbar, filename, hint, triggermeth):
@@ -55,9 +58,9 @@ def AddToolButtonBmpIS(frame, toolbar, name, hint, triggermeth, toggleBmp = ''):
         return AddToolButtonBmpObject(frame, toolbar, IS.load(name), hint[:85], triggermeth)
 
 def AddToggleToolButtonBmpObject(frame, toolbar, thebitmap, hint, triggermeth):
-    nId = wxNewId()
-    toolbar.AddTool(nId, thebitmap, thebitmap, shortHelpString = hint, isToggle = true)
-    EVT_TOOL(frame, nId, triggermeth)
+    nId = wx.NewId()
+    toolbar.AddTool(nId, thebitmap, thebitmap, shortHelpString = hint, isToggle = True)
+    frame.Bind(wx.EVT_TOOL, triggermeth, id=nId)
     return nId
 
 #This format follows wxWidgets conventions
@@ -65,18 +68,18 @@ def windowIdentifier(frameName, ctrlName):
     return 'wxID_' + frameName.upper() + ctrlName.upper()
 
 
-class BoaFileDropTarget(wxFileDropTarget):
+class BoaFileDropTarget(wx.FileDropTarget):
     def __init__(self, editor):
-        wxFileDropTarget.__init__(self)
+        wx.FileDropTarget.__init__(self)
         self.editor = editor
 
     def OnDropFiles(self, x, y, filenames):
-        wxBeginBusyCursor()
+        wx.BeginBusyCursor()
         try:
             for filename in filenames:
                 self.editor.openOrGotoModule(filename)
         finally:
-            wxEndBusyCursor()
+            wx.EndBusyCursor()
 
 def split_seq(seq, pivot, transformFunc = None):
     result = []
@@ -118,7 +121,7 @@ def human_split(line):
 
 def duplicateMenu(source):
     """ Create an duplicate of a menu (does not do sub menus)"""
-    dest = wxMenu()
+    dest = wx.Menu()
     for menu in source.GetMenuItems():
         if menu.IsSeparator():
             dest.AppendSeparator()
@@ -126,7 +129,7 @@ def duplicateMenu(source):
             dest.Append(menu.GetId(), menu.GetText(), menu.GetHelp(), menu.IsCheckable())
             mi = dest.FindItemById(menu.GetId())
             if menu.IsCheckable() and menu.IsChecked():
-                mi.Check(true)
+                mi.Check(True)
     return dest
 
 def getValidName(usedNames, baseName, ext = '', n = 1, itemCB = lambda x:x):
@@ -142,8 +145,14 @@ def srcRefFromCtrlName(ctrlName):
 def ctrlNameFromSrcRef(srcRef):
     return srcRef == 'self' and '' or srcRef[5:]
 
+def getWxPyNameForClass(Class):
+    """ Strips away _modules from the class identifier """
+    classPathSegs = Class.__module__.split('.') + [Class.__name__]
+    return '.'.join([pathSeg for pathSeg in classPathSegs if pathSeg[0] != '_'])
+
 def winIdRange(count):
-    return map(lambda x: wxNewId(), range(count))
+    return [wx.NewId() for x in range(count)]
+
 wxNewIds = winIdRange
 
 def methodLooksLikeEvent(method):
@@ -159,7 +168,7 @@ def whitespacetospace(str):
 ##tst_str = ' 1\t\n 3'
 ##print `whitespacetospace(tst_str)`
 
-class PaintEventHandler(wxEvtHandler):
+class PaintEventHandler(wx.EvtHandler):
     """ This class is used to merge paint requests.
 
         Each paint is captured and saved. Later on the idle event,
@@ -174,13 +183,13 @@ class PaintEventHandler(wxEvtHandler):
     """
 
     def __init__(self, window):
-        wxEvtHandler.__init__(self)
+        wx.EvtHandler.__init__(self)
         self.painting=0
         self.updates=[]
         self.window = window
         window.PushEventHandler(self)
-        EVT_PAINT(self, self.OnPaint)
-        EVT_IDLE(self, self.OnIdle)
+        self.Bind(wx.EVT_PAINT, self.OnPaint)
+        self.Bind(wx.EVT_IDLE, self.OnIdle)
     def OnPaint(self, event):
         if self.painting == 1:
             event.Skip()
@@ -240,9 +249,21 @@ class PaintEventHandler(wxEvtHandler):
                 height = rect2.height
             else:
                 height = rect1.y + rect1.height - rect2.y
-        rv = wxRect(x, y, width, height)
+        rv = wx.Rect(x, y, width, height)
         return rv
 
+def getI18NLangDir():
+    d = wx.GetApp().locale.GetCanonicalName()
+    path = toPyPath(os.path.join('locale', d))
+    if not os.path.exists(path):
+        if '_' in d:
+            path = toPyPath(os.path.join('locale', d.split('_', 1)[0]))
+            if not os.path.exists(path):
+                return ''
+        else:
+            return ''
+    return path
+
 def showTip(frame, forceShow=0):
     """ Displays tip of the day.
 
@@ -254,38 +275,47 @@ def showTip(frame, forceShow=0):
         conf = None
         showTip, index = (1, 0)
     else:
-        showTip = conf.getint('tips', 'showonstartup')
+        showTip = conf.getboolean('tips', 'showonstartup')
         index = conf.getint('tips', 'tipindex')
 
     if showTip or forceShow:
-        tp = wxCreateFileTipProvider(toPyPath('Docs/tips.txt'), index)
-        showTip = wxShowTip(frame, tp, showTip)
+        # try to find translated tips
+        tipsDir = getI18NLangDir()
+        if not tipsDir:
+            tipsFile = toPyPath('Docs/tips.txt')
+        else:
+            tipsFile = tipsDir+'/tips.txt'
+            if not os.path.exists(tipsFile):
+                tipsFile = toPyPath('Docs/tips.txt')
+        
+        tp = wx.CreateFileTipProvider(tipsFile, index)
+        showTip = wx.ShowTip(frame, tp, showTip)
         index = tp.GetCurrentTip()
         if conf:
-            conf.set('tips', 'showonstartup', showTip)
-            conf.set('tips', 'tipindex', index)
+            conf.set('tips', 'showonstartup', showTip and 'true' or 'false')
+            conf.set('tips', 'tipindex', str(index))
             try:
                 writeConfig(conf)
             except IOError:
-                wxLogError('Could not edit tips settings, please make '
+                wx.LogError(_('Could not edit tips settings, please make '
                       'sure that the Explorer.*.cfg file is not read only and you '
-                      'have sufficient priviledges to write to this file.')
+                      'have sufficient priviledges to write to this file.'))
 
 def readTextFromClipboard():
-    clip = wxTheClipboard
+    clip = wx.TheClipboard
     clip.Open()
     try:
-        data = wxTextDataObject()
+        data = wx.TextDataObject()
         clip.GetData(data)
         return data.GetText()
     finally:
         clip.Close()
 
 def writeTextToClipboard(text):
-    clip = wxTheClipboard
+    clip = wx.TheClipboard
     clip.Open()
     try:
-        clip.SetData(wxTextDataObject(text))
+        clip.SetData(wx.TextDataObject(text))
     finally:
         clip.Close()
 
@@ -296,12 +326,8 @@ def createAndReadConfig(name, forPlatform=1):
     confFile = os.path.join(Preferences.rcPath, '%s%s.cfg' % (name,
         forPlatform and '.'+Preferences.thisPlatform or ''))
 
-    # paths are within quotes in config, simpler to use fwd slash
-    _confDefaults = {'BOAROOT': Preferences.pyPath.replace('\\', '/'),
-                     'RESOURCECONFIG': Preferences.rcPath.replace('\\', '/')}
-
     if not _sharedConfs.has_key(confFile):
-        conf = ConfigParser(_confDefaults)
+        conf = ConfigParser()
         conf.read(confFile)
         conf.confFile = confFile
         _sharedConfs[confFile] = conf
@@ -311,26 +337,25 @@ def createAndReadConfig(name, forPlatform=1):
 def writeConfig(conf):
     conf.write(open(conf.confFile, 'w'))
 
-from wxPython import html
+import wx.html
 
-wxEVT_HTML_URL_CLICK = wxNewId()
+wxEVT_HTML_URL_CLICK = wx.NewId()
+EVT_HTML_URL_CLICK = wx.PyEventBinder(wxEVT_HTML_URL_CLICK)
 
-def EVT_HTML_URL_CLICK(win, func):
-    win.Connect(-1, -1, wxEVT_HTML_URL_CLICK, func)
 
-class wxHtmlWindowUrlClick(wxPyEvent):
+class wxHtmlWindowUrlClick(wx.PyEvent):
     def __init__(self, linkinfo):
-        wxPyEvent.__init__(self)
+        wx.PyEvent.__init__(self)
         self.SetEventType(wxEVT_HTML_URL_CLICK)
         self.linkinfo = (linkinfo.GetHref(), linkinfo.GetTarget())
 
-class wxUrlClickHtmlWindow(html.wxHtmlWindow):
+class wxUrlClickHtmlWindow(wx.html.HtmlWindow):
     """ HTML window that generates and OnLinkClicked event.
 
     Use this to avoid having to override HTMLWindow
     """
     def OnLinkClicked(self, linkinfo):
-        wxPostEvent(self, wxHtmlWindowUrlClick(linkinfo))
+        wx.PostEvent(self, wxHtmlWindowUrlClick(linkinfo))
 
 def wxProxyPanel(parent, Win, *args, **kwargs):
     """ Function which put's a panel in between two controls.
@@ -338,29 +363,29 @@ def wxProxyPanel(parent, Win, *args, **kwargs):
         Mainly for better repainting under GTK.
         Based on a pattern by Kevin Gill.
     """
-    panel = wxPanel(parent, -1, style=wxTAB_TRAVERSAL | wxCLIP_CHILDREN)
+    panel = wx.Panel(parent, -1, style=wx.TAB_TRAVERSAL | wx.CLIP_CHILDREN)
 
-    if type(Win) is types.ClassType:
-        win = apply(Win, (panel,) + args, kwargs)
-    elif type(Win) is types.InstanceType:
+    if type(Win) is types.ClassType or type(Win) is types.TypeType:
+        win = Win(*((panel,) + args), **kwargs)
+    elif isinstance(Win, wx.Window):
         win = Win
         win.Reparent(panel)
     else:
-        raise 'Unhandled type for Win'
+        raise Exception, _('Unhandled type for Win')
 
     def OnWinSize(evt, win=win):
         win.SetSize(evt.GetSize())
-    EVT_SIZE(panel, OnWinSize)
+    panel.Bind(wx.EVT_SIZE, OnWinSize)
     return panel, win
 
 def IsComEnabled():
-    if Preferences.blockCOM: return false
+    if Preferences.blockCOM: return False
     try:
         import win32com
     except ImportError:
-        return false
+        return False
     else:
-        return true
+        return True
 
 import stat, shutil
 skipdirs = ('CVS',)
@@ -398,7 +423,7 @@ def visit_update(paths, dirname, names):
 
 def get_current_frame():
     try:
-        raise 'get_exc_info'
+        Exception, 'get_exc_info'
     except:
         return sys.exc_info()[2].tb_frame.f_back
 
@@ -425,9 +450,9 @@ class PseudoFile:
 
     def flush(self):
         pass
-    
+
     def isatty(self):
-        return false
+        return False
 
 class PseudoFileOutStore(PseudoFile):
     """ File like obj with list storage """
@@ -455,7 +480,7 @@ class OutputLoggerPF(LoggerPF):
                      frame.f_back.f_lineno,)
             else:
                 ss = s
-            wxLogMessage(self.pad(ss).replace('%', '%%'))
+            wx.LogMessage(self.pad(ss).replace('%', '%%'))
 
         sys.__stdout__.write(s)
 
@@ -473,7 +498,7 @@ class ErrorLoggerPF(LoggerPF):
         elif s[-1] != '\n':
             self.buffer = self.buffer + s
         else:
-            wxLogError(self.pad(self.buffer+s[:-1]).replace('%', '%%'))
+            wx.LogError(self.pad(self.buffer+s[:-1]).replace('%', '%%'))
 
         sys.__stderr__.write(s)
 
@@ -501,17 +526,17 @@ def html2txt(htmlblock):
     p.feed(htmlblock)
     return s.getvalue().strip()
 
-def getEntireWxNamespace():
-    """ Return a dictionary containing the entire (non filtered) wxPython
-        namespace """
-    from wxPython import wx, html, htmlhelp, grid, calendar, stc, ogl
-    from wxPython import help, gizmos, wizard
-    namespace = {}
-    map(namespace.update, [wx.__dict__, html.__dict__, htmlhelp.__dict__,
-                           grid.__dict__, calendar.__dict__, 
-                           stc.__dict__, ogl.__dict__, gizmos.__dict__,
-                           help.__dict__, wizard.__dict__])
-    return namespace
+##def getEntireWxNamespace():
+##    """ Return a dictionary containing the entire (non filtered) wxPython
+##        namespace """
+##    from wxPython import wx, html, htmlhelp, grid, calendar, stc
+##    from wxPython import help, gizmos, wizard
+##    namespace = {}
+##    map(namespace.update, [wx.__dict__, html.__dict__, htmlhelp.__dict__,
+##                           grid.__dict__, calendar.__dict__,
+##                           stc.__dict__, gizmos.__dict__,
+##                           help.__dict__, wizard.__dict__])
+##    return namespace
 
 class FrameRestorerMixin:
     """ Used by top level windows to restore from gidden or iconised state
@@ -527,7 +552,7 @@ class FrameRestorerMixin:
     def restore(self):
         self.Show()
         if self.IsIconized():
-            self.Iconize(false)
+            self.Iconize(False)
         self.Raise()
 
     def setDimensions(self, dims):
@@ -541,8 +566,8 @@ class FrameRestorerMixin:
             self.SetDimensions(*dims)
 
     def getDimensions(self):
-        pos = self.GetPosition().asTuple()
-        size = self.GetSize().asTuple()
+        pos = self.GetPosition().Get()
+        size = self.GetSize().Get()
         return pos + size
 
     def loadDims(self):
@@ -550,10 +575,11 @@ class FrameRestorerMixin:
         if not conf.has_option(self.confSection, self.winConfOption):
             dims = None
         else:
-            dims = eval(conf.get(self.confSection , self.winConfOption), 
-                        {'wxSize': wxSize, 'wxPoint': wxPoint,
-                         'wxDefaultSize': wxDefaultSize, 
-                         'wxDefaultPosition': wxDefaultPosition})
+            dims = eval(conf.get(self.confSection , self.winConfOption),
+                        {'wxSize': wx.Size, 'wxPoint': wx.Point,
+                         'wxDefaultSize': wx.DefaultSize,
+                         'wxDefaultPosition': wx.DefaultPosition,
+                         'wx': wx})
 
         if dims:
             self.setDimensions(dims)
@@ -584,9 +610,9 @@ def callOnFrameRestorers(method):
 def setupCloseWindowOnEscape(win):
     def OnCloseWin(event, win=win): win.Close()
 
-    wxID_CLOSEWIN = wxNewId()
-    EVT_MENU(win, wxID_CLOSEWIN, OnCloseWin)
-    return (wxACCEL_NORMAL, WXK_ESCAPE, wxID_CLOSEWIN)
+    wxID_CLOSEWIN = wx.NewId()
+    win.Bind(wx.EVT_MENU, OnCloseWin, id=wxID_CLOSEWIN)
+    return (wx.ACCEL_NORMAL, wx.WXK_ESCAPE, wxID_CLOSEWIN)
 
 def getModelBaseDir(model):
     if hasattr(model, 'app') and model.app and model.app.savedAs:
@@ -607,11 +633,9 @@ def pathRelativeToModel(path, model):
 class BottomAligningSplitterMix:
     """ Mixin class that keeps the bottom window in a splitter at a constant height """
     def __init__(self):
-        EVT_SIZE(self, self._OnSplitterwindowSize)
-        EVT_SPLITTER_SASH_POS_CHANGED(self, self.GetId(),
-            self._OnSplitterwindowSplitterSashPosChanged)
-        EVT_SPLITTER_DOUBLECLICKED(self, self.GetId(),
-            self._OnSplitterwindowSplitterDoubleclicked)
+        self.Bind(wx.EVT_SIZE, self._OnSplitterwindowSize)
+        self.Bind(wx.EVT_SPLITTER_SASH_POS_CHANGED, self._OnSplitterwindowSplitterSashPosChanged, id=self.GetId())
+        self.Bind(wx.EVT_SPLITTER_DOUBLECLICKED, self._OnSplitterwindowSplitterDoubleclicked, id=self.GetId())
         sashsize = self.GetSashSize()
         self.SetMinimumPaneSize(sashsize)
         sashpos = self.GetClientSize().y - sashsize
@@ -619,7 +643,7 @@ class BottomAligningSplitterMix:
         self._win2sze = self._getWin2Sze()
 
     def bottomWindowIsOpen(self):
-        return self.GetSashPosition() != self.GetClientSize().y - self.GetSashSize()
+        return self.GetSashPosition()+1 != self.GetClientSize().y - self.GetSashSize()
 
     def openBottomWindow(self):
         self.SetSashPosition(
@@ -638,84 +662,86 @@ class BottomAligningSplitterMix:
     def _OnSplitterwindowSize(self, event):
         sashpos = self.GetClientSize().y - self._win2sze - self.GetSashSize()
         self.SetSashPosition(sashpos)
+        if event: event.Skip()
 
     def _OnSplitterwindowSplitterSashPosChanged(self, event):
         self._win2sze = self._getWin2Sze()
-        event.Skip()
+        if event: event.Skip()
 
     def _OnSplitterwindowSplitterDoubleclicked(self, event):
         if self.bottomWindowIsOpen():
             self.closeBottomWindow()
         else:
             self.openBottomWindow()
+        if event: event.Skip()
 
-class BottomAligningSplitterWindow(wxSplitterWindow, BottomAligningSplitterMix):
+class BottomAligningSplitterWindow(wx.SplitterWindow, BottomAligningSplitterMix):
     def __init__(self, *_args, **_kwargs):
-        apply(wxSplitterWindow.__init__, (self,)+_args, _kwargs)
+        wx.SplitterWindow.__init__(*((self,)+_args), **_kwargs)
         BottomAligningSplitterMix.__init__(self)
 
 def traverseTreeCtrl(tree, treeItem, func):
     func(tree, treeItem)
-    item, cookie = tree.GetFirstChild(treeItem, 0)
+    item, cookie = tree.GetFirstChild(treeItem)
     while item.IsOk():
         traverseTreeCtrl(tree, item, func)
         item, cookie = tree.GetNextChild(item, cookie)
 
 
-class ListCtrlLabelEditFixEH(wxEvtHandler):
+class ListCtrlLabelEditFixEH(wx.EvtHandler):
     """Fixes broken LabelEdit/Cursor behaviour on MSW
 
        Add in constructor:
        ListCtrlLabelEditFixEH(<control>)
 
        Add in destructor:
-       <control>.PopEventHandler(true)
+       <control>.PopEventHandler(True)
     """
 
-    wxEVT_CTRLEDIT = wxNewId()
+    wxEVT_CTRLEDIT = wx.NewId()
 
     def __init__(self, listCtrl):
-        wxEvtHandler.__init__(self)
-        self._blockMouseEdit = false
+        wx.EvtHandler.__init__(self)
+        self._blockMouseEdit = False
 
         self.listCtrl = listCtrl
-        EVT_LIST_BEGIN_LABEL_EDIT(listCtrl, listCtrl.GetId(), self.OnBeginLabelEdit)
+        listCtrl.Bind(wx.EVT_LIST_BEGIN_LABEL_EDIT, self.OnBeginLabelEdit, id=listCtrl.GetId())
         listCtrl.PushEventHandler(self)
 
     def OnBeginLabelEdit(self, event):
-        if not self._blockMouseEdit and wxPlatform == '__WXMSW__':
+        if not self._blockMouseEdit and wx.Platform == '__WXMSW__':
             event.Veto()
-            wxCallAfter(self.ctrlLabelEdit, event.GetIndex())
+            wx.CallAfter(self.ctrlLabelEdit, event.GetIndex())
         else:
-            self._blockMouseEdit = false
+            self._blockMouseEdit = False
         event.Skip()
 
     def ctrlLabelEdit(self, idx):
-        self._blockMouseEdit = true
+        self._blockMouseEdit = True
         self.listCtrl.EditLabel(idx)
 
-SEL_FOC = wxLIST_STATE_SELECTED | wxLIST_STATE_FOCUSED
+SEL_FOC = wx.LIST_STATE_SELECTED | wx.LIST_STATE_FOCUSED
 def selectBeforePopup(event):
     """Ensures the item the mouse is pointing at is selected before a popup.
 
     Works with both single-select and multi-select lists."""
     ctrl = event.GetEventObject()
-    if isinstance(ctrl, wxListCtrl):
+    if isinstance(ctrl, wx.ListCtrl):
         n, flags = ctrl.HitTest(event.GetPosition())
         if n >= 0:
-            if not ctrl.GetItemState(n, wxLIST_STATE_SELECTED):
-                if not (ctrl.GetWindowStyleFlag() & wxLC_SINGLE_SEL):
+            if not ctrl.GetItemState(n, wx.LIST_STATE_SELECTED):
+                if not (ctrl.GetWindowStyleFlag() & wx.LC_SINGLE_SEL):
                     # Clear selection if multi-select.
                     for i in range(ctrl.GetItemCount()):
                         ctrl.SetItemState(i, 0, SEL_FOC)
                 ctrl.SetItemState(n, SEL_FOC, SEL_FOC)
 
-def getListCtrlSelection(listctrl, state=wxLIST_STATE_SELECTED):
+def getListCtrlSelection(listctrl, state=wx.LIST_STATE_SELECTED):
     """ Returns list of item indexes of given state """
     res = []
     idx = -1
     while 1:
-        idx = listctrl.GetNextItem(idx, wxLIST_NEXT_ALL, state)
+        idx = listctrl.GetNextItem(idx, wx.LIST_NEXT_ALL, state)
         if idx == -1:
             break
         res.append(idx)
@@ -727,11 +753,11 @@ class ListCtrlSelectionManagerMix:
     As selection single and multi-select list return the item index or a
     list of item indexes respectively.
     """
-    wxEVT_DOPOPUPMENU = wxNewId()
+    wxEVT_DOPOPUPMENU = wx.NewId()
     _menu = None
 
     def __init__(self):
-        EVT_RIGHT_DOWN(self, self.OnLCSMRightDown)
+        self.Bind(wx.EVT_RIGHT_DOWN, self.OnLCSMRightDown)
         self.Connect(-1, -1, self.wxEVT_DOPOPUPMENU, self.OnLCSMDoPopup)
 
     def getPopupMenu(self):
@@ -748,7 +774,7 @@ class ListCtrlSelectionManagerMix:
 
     def getSelection(self):
         res = getListCtrlSelection(self)
-        if self.GetWindowStyleFlag() & wxLC_SINGLE_SEL:
+        if self.GetWindowStyleFlag() & wx.LC_SINGLE_SEL:
             if res:
                 return res[0]
             else:
@@ -766,42 +792,42 @@ class ListCtrlSelectionManagerMix:
             self.afterPopupMenu(menu)
             return
 
-            evt = wxPyEvent()
+            evt = wx.PyEvent()
             evt.SetEventType(self.wxEVT_DOPOPUPMENU)
             evt.menu = menu
             evt.pos = event.GetPosition()
-            wxPostEvent(self, evt)
+            wx.PostEvent(self, evt)
 
     def OnLCSMDoPopup(self, event):
         self.PopupMenu(event.menu, event.pos)
         self.afterPopupMenu(event.menu)
 
 
-# Does this version leak event handlers?
-def wxCallAfter(callable, *args, **kw):
-    handler, evtType = wxEvtHandler(), wxNewId()
-    handler.Connect(-1, -1, evtType, lambda event, handler=handler,
-          callable=callable, args=args, kw=kw: apply(callable, args, kw) )
-    evt = wxPyEvent()
-    evt.SetEventType(evtType)
-    wxPostEvent(handler, evt)
-
-_wxCallAfterId = None
-def wxCallAfter(callable, *args, **kw):
-    app = wxGetApp()
-    assert app, 'No wxApp created yet'
-
-    global _wxCallAfterId
-    if _wxCallAfterId is None:
-        _wxCallAfterId = wxNewId()
-        app.Connect(-1, -1, _wxCallAfterId,
-              lambda event: apply(event.callable, event.args, event.kw) )
-    evt = wxPyEvent()
-    evt.SetEventType(_wxCallAfterId)
-    evt.callable = callable
-    evt.args = args
-    evt.kw = kw
-    wxPostEvent(app, evt)
+### Does this version leak event handlers?
+##def wxCallAfter(callable, *args, **kw):
+##    handler, evtType = wx.EvtHandler(), wx.NewId()
+##    handler.Connect(-1, -1, evtType, lambda event, handler=handler,
+##          callable=callable, args=args, kw=kw: callable(*args, **kw) )
+##    evt = wx.PyEvent()
+##    evt.SetEventType(evtType)
+##    wx.PostEvent(handler, evt)
+##
+##_wxCallAfterId = None
+##def wxCallAfter(callable, *args, **kw):
+##    app = wx.GetApp()
+##    assert app, 'No wxApp created yet'
+##
+##    global _wxCallAfterId
+##    if _wxCallAfterId is None:
+##        _wxCallAfterId = wx.NewId()
+##        app.Connect(-1, -1, _wxCallAfterId,
+##              lambda event: event.callable(*event.args, **event.kw) )
+##    evt = wx.PyEvent()
+##    evt.SetEventType(_wxCallAfterId)
+##    evt.callable = callable
+##    evt.args = args
+##    evt.kw = kw
+##    wx.PostEvent(app, evt)
 
 def getIndentBlock():
     if Preferences.STCUseTabs:
@@ -809,6 +835,15 @@ def getIndentBlock():
     else:
         return Preferences.STCIndent*' '
 
+def getIndentedStrForLen(n):
+    if Preferences.STCUseTabs:
+        d, m = divmod(n, Preferences.STCTabWidth)
+        if m: 
+            d += 1
+        return '\t'*d
+    else:
+        return n*' '
+    
 #-------------------------------------------------------------------------------
 
 def canReadStream(stream):
@@ -829,43 +864,141 @@ def find_dotted_module(name, path=None):
     return file, filename, desc
 
 def appendMenuItem(menu, wId, label, code=(), bmp='', help=''):
-    # XXX Add kind=wxITEM_NORMAL when 2.3.3 is minimum.
+    # XXX Add kind=wx.ITEM_NORMALwhen 2.3.3 is minimum.
     text = label + (code and ' \t'+code[2] or '')
-    menuItem = wxMenuItem(menu, wId, text, help)
+    menuItem = wx.MenuItem(menu, wId, text, help)
     if Preferences.editorMenuImages and bmp and bmp != '-':
-        if wxPlatform == '__WXGTK__' and wxVERSION >= (2,3,3) or \
-              wxPlatform == '__WXMSW__':
+        if wx.Platform == '__WXGTK__' and wx.VERSION >= (2,3,3) or \
+              wx.Platform == '__WXMSW__':
             menuItem.SetBitmap(Preferences.IS.load(bmp))
     menu.AppendItem(menuItem)
 
-def stringFromControl(u):
-    try: wxUSE_UNICODE, UnicodeError
-    except NameError: return u
+def getNotebookPage(notebook, name):
+    for i in range(notebook.GetPageCount()):
+        if notebook.GetPageText(i) == name:
+            return i
+    return -1
 
-    if wxUSE_UNICODE:
-        try: 
+def getViewTitle(view):
+    if hasattr(view, 'viewTitle'):
+        return view.viewTitle
+    else:
+        return view.viewName
+
+# reset all sizes to platform defaults
+def resetMinSize(parent, ignoreCtrls=(), ignoreClasses=()):
+    # need this for some cases in linux, otherwise cuts off text
+    if wx.Platform == '__WXGTK__' and isinstance(parent, wx.StaticText):
+        textSize = parent.GetTextExtent(parent.GetLabel())
+        size = wx.Size(textSize[0]+2,-1)
+    else:
+        size = wx.DefaultSize
+          
+    parent.SetMinSize(size)    
+    parent.SetSize(wx.Size(1, 1))
+    
+    for child in parent.GetChildren():
+        if child not in ignoreCtrls and not isinstance(child, ignoreClasses):
+            resetMinSize(child, ignoreCtrls, ignoreClasses) 
+
+def wxPyExceptHook(type, value, trace):
+    if wx and sys and traceback:
+        exc = traceback.format_exception(type, value, trace)
+        for e in exc: 
+            wx.LogError(e)
+        sys.__excepthook__(type, value, trace)
+
+
+#-------------------------------------------------------------------------------
+
+coding_re = re.compile("coding[:=]\s*([-\w_.]+)")
+
+def coding_spec(str):
+    """Return the encoding declaration according to PEP 263.
+
+    Raise LookupError if the encoding is declared but unknown.
+    """
+    # Only consider the first two lines
+    str = str.split("\n", 2)[:2]
+    str = "\n".join(str)
+
+    match = coding_re.search(str)
+    if not match:
+        return None
+    name = match.group(1)
+    # Check whether the encoding is known
+    import codecs
+    try:
+        codecs.lookup(name)
+    except LookupError:
+        # The standard encoding error does not indicate the encoding
+        raise LookupError, _('Unknown encoding %s')%name
+    return name
+
+unicodeErrorMsg = 'Please change the defaultencoding in sitecustomize.py or '\
+    'use Boa command-line parameter -U handle this encoding.\nError message %s'
+
+def stringFromControl(u):
+    try: wx.USE_UNICODE, UnicodeError
+    except (AttributeError, NameError): return u
+
+    if wx.USE_UNICODE:
+        try:
             return str(u)
         except UnicodeError, err:
-            raise Exception, 'Unable to encode unicode string, please change '\
-                  'the defaultencoding in sitecustomize.py to handle this '\
-                  'encoding.\nError message %s'%str(err)
+            try:
+                spec = coding_spec(u)
+                if spec is None:
+                    raise
+                return u.encode(spec)
+            except UnicodeError, err:
+                try:
+                    s = _('Unable to encode unicode string, please change '\
+                          'the defaultencoding in sitecustomize.py to handle this '\
+                          'encoding.\nError message %s')%str(err)
+                except UnicodeError, err:
+                    raise Exception, 'Unable to encode unicode string, please change '\
+                          'the defaultencoding in sitecustomize.py to handle this '\
+                          'encoding.\nError message %s'%str(err)
+                else:
+                    raise Exception, s
     else:
         return u
-        
-def stringToControl(s):
-    try: wxUSE_UNICODE, UnicodeError
-    except NameError: return s
 
-    if wxUSE_UNICODE:
-        try: 
-            return unicode(s)
+def stringToControl(s, safe=False):
+    try: wx.USE_UNICODE, UnicodeError
+    except (AttributeError, NameError): return s
+
+    if wx.USE_UNICODE:
+        try:
+            if safe:
+                return s.decode(sys.getdefaultencoding(), 'ignore')
+            else:
+                return unicode(s)
         except UnicodeError, err:
-            raise Exception, 'Unable to decode unicode string, please change '\
-                  'the defaultencoding in sitecustomize.py to handle this '\
-                  'encoding.\n Error message %s'%str(err)
+            try:
+                spec = coding_spec(s)
+                if spec is None:
+                    raise
+                return s.decode(spec)
+            except UnicodeError, err:
+                try:
+                    s = _('Unable to decode unicode string, please change '\
+                          'the defaultencoding in sitecustomize.py to handle this '\
+                          'encoding.\n Error message %s')
+                except UnicodeError, err:
+                    raise Exception, 'Unable to decode unicode string, please change '\
+                          'the defaultencoding in sitecustomize.py to handle this '\
+                          'encoding.\n Error message %s'%str(err)
+                else:
+                    raise Exception, s
     else:
         return s
 
+def safeDecode(s):
+    return s.decode(sys.getdefaultencoding(), 'replace')    
+
+#-------------------------------------------------------------------------------
 
 def getEOLMode(text, default=os.linesep):
     if text.find('\r\n') != -1: return '\r\n'
@@ -877,15 +1010,40 @@ def toUnixEOLMode(text):
     return text.replace('\r\n', '\n').replace('\r', '\n')
 
 def checkMixedEOLs(text):
-    """ Returns false for mixed EOLs """
+    """ Returns False for mixed EOLs """
 
     crlf = text.count('\r\n')
     lf = text.count('\n')
     cr = text.count('\r')
 
     if crlf and (lf > crlf or cr > crlf):
-        return true
+        return True
     elif not crlf and cr and lf:
-        return true
+        return True
     else:
-        return false
+        return False
+
+#-------------------------------------------------------------------------------
+
+class InspectorSessionMix:
+    def doPost(self, inspector):
+        pass
+
+    def doCancel(self, inspector):
+        pass
+
+    def promptPostOrCancel(self, inspector):
+        pass
+
+    # Up is included because it can exit a session
+    def doUp(self, inspector):
+        pass
+
+def getEventChecked(event):
+    # XXX Chaos :(
+    checked = event.IsChecked()
+    if wx.Platform == '__WXGTK__' or wx.VERSION[:3] > (2, 5, 3):
+        return checked
+    else:
+        return not checked
+
