@@ -7,17 +7,18 @@
 # Author:      Riaan Booysen
 #
 # Created:     2001
-# RCS-ID:      $Id: InspectableViews.py,v 1.16 2004/08/16 13:35:57 riaan Exp $
-# Copyright:   (c) 2001 - 2004 Riaan Booysen
+# RCS-ID:      $Id: InspectableViews.py,v 1.26 2007/07/02 15:01:16 riaan Exp $
+# Copyright:   (c) 2001 - 2007 Riaan Booysen
 # Licence:     GPL
 #-----------------------------------------------------------------------------
 print 'importing Views.InspectableViews'
 
 import copy, os, pprint
 
-from wxPython.wx import *
+import wx
 
 import Preferences, Utils
+from Utils import _
 
 import PaletteMapping, EditorViews
 from ObjCollection import ObjectCollection, getCollName
@@ -26,30 +27,18 @@ import methodparse, sourceconst
 
 class DesignerError(Exception): pass
 
-class InspectorSessionMix:
-    def doPost(self, inspector):
-        pass
-
-    def doCancel(self, inspector):
-        pass
-
-    def promptPostOrCancel(self, inspector):
-        pass
-
-    # Up is included because it can exit a session
-    def doUp(self, inspector):
-        pass
-
-class InspectableObjectView(EditorViews.EditorView, InspectorSessionMix):
+class InspectableObjectView(EditorViews.EditorView, Utils.InspectorSessionMix):
     """ Base class for Designers
 
     A designer visually maintains one _init_* method in the source.
     """
     viewName = 'InspectableObject'
+    viewTitle = _('InspectableObject')
+    
     collectionMethod = 'init_'
     collectionParams = 'self'
 ##    handledProps = []
-    supportsParentView = false
+    supportsParentView = False
 
     def setupArgs(self, ctrlName, params, dontEval, evalDct):
         """ Create a dictionary of parameters for the constructor of the
@@ -65,21 +54,21 @@ class InspectableObjectView(EditorViews.EditorView, InspectorSessionMix):
             #if len(value) >= 11 and value[:11] == 'self._init_':
             #    continue
             #    collItem = methodparse.CollectionInitParse(value)
-            #    self.addCollView(paramKey, collItem.method, false)
+            #    self.addCollView(paramKey, collItem.method, False)
             if paramKey in dontEval:
                 args[paramKey] = params[paramKey]
             else:
-                #try:
-                args[paramKey] = PaletteMapping.evalCtrl(params[paramKey], 
-                      evalDct)
-                #except AttributeError:
-                #    args[paramKey] = PaletteMapping.evalCtrl(params[paramKey], 
-                #          {'self': self.controllerView.objectNamespace})
+                try:
+                    args[paramKey] = PaletteMapping.evalCtrl(params[paramKey], 
+                          evalDct)
+                except AttributeError:
+                    args[paramKey] = PaletteMapping.evalCtrl(params[paramKey], 
+                          {'self': self.controllerView.objectNamespace})
 
         return args
 
     def __init__(self, inspector, model, compPal, actions=(), dclickActionIdx=-1, 
-          editorIsWindow=true):
+          editorIsWindow=True):
         self.compPal = compPal
         EditorViews.EditorView.__init__(self, model, actions, dclickActionIdx, editorIsWindow)
         self.selection = None
@@ -88,7 +77,7 @@ class InspectableObjectView(EditorViews.EditorView, InspectorSessionMix):
         self.objects = {}
         self.objectOrder = []
         self.collEditors = {}
-        self.opened = false
+        self.opened = False
 
     def destroy(self):
         del self.controllerView
@@ -146,7 +135,7 @@ class InspectableObjectView(EditorViews.EditorView, InspectorSessionMix):
 
         for ctrlName in collDeps.keys():
             for collInit in collDeps[ctrlName]:
-                self.addCollView(ctrlName, collInit.method, false)
+                self.addCollView(ctrlName, collInit.method, False)
 
     def initObjCreator(self, constrPrs):
         # Assumes all design time ctrls are imported in global scope
@@ -155,12 +144,12 @@ class InspectableObjectView(EditorViews.EditorView, InspectorSessionMix):
                   self.model.customClasses)
         except NameError:
             raise DesignerError, \
-                  '%s is not defined on the Palette.'%constrPrs.class_name
+                  _('%s is not defined on the Palette.')%constrPrs.class_name
         try:
             ctrlCompnClass = PaletteMapping.compInfo[ctrlClass][1]
         except KeyError:
             raise DesignerError, \
-                  '%s is not defined on the Palette.'%ctrlClass.__name__
+                  _('%s is not defined on the Palette.')%ctrlClass.__name__
         else:
             ctrlName = self.loadControl(ctrlClass, ctrlCompnClass,
               constrPrs.comp_name, constrPrs.params)
@@ -183,7 +172,7 @@ class InspectableObjectView(EditorViews.EditorView, InspectorSessionMix):
                 # Collection initialisers
                 elif len(prop.params) and prop.params[0][:11] == 'self._init_':
                     collItem = methodparse.CollectionInitParse(prop.params[0])
-                    self.addCollView(name, collItem.method, false)
+                    self.addCollView(name, collItem.method, False)
                 # Check for custom evaluator
                 elif comp.customPropEvaluators.has_key(prop.prop_name):
                     args = comp.customPropEvaluators[prop.prop_name](prop.params, 
@@ -192,9 +181,9 @@ class InspectableObjectView(EditorViews.EditorView, InspectorSessionMix):
                     # XXX argument list with more than one prop value are
                     # XXX initialised thru the companion instead of the control
                     if prop.prop_name in comp.initPropsThruCompanion:
-                        apply(getattr(comp, prop.prop_setter), (args,))
+                        getattr(comp, prop.prop_setter)(*(args,))
                     else:
-                        apply(getattr(ctrl, prop.prop_setter), args)
+                        getattr(ctrl, prop.prop_setter)(*args)
                 # Check for pops which don't update the control
                 elif prop.prop_name in comp.onlyPersistProps():
                     continue
@@ -207,7 +196,7 @@ class InspectableObjectView(EditorViews.EditorView, InspectorSessionMix):
                         value = PaletteMapping.evalCtrl(prop.params[0], 
                           {'self': self.controllerView.objectNamespace})
                     except:
-                        print 'Problem with: %s' % prop.asText()
+                        print _('Problem with: %s') % prop.asText()
                         raise
 
                     if prop.prop_name in comp.initPropsThruCompanion:
@@ -232,7 +221,7 @@ class InspectableObjectView(EditorViews.EditorView, InspectorSessionMix):
                         dependents[name] = []
                     dependents[name].append(collInit)
                 else:
-                    self.addCollView(name, collInit.method, false)
+                    self.addCollView(name, collInit.method, False)
 
             # store default collection initialisers
             comp.setCollInits(collInits[name])
@@ -253,8 +242,10 @@ class InspectableObjectView(EditorViews.EditorView, InspectorSessionMix):
     def addCollView(self, name, collInitMethod, create):
         comp, ctrl = self.objects[name][:2]
         collName = getCollName(collInitMethod, name)
-        collCompClass = comp.subCompanions[collName]
-        # decl collComp -> CollectionDTC
+        try:
+            collCompClass = comp.subCompanions[collName]
+        except KeyError:
+            raise Exception, _('Sub-Companion not found for %s in %s')%(name, collInitMethod)
         collComp = collCompClass(name, self, comp, ctrl)
         if create:
             collComp.persistCollInit(collInitMethod, name, collName)
@@ -288,16 +279,16 @@ class InspectableObjectView(EditorViews.EditorView, InspectorSessionMix):
         if prop.prop_name in dependentProps:
             refs = self.getRefsFromProp(prop)
             # Postpone if target ctrls not yet defined
-            allCtrlsDefined = true#len(refs) > 0
+            allCtrlsDefined = True#len(refs) > 0
             for ref in refs:
                 if ref not in definedCtrls:
-                    allCtrlsDefined = false
+                    allCtrlsDefined = False
 
             if not allCtrlsDefined:
                 self.addDepLink(prop, ctrlName, deps, depLinks)
-                return true
+                return True
 
-        return false
+        return False
 
     def applyDepsForCtrl(self, ctrlName, depLinks):
         if depLinks.has_key(ctrlName):
@@ -336,7 +327,7 @@ class InspectableObjectView(EditorViews.EditorView, InspectorSessionMix):
                             else:
                                 refs.append(self.companion.eval(param))
 
-                        apply(getattr(ctrl, prop.prop_setter), refs)
+                        getattr(ctrl, prop.prop_setter)(*refs)
 
             del depLinks[ctrlName]
 
@@ -461,7 +452,7 @@ class InspectableObjectView(EditorViews.EditorView, InspectorSessionMix):
             for imp in imps:
                 imp = imp.strip()
                 if imp:
-                    module.addImportStatement(imp, resourceImport=true)
+                    module.addImportStatement(imp, resourceImport=True)
 
         emptyCodeBlock = newBody == ['']
 
@@ -476,7 +467,7 @@ class InspectableObjectView(EditorViews.EditorView, InspectorSessionMix):
               self.collectionMethod)
             if (len(docs) > 0) and docs[0]:
                 newBody.insert(0, '%s""" %s """'%(sourceconst.bodyIndent, docs))
-                emptyCodeBlock = false
+                emptyCodeBlock = False
 
             if emptyCodeBlock:
                 module.removeMethod(self.model.main, self.collectionMethod)
@@ -555,7 +546,7 @@ class InspectableObjectView(EditorViews.EditorView, InspectorSessionMix):
                 except NameError:
                     print 'PASTE ERROR', input
         if not methList:
-            raise 'Nothing to paste'
+            raise Exception, _('Nothing to paste')
 
         collObjColls = []
         pastedCtrls = []
@@ -582,7 +573,7 @@ class InspectableObjectView(EditorViews.EditorView, InspectorSessionMix):
                 collObjColls.append( (meth[0], ctrlName, newObjColl) )
 
         if not collMethod:
-            raise DesignerError, 'Method % not found' % self.collectionMethod
+            raise DesignerError, _('Method %s not found') % self.collectionMethod
 
         # Parse input source
         objCol = self.model.readDesignerMethod(collMethod, methBody)
@@ -644,11 +635,11 @@ class InspectableObjectView(EditorViews.EditorView, InspectorSessionMix):
         # create controls
         deps = {}
         depLnks = {}
-        self.inspector.vetoSelect = true
+        self.inspector.vetoSelect = True
         try:
             self.initObjectsAndCompanions(objCol.creators, objCol, deps, depLnks)
         finally:
-            self.inspector.vetoSelect = false
+            self.inspector.vetoSelect = False
 
         # merge pasted controls with current controls
         self.model.objectCollections[collMethod].merge(objCol)
@@ -667,8 +658,13 @@ class InspectableObjectView(EditorViews.EditorView, InspectorSessionMix):
         # XXX Now that there is multiple maintained methods is may fail because
         # XXX it's only unique in the method.
         num = 1
-        if className[:2] == 'wx':
-            newName = '%s%s'%(className[2:3].lower(), className[3:])
+        
+        dotted = className.rfind('.')
+        if dotted != -1:
+            if className[:3] == 'wx.':
+                newName = '%s%s'%(className[dotted+1:dotted+2].lower(), className[dotted+2:])
+            else:
+                newName = '%s%s'%(className[0].lower(), className[1:])                
         else:
             newName = '%s%s'%(className[0].lower(), className[1:])
 
@@ -686,7 +682,7 @@ class InspectableObjectView(EditorViews.EditorView, InspectorSessionMix):
         companion = ObjCompanionClass(objName, self, ObjClass)
         params = companion.designTimeSource()
         self.addObject(objName, companion, companion.designTimeObject(), '')
-        companion.persistConstr(ObjClass.__name__, params)
+        companion.persistConstr(Utils.getWxPyNameForClass(ObjClass), params)
         return objName
 
 
@@ -777,14 +773,14 @@ class InspectableObjectView(EditorViews.EditorView, InspectorSessionMix):
                 results['self.'+objName] = self.objects[objName][1]
         return results
 
-    def showCollectionEditor(self, ctrlName, propName, show=true):
+    def showCollectionEditor(self, ctrlName, propName, show=True):
         """ Show the Collection Editor frame for given name and prop """
         # XXX param ctrlName is actually wrong!
         if ctrlName == self.GetName():
             ctrlName = ''
 
         if not self.collEditors.has_key((ctrlName, propName)):
-            self.addCollView(ctrlName, '_init_coll_%s_%s'%(ctrlName, propName), true)
+            self.addCollView(ctrlName, '_init_coll_%s_%s'%(ctrlName, propName), True)
 
         collEditor = self.collEditors[(ctrlName, propName)]
         
@@ -796,18 +792,18 @@ class InspectableObjectView(EditorViews.EditorView, InspectorSessionMix):
     def checkHost(self, CtrlCompanion):
         """ Checks that the companion may be hosted in this designer """
         if CtrlCompanion.host == 'Not Implemented':
-            dlg = wxMessageDialog(self, 'This component is not yet implemented',
-                              'Not Implemented', wxOK | wxICON_ERROR)
+            dlg = wx.MessageDialog(self, _('This component is not yet implemented'),
+                              _('Not Implemented'), wx.OK | wx.ICON_ERROR)
             try: dlg.ShowModal()
             finally: dlg.Destroy()
-            raise DesignerError, 'Not Implemented'
+            raise DesignerError, _('Not Implemented')
         if CtrlCompanion.host != self.viewName:
-            dlg = wxMessageDialog(self,
-              'This component must be created in the '+CtrlCompanion.host+' view',
-              'Wrong Designer', wxOK | wxICON_ERROR)
+            dlg = wx.MessageDialog(self,
+              _('This component must be created in the %s view')%CtrlCompanion.host,
+              _('Wrong Designer'), wx.OK | wx.ICON_ERROR)
             try: dlg.ShowModal()
             finally: dlg.Destroy()
-            raise DesignerError, 'Wrong Designer'
+            raise DesignerError, _('Wrong Designer')
 
     def expandNamesToContainers(self, ctrlNames):
         """ Expand set of names to include the names of all their children """
@@ -844,7 +840,7 @@ class InspectableObjectView(EditorViews.EditorView, InspectorSessionMix):
 
         from CreationOrdDlg import CreationOrderDlg
         dlg = CreationOrderDlg(self, sibs, allSibs)
-        if dlg.ShowModal() == wxID_OK:
+        if dlg.ShowModal() == wx.ID_OK:
             for idx, name in map(None, dlg.allCtrlIdxs, dlg.allCtrlNames):
                 self.objectOrder[idx] = name
 
