@@ -5,18 +5,19 @@
 # Author:      Riaan Booysen
 #
 # Created:     1999
-# RCS-ID:      $Id: OGLViews.py,v 1.21 2004/08/16 13:07:41 riaan Exp $
-# Copyright:   (c) 1999 - 2004 Riaan Booysen
+# RCS-ID:      $Id: OGLViews.py,v 1.27 2007/07/02 15:01:16 riaan Exp $
+# Copyright:   (c) 1999 - 2007 Riaan Booysen
 # Licence:     GPL
 #----------------------------------------------------------------------
 print 'importing Views.OGLViews'
 
 import pickle, os
 
-from wxPython.wx import *
-from wxPython.ogl import *
+import wx
+import wx.lib.ogl as ogl
 
 import Preferences, Utils
+from Utils import _
 
 from Preferences import IS
 
@@ -31,25 +32,25 @@ import EditorViews
 # * Is the topological layout applicable to import diagrams? (They can be cyclic)
 # * Optional hiding of classes in UMLView
 
-wxOGLInitialize()
+ogl.OGLInitialize()
 
-class RoundedRectangleShape(wxRectangleShape):
+class RoundedRectangleShape(ogl.RectangleShape):
     def __init__(self, w=0.0, h=0.0):
-        wxRectangleShape.__init__(self, w, h)
+        ogl.RectangleShape.__init__(self, w, h)
         self.SetCornerRadius(-0.3)
 
-class MyEvtHandler(wxShapeEvtHandler):
+class MyEvtHandler(ogl.ShapeEvtHandler):
     def OnLeftClick(self, x, y, keys = 0, attachment = 0):
         shape = self.GetShape()
         canvas = shape.GetCanvas()
-        dc = wxClientDC(canvas)
+        dc = wx.ClientDC(canvas)
         canvas.PrepareDC(dc)
 
         if shape.Selected():
-            shape.Select(false, dc)
+            shape.Select(False, dc)
             canvas.Redraw(dc)
         else:
-            redraw = false
+            redraw = False
             shapeList = canvas.GetDiagram().GetShapeList()
             toUnselect = []
             for s in shapeList:
@@ -61,16 +62,16 @@ class MyEvtHandler(wxShapeEvtHandler):
                         toUnselect.append(s)
                 except Exception, message: pass#print Exception, message
 
-            shape.Select(true, dc)
+            shape.Select(True, dc)
 
             if toUnselect:
                 for s in toUnselect:
-                    s.Select(false, dc)
+                    s.Select(False, dc)
                 canvas.Redraw(dc)
 
     def OnEndDragLeft(self, x, y, keys = 0, attachment = 0):
         shape = self.GetShape()
-        self.base_OnEndDragLeft(x, y, keys, attachment)
+        ogl.ShapeEvtHandler.OnEndDragLeft(self, x, y, keys, attachment)
         if not shape.Selected():
             self.OnLeftClick(x, y, keys, attachment)
 
@@ -83,7 +84,7 @@ class MyEvtHandler(wxShapeEvtHandler):
             self.OnLeftClick(x, y, keys, attachment)
 
         if hasattr(self, 'menu') and self.menu:
-            shape.GetCanvas().PopupMenu(self.menu, wxPoint(x, y))
+            shape.GetCanvas().PopupMenu(self.menu, wx.Point(x, y))
 
     def OnRightDown(self, event):
         print "OnRightDown", event
@@ -92,10 +93,10 @@ class MyEvtHandler(wxShapeEvtHandler):
 
 incy = 45
 
-class PersistentShapeCanvas(wxShapeCanvas):
+class PersistentShapeCanvas(ogl.ShapeCanvas):
     ext = '.lay'
     def __init__(self, parent, shapes):
-        wxShapeCanvas.__init__(self, parent, style = 0)
+        ogl.ShapeCanvas.__init__(self, parent, style = 0)
         self.SetBackgroundColour(Preferences.vpOGLCanvasBackgroundColour)
         self.shapes = shapes
 
@@ -117,17 +118,17 @@ class PersistentShapeCanvas(wxShapeCanvas):
 
     def printSizes(self, filename):
         """ Export the Canvas to Postscript """
-        prdata=wxPrintData()
+        prdata = wx.PrintData()
         from Explorers.Explorer import openEx
-        t=openEx(filename)
+        t = openEx(filename)
         prdata.SetFilename(t.currentFilename())
-        dc=wxPostScriptDC(prdata)
+        dc = wx.PostScriptDC(prdata)
         if dc.Ok():
             dc.StartDoc('Export')
             self.Redraw(dc)
             dc.EndDoc()
             
-            wxLogMessage('Exported %s'%filename)
+            wx.LogMessage('Exported %s'%filename)
 
     def loadSizes(self, filename):
         from Explorers.Explorer import openEx, TransportError
@@ -135,16 +136,16 @@ class PersistentShapeCanvas(wxShapeCanvas):
         try:
             persProps = pickle.loads(t.load())
         except SyntaxError:
-            if wxMessageBox('%s is possibly corrupt (cannot be unpickled), delete it?'\
-                            'Default layout will be used.'%filename,
-                  'Corrupt file', style = wxYES_NO | wxICON_EXCLAMATION) == wxYES:
-                # XXX Just lazy, must fix to use transport !!
+            if wx.MessageBox(_('%s is possibly corrupt (cannot be unpickled), delete it?'\
+                  'Default layout will be used.')%filename, _('Corrupt file'), 
+                  style = wx.YES_NO | wx.ICON_EXCLAMATION) == wx.YES:
+                # XXX update to use transport !!
                 if filename[:7] != 'file://':
-                    wxLogMessage('Sorry, only supported on the filesystem')
+                    wx.LogMessage(_('Sorry, only supported on the filesystem'))
                 else:
                     os.remove(filename[7:])
 
-            raise TransportError('Corrupt layout file')
+            raise TransportError(_('Corrupt layout file'))
 
         unmatchedPcls = persProps.keys()
         matchedShapes = []
@@ -165,7 +166,7 @@ class PersistentShapeCanvas(wxShapeCanvas):
     def redraw(self):
         diagram = self.GetDiagram()
         canvas = diagram.GetCanvas()
-        dc = wxClientDC(canvas)
+        dc = wx.ClientDC(canvas)
         canvas.PrepareDC(dc)
         for shape in self.shapes:
             shape.Move(dc, shape.GetX(), shape.GetY())
@@ -186,9 +187,9 @@ class PerstShape:
          before reading sizes into pickle."""
 
 
-class PerstDividedShape(wxDividedShape, PerstShape):
+class PerstDividedShape(ogl.DividedShape, PerstShape):
     def __init__(self, unqPclName, width, height):
-        wxDividedShape.__init__(self, width, height)
+        ogl.DividedShape.__init__(self, width, height)
         PerstShape.__init__(self, unqPclName)
 
     def setPos(self, pos):
@@ -210,7 +211,7 @@ class PerstDividedShape(wxDividedShape, PerstShape):
         regions and draws it. There seems to be a problem that
         the text is not normally drawn. """
         canvas = self.GetCanvas()
-        dc = wxClientDC(canvas)
+        dc = wx.ClientDC(canvas)
         canvas.PrepareDC(dc)
         count = 0
         for region in self.GetRegions():
@@ -218,37 +219,38 @@ class PerstDividedShape(wxDividedShape, PerstShape):
             self.FormatText(dc, region.GetText(), count)
             count = count + 1
 
-class ScrollingContainer(wxScrolledWindow):
+class ScrollingContainer(wx.ScrolledWindow):
     scrollStepX = 10
     scrollStepY = 10
     def __init__(self, parent, size):
-        wxScrolledWindow.__init__(self, parent, -1, style = wxSUNKEN_BORDER)
+        wx.ScrolledWindow.__init__(self, parent, -1, style = wx.SUNKEN_BORDER)
         self.SetScrollbars(self.scrollStepX, self.scrollStepY,
                            size.x / self.scrollStepX, size.y / self.scrollStepY)
 
 class PersistentOGLView(ScrollingContainer, EditorViews.EditorView):
     viewName = 'OGL'
+    viewTitle = _('OGL')
     loadBmp = 'Images/Editor/Open.png'
     saveBmp = 'Images/Editor/Save.png'
     defSize = 2000
 
     def __init__(self, parent, model, actions = ()):
-        ScrollingContainer.__init__(self, parent, wxSize(self.defSize, self.defSize))
+        ScrollingContainer.__init__(self, parent, wx.Size(self.defSize, self.defSize))
         EditorViews.EditorView.__init__(self, model,
-          (('(Re)load diagram', self.OnLoad, self.loadBmp, ''),
-           ('Save diagram', self.OnSave, self.saveBmp, ''),
-           ('Print diagram to PostScript', self.OnPrintToPS, '-', ''), 
+          ((_('(Re)load diagram'), self.OnLoad, self.loadBmp, ''),
+           (_('Save diagram'), self.OnSave, self.saveBmp, ''),
+           (_('Print diagram to PostScript'), self.OnPrintToPS, '-', ''), 
            ('-', None, '-', ''),
-           ('Change size', self.OnSetSize, '-', ''),
+           (_('Change size'), self.OnSetSize, '-', ''),
            )+actions)
 
         self.shapes = []
         self.canvas = PersistentShapeCanvas(self, self.shapes)
         self.canvas.SetSize(self.GetVirtualSize())
 
-        EVT_RIGHT_UP(self.canvas, self.OnRightClick)
+        self.canvas.Bind(wx.EVT_RIGHT_UP, self.OnRightClick)
 
-        self.diagram = wxDiagram()
+        self.diagram = ogl.Diagram()
         self.canvas.SetDiagram(self.diagram)
         self.diagram.SetCanvas(self.canvas)
 
@@ -256,13 +258,13 @@ class PersistentOGLView(ScrollingContainer, EditorViews.EditorView):
 
         self.size = self.defSize
 
-        self._loaded = false
+        self._loaded = False
 
-        self.active = true
+        self.active = True
 
     def destroy(self):
         self.destroyShapes()
-        self.diagram.Destroy()
+##        self.diagram.Destroy()
         EditorViews.EditorView.destroy(self)
 
     def destroyShapes(self):
@@ -274,31 +276,31 @@ class PersistentOGLView(ScrollingContainer, EditorViews.EditorView):
         from Explorers.Explorer import TransportError
         try:
             self.canvas.loadSizes(layoutFile)
-            self._loaded = true
+            self._loaded = True
         except TransportError:
-            self._loaded = false
+            self._loaded = False
 
     def newLine(self, dc, fromShape, toShape):
-        line = wxLineShape()
+        line = ogl.LineShape()
         line.SetCanvas(self.canvas)
         line.SetPen(Preferences.vpOGLLinePen)
         line.SetBrush(Preferences.vpOGLLineBrush)
 
-        line.AddArrow(ARROW_ARROW)
+        line.AddArrow(ogl.ARROW_ARROW)
         #pmf = wxPseudoMetaFile()
         #pmf.LoadFromMetaFile('Images/Views/UML/inherit.wmf', 10.0, 10.0)
         #line.AddArrow(ARROW_METAFILE, mf=pmf)
         line.MakeLineControlPoints(2)
         fromShape.AddLine(line, toShape)
         self.diagram.AddShape(line)
-        line.Show(true)
+        line.Show(True)
 
         # for some reason, the shapes have to be moved for the line to show up...
         fromShape.Move(dc, fromShape.GetX(), fromShape.GetY())
 
     def newRegion(self, font, name, textLst, maxWidth, totHeight = 10):
-        region = wxShapeRegion()
-        dc = wxClientDC(self.canvas)
+        region = ogl.ShapeRegion()
+        dc = wx.ClientDC(self.canvas)
         dc.SetFont(font)
 
         for text in textLst:
@@ -314,17 +316,17 @@ class PersistentOGLView(ScrollingContainer, EditorViews.EditorView):
         return region, maxWidth, totHeight
 
     def addShape(self, shape, x, y, pen, brush, text):
-#        shape.SetDraggable(false)
+#        shape.SetDraggable(False)
         shape.SetCanvas(self.canvas)
         shape.SetX(x)
         shape.SetY(y)
         shape.SetPen(pen)
         shape.SetBrush(brush)
-#        shape.SetFont(wxFont(6, wxMODERN, wxNORMAL, wxNORMAL, false))
+#        shape.SetFont(wx.Font(6, wx.MODERN, wx.NORMAL, wx.NORMAL, False))
         shape.AddText(text)
-        shape.SetShadowMode(SHADOW_RIGHT)
+        shape.SetShadowMode(ogl.SHADOW_RIGHT)
         self.diagram.AddShape(shape)
-        shape.Show(true)
+        shape.Show(True)
 
         evthandler = MyEvtHandler()
         evthandler.menu = self.shapeMenu
@@ -354,12 +356,12 @@ class PersistentOGLView(ScrollingContainer, EditorViews.EditorView):
         self.canvas.printSizes(os.path.splitext(self.model.filename)[0]+'.ps')
 
     def OnSetSize(self, event):
-        dlg = wxTextEntryDialog(self, 'Enter new canvas size (width==height)',
+        dlg = wx.TextEntryDialog(self, 'Enter new canvas size (width==height)',
             'Size', `self.size`)
         try:
-            if dlg.ShowModal() == wxID_OK:
+            if dlg.ShowModal() == wx.ID_OK:
                 self.size = int(dlg.GetValue())
-                self.setSize(wxSize(self.size, self.size))
+                self.setSize(wx.Size(self.size, self.size))
         finally:
             dlg.Destroy()
 
@@ -473,7 +475,7 @@ class SortedUMLViewMix:
         rawHeight = height
         height = height * whiteSpaceFactor
         verticalWhiteSpace = (height-rawHeight)/(len(generations)-1.0 or 2.0)
-        self.setSize(wxSize(int(width+50), int(height+50))) # fudge factors to keep some extra space
+        self.setSize(wx.Size(int(width+50), int(height+50))) # fudge factors to keep some extra space
         # distribute each generation across the width
         # and the generations across height
         y = 0
@@ -487,7 +489,7 @@ class SortedUMLViewMix:
                 # snap to diagram grid coords
                 csX, csY = self.diagram.Snap((shapeX/2.0)+x, (shapeY/2.0)+y)
                 # don't display until finished
-                classShape.Move(dc, csX, csY, false)
+                classShape.Move(dc, csX, csY, False)
                 x = x + shapeX + whiteSpace
             y = y + currentHeight + verticalWhiteSpace
 
@@ -567,8 +569,10 @@ def _buildChildrenLists (routes):
     return childrenTable, parentTable
 
 class UMLView(PersistentOGLView, SortedUMLViewMix):
-    ext = '.umllay'
     viewName = 'UML'
+    viewTitle = _('UML')
+
+    ext = '.umllay'
     showAttributes = 1
     showMethods = 1
     AllClasses = {}
@@ -578,18 +582,18 @@ class UMLView(PersistentOGLView, SortedUMLViewMix):
     def __init__(self, parent, model):
         PersistentOGLView.__init__(self, parent, model, (
             ('-', None, '-', ''),
-            ('Toggle Attributes', self.OnToggleAttributes, self.toggleAttrBmp, ''),
-            ('Toggle Methods', self.OnToggleMethods, self.toggleMethBmp, ''),
+            (_('Toggle Attributes'), self.OnToggleAttributes, self.toggleAttrBmp, ''),
+            (_('Toggle Methods'), self.OnToggleMethods, self.toggleMethBmp, ''),
             ('-', None, '-', ''),
-            ('Force layout', self.OnForceLayout, '-', ''),
+            (_('Force layout'), self.OnForceLayout, '-', ''),
         ))
-        self.menuStdClass = wxMenu()
-        id = wxNewId()
-        self.menuStdClass.Append(id, "Goto Source")
-        EVT_MENU(self, id, self.OnGotoSource)
-        id = wxNewId()
-        self.menuStdClass.Append(id, "Goto Documentation",)
-        EVT_MENU(self, id, self.OnGotoDoc)
+        self.menuStdClass = wx.Menu()
+        id = wx.NewId()
+        self.menuStdClass.Append(id, _('Goto Source'))
+        self.Bind(wx.EVT_MENU, self.OnGotoSource, id=id)
+        id = wx.NewId()
+        self.menuStdClass.Append(id, _('Goto Documentation'),)
+        self.Bind(wx.EVT_MENU, self.OnGotoDoc, id=id)
 
         self.shapeMenu = self.menuStdClass
 
@@ -653,7 +657,7 @@ class UMLView(PersistentOGLView, SortedUMLViewMix):
         return self.shapes[idx]
 
     def refreshCtrl(self):
-        dc = wxClientDC(self.canvas)
+        dc = wx.ClientDC(self.canvas)
         self.canvas.PrepareDC(dc)
 
         self.destroyShapes()
@@ -684,9 +688,9 @@ class UMLView(PersistentOGLView, SortedUMLViewMix):
                 module = self.model.getModule()
                 #srcView.gotoLine(int(module.classes[name].block.start) -1)
             else:
-                print "Documentation View is not open"
+                print _('Documentation View is not open')
         else:
-            print "No shape selected"
+            print _('No shape selected')
 
     def OnGotoSource(self, event):
         if self.menuClass:
@@ -698,9 +702,9 @@ class UMLView(PersistentOGLView, SortedUMLViewMix):
                 module = self.model.getModule()
                 srcView.gotoLine(int(module.classes[name].block.start) -1)
             else:
-                print "No source for selection"
+                print _('No source for selection')
         else:
-            print "No shape selected"
+            print _('No shape selected')
 
     ## This allows me to pop-up a menu for the shape. However it loses the
     ## main menu position (x, y) go to 0,0 after the skip
@@ -709,7 +713,7 @@ class UMLView(PersistentOGLView, SortedUMLViewMix):
         x, y = (event.m_x, event.m_y)
         hit = 0
         for (name, shape) in self.AllClasses.items():
-            (hit, attach_point, distance) = shape.HitTest(x, y)
+            hit = shape.HitTest(x, y)
             if hit: break
         x, y = self.CalcScrolledPosition(x, y)
         if not hit:
@@ -721,11 +725,11 @@ class UMLView(PersistentOGLView, SortedUMLViewMix):
         # However, it may be a class or external
         if self.model.getModule().classes.has_key(name):
             (self.menuShape, self.menuClass) = (shape, name)
-            self.PopupMenu(self.menuStdClass, wxPoint(x, y))
+            self.PopupMenu(self.menuStdClass, wx.Point(x, y))
             (self.menuShape, self.menuClass) = (None, None)
 
     def OnForceLayout(self, event):
-        dc = wxClientDC(self.canvas)
+        dc = wx.ClientDC(self.canvas)
         self.canvas.PrepareDC(dc)
 
         self.destroyShapes()
@@ -738,14 +742,16 @@ class UMLView(PersistentOGLView, SortedUMLViewMix):
 #-------------------------------------------------------------------------------
 
 class ImportsView(PersistentOGLView):
+    viewName = 'Imports'
+    viewTitle = _('Imports')
+
     ext = '.implay'
     refreshBmp = 'Images/Editor/Refresh.png'
-    viewName = 'Imports'
 
     def __init__(self, parent, model):
         PersistentOGLView.__init__(self, parent, model,
           (('-', None, '', ''),
-           ('Refresh', self.OnRefresh, self.refreshBmp, ''))
+           (_('Refresh'), self.OnRefresh, self.refreshBmp, ''))
         )
         self.relationships = None
         self.showImports = 1
@@ -782,7 +788,7 @@ class ImportsView(PersistentOGLView):
         return shape, maxWidth + 10
 
     def refreshCtrl(self):
-        dc = wxClientDC(self)
+        dc = wx.ClientDC(self)
         self.PrepareDC(dc)
 
         # Because of slow building process, cache after first time
@@ -835,20 +841,22 @@ class ImportsView(PersistentOGLView):
 
 
 class AppPackageView(PersistentOGLView):
+    viewName = 'Application packages'
+    viewTitle = _('Application packages')
+
     ext = '.apklay'
     refreshBmp = 'Images/Editor/Refresh.png'
-    viewName = 'Application packages'
 
     def __init__(self, parent, model):
         PersistentOGLView.__init__(self, parent, model,
           (('-', None, '', ''),
-           ('Refresh', self.OnRefresh, self.refreshBmp, ''))
+           (_('Refresh'), self.OnRefresh, self.refreshBmp, ''))
         )
         self.relationships = None
 
     def newModule(self, size, pos, moduleName, importList):
         idx = self.addShape(PerstDividedShape(moduleName, size[0], size[1]),
-          pos[0], pos[1], wxBLACK_PEN, wxLIGHT_GREY_BRUSH, '')
+          pos[0], pos[1], wx.BLACK_PEN, wx.LIGHT_GREY_BRUSH, '')
 
         maxWidth = 10 #padding
 
@@ -874,7 +882,7 @@ class AppPackageView(PersistentOGLView):
         return shape, maxWidth + 10
 
     def refreshCtrl(self):
-        dc = wxClientDC(self)
+        dc = wx.ClientDC(self)
         self.PrepareDC(dc)
 
         # Because of slow building process, cache after first time
@@ -913,10 +921,11 @@ class AppPackageView(PersistentOGLView):
         self.relationships = None
         self.refreshCtrl()
 
-class __Cleanup:
-    cleanup = wxOGLCleanUp
-    def __del__(self):
-        self.cleanup()
-
-# when this module gets cleaned up then wxOGLCleanUp() will get called
-__cu = __Cleanup()
+##class __Cleanup:
+##    cleanup = ogl.OGLCleanUp
+####    def __del__(self):
+##    def __del__():
+##        self.cleanup()
+##
+### when this module gets cleaned up then wx.OGLCleanUp() will get called
+##__cu = __Cleanup()
